@@ -1,13 +1,21 @@
 <?php
 # Send confirmation message for password recovery.
 #
-# Copyright (C) 1999-2000 The SourceForge Crew
-# Copyright (C) 2004-2005 Mathieu Roy <yeupou--gnu.org>
-# Copyright (C) 2004-2005 Joxean Koret <joxeankoret--yahoo.es>
-# Copyright (C) 2017, 2018, 2019, 2022, 2023 Ineiev <ineiev--gnu.org>
+# Copyright (C) 1999, 2000 The SourceForge Crew
+# Copyright (C) 2004, 2005 Joxean Koret <joxeankoret--yahoo.es>
+# Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
+# Copyright (C) 2014, 2016, 2017 Assaf Gordon
+# Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
+# Copyright (C) 2013, 2014, 2017-2023 Ineiev <ineiev@gnu.org>
 #
 # This file is part of Savane.
 #
+# Code written before 2008-03-30 (commit 8b757b2565ff) is distributed
+# under the terms of the GNU General Public license version 3 or (at your
+# option) any later version; further contributions are covered by
+# the GNU Affero General Public license version 3 or (at your option)
+# any later version.  The license notices for the AGPL and the GPL follow.
+#
 # Savane is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
 # published by the Free Software Foundation, either version 3 of the
@@ -20,13 +28,25 @@
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# Savane is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as
+# published by the Free Software Foundation, either version 3 of the
+# License, or (at your option) any later version.
+#
+# Savane is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 require_once ('../include/init.php');
 require_once ('../include/sane.php');
 require_once ('../include/session.php');
 require_once ('../include/sendmail.php');
 require_once ('../include/database.php');
-require_once ('../include/gpg.php');
 
 extract (sane_import ('post', ['name' => 'form_loginname']));
 
@@ -127,25 +147,20 @@ $message .=
     . "somebody else, e.g. do not mail this to a public mailinglist!\n\n"
 );
 $message .= sprintf (_("-- the %s team."), $GLOBALS['sys_name'])
-  . "\n";
+  . "\n" . sendmail_signature ();
 
 # We should not add i18n to admin messages.
 $message_for_admin =
-sprintf (
-  ("Someone attempted to change a password via email verification\n"
-   . "on %s\n\nSomeone is maybe trying to steal a user account.\n\n"
-   . "The user affected is %s\n\n"
-   . "Date: %s\n"),
-  $sys_default_domain, $form_loginname, gmdate ('D, d M Y H:i:s \G\M\T')
-);
+  sprintf (
+    ("Someone attempted to change a password via email verification\n"
+     . "on %s\n\nSomeone is maybe trying to steal a user account.\n\n"
+     . "The user affected is %s\n\n"
+     . "Date: %s\n"),
+    $sys_default_domain, $form_loginname, gmdate ('D, d M Y H:i:s \G\M\T')
+  );
 
-$encrypted_message = $gpg_error = $gpg_error = "";
-if (user_get_preference ("email_encrypted", $row_user['user_id']))
-  list ($gpg_error, $gpg_result, $encrypted_message) =
-    encrypt_to_user ($row_user['user_id'], $message);
-
-if($encrypted_message != "")
-  $message = $encrypted_message;
+list ($fail, $gpg_error) =
+  sendmail_encrypt_message ($row_user['user_id'], $message);
 
 sendmail_mail (
   ['from' => "$sys_mail_replyto@$sys_mail_domain", 'to' => $row_user['email']],
@@ -157,7 +172,7 @@ sendmail_mail (
     'to' =>  "$sys_mail_admin@$sys_mail_domain"],
   [ 'subject' => "password change - $sys_default_domain",
     'body' => $message_for_admin],
-  ['tracker' => "lostpw"]
+  ['tracker' => "lostpw", 'skip_format_body' => true]
 );
 
 fb (_("Confirmation mailed"));
@@ -170,7 +185,7 @@ print '<p>'
   . _("Follow the instructions in the email to change your account password.")
   . "</p>\n";
 
-if ($encrypted_message === "")
+if ($fail)
   {
     if (user_get_preference ("email_encrypted", $row_user['user_id']))
       print "<p><strong>$gpg_error<strong></p>";
