@@ -1,13 +1,20 @@
 <?php
 # Register an account, part 1 (part 2 is e-mail confirmation)
 #
-# Copyright (C) 1999-2000 The SourceForge Crew
-# Copyright (C) 2003-2006 Mathieu Roy <yeupou--gna.org>
-# Copyright (C) 2007  Sylvain Beucler
-# Copyright (C) 2017, 2019, 2020, 2022, 2023 Ineiev
+# Copyright (C) 1999, 2000 The SourceForge Crew
+# Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
+# Copyright (C) 2014, 2016, 2017 Assaf Gordon
+# Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
+# Copyright (C) 2013, 2014, 2017-2023 Ineiev
 #
 # This file is part of Savane.
 #
+# Code written before 2008-03-30 (commit 8b757b2565ff) is distributed
+# under the terms of the GNU General Public license version 3 or (at your
+# option) any later version; further contributions are covered by
+# the GNU Affero General Public license version 3 or (at your option)
+# any later version.  The license notices for the AGPL and the GPL follow.
+#
 # Savane is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
 # published by the Free Software Foundation, either version 3 of the
@@ -20,6 +27,19 @@
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# Savane is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as
+# published by the Free Software Foundation, either version 3 of the
+# License, or (at your option) any later version.
+#
+# Savane is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 require_once ('../include/init.php');
 require_once ('../include/sane.php');
@@ -262,35 +282,29 @@ if ($form_is_valid)
 site_header (
   ['title' => _("User account registration"), 'context' => 'account']
 );
-print form_header (
-  $_SERVER['PHP_SELF'], htmlentities ($form_id, ENT_QUOTES, 'UTF-8')
-);
+print form_header ($php_self, $form_id);
 $br = "</span><br />\n&nbsp;&nbsp;";
 $pre = '<p><span class="preinput">';
 print $pre . _("Login Name:") . $br;
-print form_input("text", "form_loginname", $form_loginname);
+print form_input ("text", "form_loginname", $form_loginname);
 print $pre . account_password_help () . '</span></p>';
 print $pre . _("Password / passphrase:") . $br;
-print form_input("password", "form_pw", $form_pw) . "</p>\n";
+print form_input ("password", "form_pw", $form_pw) . "</p>\n";
 print $pre . _("Re-type Password:") . $br;
-print form_input("password", "form_pw2", $form_pw2) . "</p>\n";
+print form_input ("password", "form_pw2", $form_pw2) . "</p>\n";
 print $pre . _("Real Name:") . $br;
-print '<input size="30" type="text" name="form_realname" value="'
-  . htmlentities ($form_realname, ENT_QUOTES , 'UTF-8') . "\" /></p>\n";
+print form_input ('text', 'form_realname', $form_realname, 'size="30"');
+print "</p>\n";
 print $pre . _("Email Address:") . $br;
-print '<input size="30" type="text" name="form_email" value="'
-  . htmlentities ($form_email, ENT_QUOTES , 'UTF-8') . '" />';
+print form_input ('text', "form_email", $form_email, 'size="30"');
 print "<br />\n" . '<span class="text">'
-  . _("This email address will be verified before account activation. "
-      . "Check your\nspam filters. Do not use a hotmail or comcast "
-      . "address here.")
+  . _("This email address will be verified before account activation.")
   . "</span></p>\n";
 
 if ($sys_registration_text_spam_test)
   {
     print $pre . _("Antispam test:") . $br;
-    print '<input size="30" type="text" name="form_year" value="'
-      . htmlentities ($form_year, ENT_QUOTES, 'UTF-8') . '" />';
+    print form_input ('text', "form_year", $form_year, 'size="30"');
     print "<br />\n<span class='text'>";
     printf (
       _("In what year was the GNU project announced? "
