@@ -1,12 +1,21 @@
 <?php
 # Manage commit hooks/triggers.
-# Copyright (C) 2006  Sylvain Beucler
-# Copyright (C) 2017, 2018, 2021, 2022, 2023 Ineiev
+# Copyright (C) 1999, 2000 The SourceForge Crew
+# Copyright (C) 2000-2006 Mathieu Roy
+# Copyright (C) 2014, 2016, 2017 Assaf Gordon
+# Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
+# Copyright (C) 2013, 2014, 2017-2023 Ineiev
 #
 # This file is part of the Savane project
 #
 # This file is part of Savane.
 #
+# Code written before 2008-03-30 (commit 8b757b2565ff) is distributed
+# under the terms of the GNU General Public license version 3 or (at your
+# option) any later version; further contributions are covered by
+# the GNU Affero General Public license version 3 or (at your option)
+# any later version.  The license notices for the AGPL and the GPL follow.
+#
 # Savane is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
 # published by the Free Software Foundation, either version 3 of the
@@ -19,6 +28,19 @@
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# Savane is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as
+# published by the Free Software Foundation, either version 3 of the
+# License, or (at your option) any later version.
+#
+# Savane is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 require_once ('../../include/init.php');
 require_once ('../../include/sane.php');
@@ -87,7 +109,7 @@ if (isset ($log_accum))
             WHERE
               cvs_hooks.id = cvs_hooks_log_accum.hook_id
               AND group_id = ? AND id = ?",
-            [$group_id, $hook_id]) or die (db_error ());
+            [$group_id, $hook_id]) or util_die (db_error ());
           if ($have_arr_id)
             unset ($arr_id[$hook_id]);
         }
@@ -128,7 +150,7 @@ if (isset ($log_accum))
                   'dir_list' => $dir_list,
                   'hook_name' => 'log_accum'
                 ],
-                DB_AUTOQUERY_INSERT) or die (db_error ());
+                DB_AUTOQUERY_INSERT) or util_die (db_error ());
               $new_hook_id = db_insertid (NULL);
               db_autoexecute ('cvs_hooks_log_accum',
                 [
@@ -138,7 +160,7 @@ if (isset ($log_accum))
                   'enable_diff' => $enable_diff,
                   'emails_diff' => $emails_diff
                 ],
-                DB_AUTOQUERY_INSERT) or die (db_error ());
+                DB_AUTOQUERY_INSERT) or util_die (db_error ());
               continue;
             }
           db_autoexecute ('cvs_hooks, cvs_hooks_log_accum',
@@ -151,7 +173,7 @@ if (isset ($log_accum))
             DB_AUTOQUERY_UPDATE,
             "cvs_hooks.id = cvs_hooks_log_accum.hook_id
             AND group_id = ? AND id = ?",
-            [$group_id, $hook_id]) or die (db_error ());
+            [$group_id, $hook_id]) or util_die (db_error ());
         } # foreach ($arr_id as $hook_id => $ignored)
   } # if (isset($log_accum))
 site_project_header (['group' => $group_id, 'context' => 'ahome']);
