@@ -1,11 +1,20 @@
 <?php
 # Display forum.
 #
-# Copyright (C) 1999-2000 The SourceForge Crew
-# Copyright (C) 2017, 2018, 2023 Ineiev
+# Copyright (C) 1999, 2000 The SourceForge Crew
+# Copyright (C) 2000-2006 Mathieu Roy
+# Copyright (C) 2014, 2016, 2017 Assaf Gordon
+# Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
+# Copyright (C) 2013, 2014, 2017-2023 Ineiev
 #
 # This file is part of Savane.
 #
+# Code written before 2008-03-30 (commit 8b757b2565ff) is distributed
+# under the terms of the GNU General Public license version 3 or (at your
+# option) any later version; further contributions are covered by
+# the GNU Affero General Public license version 3 or (at your option)
+# any later version.  The license notices for the AGPL and the GPL follow.
+#
 # Savane is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
 # published by the Free Software Foundation, either version 3 of the
@@ -18,6 +27,19 @@
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# Savane is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as
+# published by the Free Software Foundation, either version 3 of the
+# License, or (at your option) any later version.
+#
+# Savane is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 require_once ('../include/init.php');
 require_once ('../include/sane.php');
 require_once ('../include/form.php');
@@ -129,7 +151,7 @@ if ($forum_id)
       }
     # Now setup the query.
     $threading_sql = '';
-    if ($style == 'nested' || $style== 'threaded' )
+    if ($style == 'nested' || $style == 'threaded' )
       {
         # The flat and 'no comments' view just selects the most recent
         # messages out of the forum.
@@ -147,7 +169,7 @@ if ($forum_id)
         f.group_forum_id = ?  AND u.user_id = f.posted_by $threading_sql
         AND g.group_forum_id = f.group_forum_id
       ORDER BY f.date DESC LIMIT ?, ?",
-      [$forum_id, $offset, $max_rows + 1]
+      [$forum_id, intval ($offset), $max_rows + 1]
     );
     $rows = db_numrows ($result);
     if ($rows > $max_rows)
@@ -191,7 +213,7 @@ if ($forum_id)
         $ret_val .= "<table border='0' width='50%'>\n"
           . form_tag (['method' => 'get'])
           . form_hidden (
-              ['set' => 'custom', 'forum_id' => htmlspecialchars ($forum_id)]
+              ['set' => 'custom', 'forum_id' => utils_specialchars ($forum_id)]
             )
           . "\n<tr>\n<td><span class='smaller'>$options_popup</span></td>\n"
           . "<td><span class='smaller'>$max_row_popup</span></td>\n"
