@@ -1,13 +1,20 @@
 <?php
 # Forms and functions to manage accounts (including groups).
 #
-# Copyright (C) 1999-2000 The SourceForge Crew
-# Copyright (C) 2003-2006 Mathieu Roy <yeupou--gnu.org>
-# Copyright (C) 2007  Sylvain Beucler
-# Copyright (C) 2017-2019, 2021, 2022 Ineiev
+# Copyright (C) 1999, 2000 The SourceForge Crew
+# Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
+# Copyright (C) 2014, 2016, 2017 Assaf Gordon
+# Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
+# Copyright (C) 2013, 2014, 2017-2023 Ineiev
 #
 # This file is part of Savane.
 #
+# Code written before 2008-03-30 (commit 8b757b2565ff) is distributed
+# under the terms of the GNU General Public license version 3 or (at your
+# option) any later version; further contributions are covered by
+# the GNU Affero General Public license version 3 or (at your option)
+# any later version.  The license notices for the AGPL and the GPL follow.
+#
 # Savane is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
 # published by the Free Software Foundation, either version 3 of the
@@ -20,7 +27,21 @@
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# Savane is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as
+# published by the Free Software Foundation, either version 3 of the
+# License, or (at your option) any later version.
+#
+# Savane is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+require_once (dirname (__FILE__) . '/utils.php');
 require_once (dirname (__FILE__) . '/pwqcheck.php');
 
 # Return a string explaining current pwcheck requirements.
@@ -107,11 +128,10 @@ function account_password_help ()
     return $help;
   $pwqgen = exec ("pwqgen");
   # TRANSLATORS: the argument is an example of passphrase.
-  $help .= " " . sprintf (_("For instance: %s."), htmlspecialchars ($pwqgen));
+  $help .= " " . sprintf (_("For instance: %s."), utils_specialchars ($pwqgen));
   $help .= " <br />\n"
     . sprintf (
-        _("pwqcheck options are '%s':"),
-        htmlspecialchars ($pwqcheck_args)
+        _("pwqcheck options are '%s':"), utils_specialchars ($pwqcheck_args)
       );
   $help .= expand_pwqcheck_options ();
   return $help;
@@ -119,6 +139,28 @@ function account_password_help ()
 
 # Modified from
 # http://www.openwall.com/articles/PHP-Users-Passwords#enforcing-password-policy
+function account_pwcheck ($newpass, $oldpass, $user)
+{
+  # Some really trivial and obviously-insufficient password strength
+  # checks - we ought to use the pwqcheck(1) program instead.
+  # TRANSLATORS: this string in used in the context "Bad password (%s)".
+  if (strlen ($newpass) < 7)
+    return _('way too short');
+  if (
+    stristr ($oldpass, $newpass)
+    || (strlen ($oldpass) >= 4 && stristr ($newpass, $oldpass))
+  )
+    # TRANSLATORS: this string in used in the context "Bad password (%s)".
+    return _('based on the old one');
+  if (
+    stristr ($user, $newpass)
+    || (strlen ($user) >= 4 && stristr ($newpass, $user))
+  )
+    # TRANSLATORS: this string in used in the context "Bad password (%s)".
+    return _('based on the username');
+  return 0;
+}
+
 function account_pwvalid ($newpass, $oldpass = '', $user = '')
 {
   global $use_pwqcheck, $pwqcheck_args;
@@ -126,30 +168,14 @@ function account_pwvalid ($newpass, $oldpass = '', $user = '')
     $check = pwqcheck ($newpass, $oldpass, $user, '', $pwqcheck_args);
   else
     {
-      # Some really trivial and obviously-insufficient password strength
-      # checks - we ought to use the pwqcheck(1) program instead.
-      $check = 0;
-      # TRANSLATORS: this string in used in the context "Bad password (%s)".
-      if (strlen ($newpass) < 7)
-        $check = _('way too short');
-      elseif (
-        stristr ($oldpass, $newpass)
-        || (strlen ($oldpass) >= 4 && stristr ($newpass, $oldpass))
-      )
-        # TRANSLATORS: this string in used in the context "Bad password (%s)".
-        $check = _('based on the old one');
-      elseif (
-        stristr ($user, $newpass)
-        || (strlen ($user) >= 4 && stristr ($newpass, $user))
-      )
-        # TRANSLATORS: this string in used in the context "Bad password (%s)".
-        $check = _('based on the username');
+      $check = account_pwcheck ($newpass, $oldpass, $user);
+      # TRANSLATORS: the argument explains the reason why the password is bad.
+      if ($check !== 0)
+        $check = sprintf (_("Bad password (%s)"), $check);
     }
 
   if ($check === 0)
     return 1;
-  # TRANSLATORS: the argument explains the reason why the password is bad.
-  $check = sprintf (_("Bad password (%s)"), $check);
   fb ($check, 1);
   return 0;
 }
@@ -239,7 +265,7 @@ function account_namevalid ($name, $allow_dashes=0, $allow_underscores=1,
       return 0;
     }
 
-  $char_set = "${alphabet}0123456789$underscore$dash$dot";
+  $char_set = "{$alphabet}0123456789$underscore$dash$dot";
   # Must contain only allowed characters, depending on the arguments.
   if (strspn ($name, $char_set) != strlen ($name))
     {
@@ -499,14 +525,10 @@ function account_genunixpw ($plainpw)
 function account_encryptpw ($plainpw)
 {
   $salt = account_gensalt (16);
-  $pfx = '$6$';
   # rounds=5000 is the 2010 glibc default, possibly we'll upgrade in
   # the future, better have this explicit.
   # Cf. http://www.akkadia.org/drepper/sha-crypt.html
-  if (version_compare (PHP_VERSION, '5.3.2', '>='))
-    $ptx = '$6$rounds=5000$';
-  # The PHP version in Lenny 5.2.6 has troubles with the above
-  # (truncated hash at 9 chars).
+  $pfx = '$6$rounds=5000$';
   return crypt ($plainpw, "$pfx$salt");
 }
 
@@ -534,6 +556,10 @@ function account_shellselects ($current)
 
 function account_validpw ($stored_pw, $plain_pw)
 {
-  return (crypt ($plain_pw, $stored_pw) == $stored_pw);
+  if (empty ($stored_pw) || empty ($plain_pw))
+    return false;
+  if (strlen ($stored_pw) < 2) # Disabled account, for sure.
+    return false;
+  return crypt ($plain_pw, $stored_pw) == $stored_pw;
 }
 ?>
