@@ -1,13 +1,21 @@
 <?php
 # Compute context for given URL.
 #
-# Copyright (C) 2005-2006 Mathieu Roy <yeupou--gnu.org>
-# Copyright (C) 2007, 2008  Sylvain Beucler
-# Copyright (C) 2008  Aleix Conchillo Flaque
-# Copyright (C) 2017, 2023 Ineiev
+# Copyright (C) 1999, 2000 The SourceForge Crew
+# Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
+# Copyright (C) 2008 Aleix Conchillo Flaque
+# Copyright (C) 2014, 2016, 2017 Assaf Gordon
+# Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
+# Copyright (C) 2013, 2014, 2017-2023 Ineiev
 #
 # This file is part of Savane.
 #
+# Code written before 2008-03-30 (commit 8b757b2565ff) is distributed
+# under the terms of the GNU General Public license version 3 or (at your
+# option) any later version; further contributions are covered by
+# the GNU Affero General Public license version 3 or (at your option)
+# any later version.  The license notices for the AGPL and the GPL follow.
+#
 # Savane is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
 # published by the Free Software Foundation, either version 3 of the
@@ -20,6 +28,19 @@
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# Savane is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as
+# published by the Free Software Foundation, either version 3 of the
+# License, or (at your option) any later version.
+#
+# Savane is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 require_once (dirname (__FILE__) . '/group.php');
 
@@ -120,7 +141,7 @@ function context_guess_from_url ($page)
   foreach (['project', 'my', 'siteadmin'] as $f)
     if ($context == $f)
       {
-        $fnc = "context_guess_${f}_context";
+        $fnc = "context_guess_{$f}_context";
         $ret = $fnc ($page_basename, $func);
         if ($ret !== null)
           return [$context, $ret];
@@ -201,12 +222,6 @@ function context_project_context_title ()
   return _("Summary");
 }
 
-function context_userguide_context_title ()
-{
-  $GLOBALS['group_id'] = $GLOBALS['sys_group_id'];
-  return _("In Depth Guide");
-}
-
 function context_my_context_title ()
 {
   $titles = [ 'configure' => _("My Account Configuration"),
@@ -222,7 +237,7 @@ function context_my_context_title ()
 # (possibly including side effects).
 function context_cont_custom_title ()
 {
-  $titles = ['project', 'userguide', 'my'];
+  $titles = ['project', 'my'];
 
   if (!in_array (CONTEXT, $titles))
     return null;
@@ -237,7 +252,7 @@ function context_title ()
   $title = null;
   foreach (['list', 'conf', 'custom'] as $f)
     {
-      $func = "context_cont_${f}_title";
+      $func = "context_cont_{$f}_title";
       $title = $func ();
       if ($title !== null)
         break;
@@ -282,7 +297,7 @@ function context_cont_icon ()
 {
   $icon_list = [
     'admin' => ['siteadmin'], 'bug' => ['bugs'], 'support' => ['help'],
-    'man' => ['doc', 'userguide', 'cookbook'], 'search' => ['directory'],
+    'man' => ['doc', 'cookbook'], 'search' => ['directory'],
     'cvs' => ['cvs', 'arch', 'svn', 'git', 'hg', 'bzr'],
     'news' => ['forum', 'news', 'special'],
   ];
