@@ -1,16 +1,23 @@
 <?php
 # Database access wrappers, with quoting/escaping.
 #
-# Copyright (C) 1999-2000  The SourceForge Crew
-# Copyright (C) 2004-2005  Elfyn McBratney <elfyn--emcb.co.uk>
-# Copyright (C) 2004-2005  Mathieu Roy <yeupou--gnu.org>
-# Copyright (C) 2000-2006  John Lim (ADOdb)
-# Copyright (C) 2007  Cliss XXI (GCourrier)
-# Copyright (C) 2006, 2007  Sylvain Beucler
-# Copyright (C) 2017, 2019, 2020, 2022, 2023 Ineiev
+# Copyright (C) 1999, 2000 The SourceForge Crew
+# Copyright (C) 2004, 2005 Elfyn McBratney <elfyn--emcb.co.uk>
+# Copyright (C) 2000-2006 John Lim (ADOdb)
+# Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
+# Copyright (C) 2007 Cliss XXI (GCourrier)
+# Copyright (C) 2014, 2016, 2017 Assaf Gordon
+# Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
+# Copyright (C) 2013, 2014, 2017-2023 Ineiev
 #
 # This file is part of Savane.
 #
+# Code written before 2008-03-30 (commit 8b757b2565ff) is distributed
+# under the terms of the GNU General Public license version 3 or (at your
+# option) any later version; further contributions are covered by
+# the GNU Affero General Public license version 3 or (at your option)
+# any later version.  The license notices for the AGPL and the GPL follow.
+#
 # Savane is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
 # published by the Free Software Foundation, either version 3 of the
@@ -23,6 +30,19 @@
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# Savane is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as
+# published by the Free Software Foundation, either version 3 of the
+# License, or (at your option) any later version.
+#
+# Savane is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 define ('DB_AUTOQUERY_INSERT', 1);
 define ('DB_AUTOQUERY_UPDATE', 2);
@@ -117,8 +137,7 @@ function db_argval ($v)
 
 function db_query_report_string ($sql, $inputarr)
 {
-  return "Query is: <code>"
-    . htmlspecialchars ($sql) . "</code>, \$inputarr is <code>"
+  return "Query is: <code>$sql</code>, \$inputarr is <code>"
     . print_r ($inputarr, 1) . "</code>";
 }
 
@@ -168,8 +187,8 @@ function db_variable_binding ($sql, $inputarr = null)
   if ($ret !== null)
     return $ret;
   util_die (
-    "db_variable_binding: input array does not match query: <pre>"
-    . htmlspecialchars ($sql) . "<br />" . print_r ($inputarr, true)
+    "db_variable_binding: input array does not match query: <pre>$sql"
+    . "<br />" . print_r ($inputarr, true)
   );
 }
 
@@ -198,9 +217,7 @@ function db_autoexecute ($table, $dict, $mode = DB_AUTOQUERY_INSERT,
   foreach ($tables as $table)
     {
       if (!preg_match('/^[a-zA-Z_][a-zA-Z0-9_]+$/', $table))
-        util_die (
-          "db_autoexecute: invalid table name: " . htmlspecialchars($table)
-        );
+        util_die ("db_autoexecute: invalid table name: $table");
       if ($first)
         {
           $tables_string = "`$table`";
@@ -276,7 +293,7 @@ function db_execute ($sql, $inputarr = null, $multi_query = 0)
 
 function db_query_die ($qstring, $errors = null)
 {
-  $str = 'db_query: SQL query error in [' . htmlspecialchars ($qstring) . ']';
+  $str = "db_query: SQL query error in [$qstring]";
   if (empty ($errors))
     $str .= ' <i>' . db_error () . '</i>';
   else
@@ -423,6 +440,11 @@ function db_affected_rows ($qhandle)
   return mysqli_affected_rows ($GLOBALS['mysql_conn']);
 }
 
+function db_data_seek ($qhandle, $row = 0)
+{
+  return mysqli_data_seek ($qhandle, $row);
+}
+
 function db_fetch_array ($qhandle = 0)
 {
   if ($qhandle)
