@@ -1,12 +1,20 @@
 <?php
 # Various boxes.
 #
-# Copyright (C) 1999-2000 The SourceForge Crew
+# Copyright (C) 1999, 2000 The SourceForge Crew
 # Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
-# Copyright (C) 2017, 2020, 2023 Ineiev
+# Copyright (C) 2014, 2016, 2017 Assaf Gordon
+# Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
+# Copyright (C) 2013, 2014, 2017-2023 Ineiev
 #
 # This file is part of Savane.
 #
+# Code written before 2008-03-30 (commit 8b757b2565ff) is distributed
+# under the terms of the GNU General Public license version 3 or (at your
+# option) any later version; further contributions are covered by
+# the GNU Affero General Public license version 3 or (at your option)
+# any later version.  The license notices for the AGPL and the GPL follow.
+#
 # Savane is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
 # published by the Free Software Foundation, either version 3 of the
@@ -19,6 +27,19 @@
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# Savane is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as
+# published by the Free Software Foundation, either version 3 of the
+# License, or (at your option) any later version.
+#
+# Savane is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 function show_altrow ($i)
 {
@@ -113,13 +134,14 @@ function show_sitestats ()
   $result = db_query ("SELECT type_id, name FROM group_type ORDER BY name");
   while ($eachtype = db_fetch_array ($result))
     {
+      $n = stats_getprojects_bytype_active ($eachtype['type_id']);
+      if ($n < 1)
+        continue;
       $return .= show_altrow ($i++);
       $return .= "&nbsp;&nbsp;- <a href=\"{$sys_home}search/"
         . '?type_of_search=soft&amp;words=%%%&amp;type='
         . $eachtype['type_id'] . '" class="center">';
-      $return .= ' ' . gettext ($eachtype['name']) . ": ";
-      $return .= stats_getprojects_bytype_active ($eachtype['type_id']);
-      $return .= "</a></span></div>\n";
+      $return .= ' ' . gettext ($eachtype['name']) . ": $n</a></span></div>\n";
     }
   $pending = stats_getprojects_pending ();
   $return .= show_altrow ($i++) . '&nbsp;&nbsp;';
