@@ -1,11 +1,20 @@
 <?php
 # Form functions.
 #
-# Copyright (C) 2004-2006 Mathieu Roy <yeupou--gnu.org>
-# Copyright (C) 2017, 2022, 2023 Ineiev
+# Copyright (C) 1999, 2000 The SourceForge Crew
+# Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
+# Copyright (C) 2014, 2016, 2017 Assaf Gordon
+# Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
+# Copyright (C) 2013, 2014, 2017-2023 Ineiev
 #
 # This file is part of Savane.
 #
+# Code written before 2008-03-30 (commit 8b757b2565ff) is distributed
+# under the terms of the GNU General Public license version 3 or (at your
+# option) any later version; further contributions are covered by
+# the GNU Affero General Public license version 3 or (at your option)
+# any later version.  The license notices for the AGPL and the GPL follow.
+#
 # Savane is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
 # published by the Free Software Foundation, either version 3 of the
@@ -18,6 +27,19 @@
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# Savane is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as
+# published by the Free Software Foundation, either version 3 of the
+# License, or (at your option) any later version.
+#
+# Savane is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 $dir_name = dirname (__FILE__);
 require_once ("$dir_name/spam.php");
@@ -28,7 +50,9 @@ require_once ("$dir_name/spam.php");
 #    - form_clean must be used after succesful item submission
 
 # Start the form with unique ID, store it in the database.
-function form_header ($action, $form_id=false, $method="post", $extra=false)
+function form_header (
+  $action, $form_id = false, $method = "post", $extra = false
+)
 {
   if ($extra)
     $extra = " $extra";
@@ -36,20 +60,20 @@ function form_header ($action, $form_id=false, $method="post", $extra=false)
   # Keep previous form id, in case of form that are recreated on failure.
   if (!$form_id)
     {
-      mt_srand((double)microtime()*1000000);
-      $form_id=md5(mt_rand(0,1000000));
+      utils_srand ();
+      $form_id = md5 (mt_rand (0, 1000000));
     }
-  $result = db_autoexecute('form',
-    array('form_id' => $form_id,
-          'timestamp' => time(),
-          'user_id' => user_getid()),
-    DB_AUTOQUERY_INSERT);
-  if (db_affected_rows($result) != 1)
-    fb(_("System error while creating the form, report it to admins"), 1);
+  $result = db_autoexecute ('form',
+    [ 'form_id' => $form_id, 'timestamp' => time (),
+      'user_id' => user_getid ()],
+    DB_AUTOQUERY_INSERT
+  );
+  if (db_affected_rows ($result) != 1)
+    fb (_("System error while creating the form, report it to admins"), 1);
 
-  return '
-  <form action="'.htmlentities($action).'" method="'.$method.'"'.$extra.'>'
-       .form_input("hidden","form_id",$form_id);
+  return "\n<form action=\""
+    . utils_specialchars ($action) . "\" method=\"$method\"$extra>"
+    . form_hidden (["form_id" => $form_id]);
 }
 
 # Similar to form_header, but without generating new $form_id.
@@ -70,21 +94,46 @@ function form_tag ($args = [], $action_suffix = '')
 }
 
 # Usual input.
-function form_input ($type, $name, $value="", $extra=false)
+function form_input ($type, $name, $value = "", $extra = false)
 {
-  if ($value != "")
-    $value = 'value="'.htmlentities($value).'"';
+  if ($value !== "")
+    $value = 'value="' . utils_specialchars ($value) . '"';
   if ($extra)
     $extra = " $extra";
-  $id_attr = ' id="'.$name.'"';
+  $id_attr = " id=\"$name\"";
   if ($type == 'hidden' || $type == 'submit' || $type == 'radio')
     $id_attr = '';
-
   return "<input type=\"$type\"$id_attr name=\"$name\" $value$extra />";
 }
 
+function form_set_label_attr (&$attr)
+{
+  if (!array_key_exists ('label', $attr))
+    return null;
+  $ret = $attr['label'];
+  unset ($attr['label']);
+  return $ret;
+}
+
+function form_radio ($name, $value, $attr)
+{
+  $label = form_set_label_attr ($attr);
+  $extra = '';
+  if (!empty ($attr['checked']))
+    $extra .= "checked='checked' ";
+  if (empty ($attr['id']) && !$label)
+    $attr['id'] = "val_{$value}_$name";
+  if (!empty ($attr['id']))
+    $extra .= "id=\"{$attr['id']}\"";
+  $ret = form_input ('radio', $name, $value, $extra);
+  if (null === $label || empty ($attr['id']))
+    return $ret;
+  return $ret . html_label ($attr['id'], $label);
+}
+
 function form_checkbox ($name, $is_checked = 0, $attr = [])
 {
+  $label = form_set_label_attr ($attr);
   $extra = '';
   if ($is_checked)
     $extra .= ' checked="checked"';
@@ -94,7 +143,10 @@ function form_checkbox ($name, $is_checked = 0, $attr = [])
   $val = '1';
   if (isset ($attr['value']))
     $val = '';
-  return form_input ('checkbox', $name, $val, $extra);
+  $ret = form_input ('checkbox', $name, $val, $extra);
+  if (null === $label)
+    return $ret;
+  return $ret . html_label ($name, $label);
 }
 
 function form_option ($value, $selected_value = NULL, $label = NULL)
