@@ -1,12 +1,21 @@
 <?php /*-*-PHP-*-*/
 # Quick HTML_QuickForm clone without the GPL-incompatible license
 #
-# Copyright (C) 2007  Cliss XXI
-# Copyright (C) 2007  Sylvain Beucler
-# Copyright (C) 2017, 2018, 2022 Ineiev
+# Copyright (C) 1999, 2000 The SourceForge Crew
+# Copyright (C) 2000-2006 Mathieu Roy
+# Copyright (C) 2007 Cliss XXI
+# Copyright (C) 2014, 2016, 2017 Assaf Gordon
+# Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
+# Copyright (C) 2013, 2014, 2017-2023 Ineiev
 #
 # This file is part of Savane.
 #
+# Code written before 2008-03-30 (commit 8b757b2565ff) is distributed
+# under the terms of the GNU General Public license version 3 or (at your
+# option) any later version; further contributions are covered by
+# the GNU Affero General Public license version 3 or (at your option)
+# any later version.  The license notices for the AGPL and the GPL follow.
+#
 # Savane is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
 # published by the Free Software Foundation, either version 3 of the
@@ -19,6 +28,21 @@
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# Savane is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as
+# published by the Free Software Foundation, either version 3 of the
+# License, or (at your option) any later version.
+#
+# Savane is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+
+require_once (dirname (__FILE__) . '/utils.php');
 
 class GPLQuickForm_Element
 {
@@ -112,7 +136,7 @@ class GPLQuickForm_Element
       $title = $this->title;
     $label = '';
     if ($title)
-      $label = 'title="' . htmlspecialchars ($title, ENT_QUOTES) . '" ';
+      $label = 'title="' . utils_specialchars ($title) . '" ';
     return $label;
   }
 
@@ -148,10 +172,10 @@ class GPLQuickForm_Element
     print '<p>';
     print "<b><label $for_attr>{$this->title}</label></b>&nbsp;\n&nbsp;";
     if ($this->frozen)
-      print "$value<input type='hidden' $name_attr value='$esc_val' />\n";
+      print "$value<input type='hidden' $name_attr value=\"$esc_val\" />\n";
     else
       print "<input type='text' " . $this->title_attr ()
-        . "$name_attr value='$esc_val' />\n";
+        . "$name_attr value=\"$esc_val\" />\n";
     if (!empty ($this->error))
       print "&nbsp;&nbsp; <span class='error'>$this->error</span>";
     if (!$this->frozen && !empty ($this->label))
@@ -185,7 +209,7 @@ class GPLQuickForm_Element
         print "<input type='hidden' $name_attr value='$value' />";
         return;
       }
-    $esc_val = htmlspecialchars ($value, ENT_QUOTES);
+    $esc_val = utils_specialchars ($value);
     if ($this->type == 'checkbox')
       {
         $this->display_checkbox ($value);
@@ -206,7 +230,7 @@ class GPLQuickForm_Element
         if ($this->frozen)
           print "*****";
         else
-          print "<input type='password' $name_attr value='$esc_val' />\n";
+          print "<input type='password' $name_attr value=\"$esc_val\" />\n";
         break;
 
       case 'select':
@@ -218,7 +242,7 @@ class GPLQuickForm_Element
             print "<input type='hidden' $name_attr value='$value' />\n";
             break;
           }
-        print "<select $name_attr " . $this->title_attr ();
+        print "<select $name_attr " . $this->title_attr () . ">\n";
         foreach($this->select_options as $id => $text)
           {
             $selected = '';
@@ -429,25 +453,26 @@ class GPLQuickForm
                 $rule_is_valid = ($value == $value2);
                 break;
               default:
-                die("Unsupported rule type: $type");
+                util_die ("Unsupported rule type: $type");
               }
             if (!$rule_is_valid)
               {
                 $form_is_valid = false;
                 $elt_is_valid[$name] = false;
-                $elt->setError($error_message);
+                $elt->setError ($error_message);
               }
           }
       }
     return $form_is_valid;
   }
 
-  public function display()
+  public function display ()
   {
-    print "<form class='gpl-quick-form' id='$this->name' action='"
-      . htmlentities ($_SERVER['PHP_SELF']) . "' method='$this->method'>\n";
+    print "<form class='gpl-quick-form' id='{$this->name}' action=\""
+      . utils_specialchars ($_SERVER['PHP_SELF'])
+      . "\" method='{$this->method}'>\n";
     foreach ($this->elements as $element)
-      $element->display();
+      $element->display ();
     print "\n</form>\n";
   }
 }
