@@ -1,15 +1,22 @@
 <?php # -*- PHP -*-
 # Group info.
 #
-# Copyright (C) 1999-2000 The SourceForge Crew
-# Copyright (C) 2000-2003 Free Software Foundation
+# Copyright (C) 1999, 2000 The SourceForge Crew
+# Copyright (C) 2000-2006 Free Software Foundation, Inc.
 # Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
-# Copyright (C) 2007, 2008  Sylvain Beucler
-# Copyright (C) 2008  Aleix Conchillo Flaque
-# Copyright (C) 2017-2019, 2021, 2022 Ineiev
+# Copyright (C) 2008 Aleix Conchillo Flaque
+# Copyright (C) 2014, 2016, 2017 Assaf Gordon
+# Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
+# Copyright (C) 2013, 2014, 2017-2023 Ineiev
 #
 # This file is part of Savane.
 #
+# Code written before 2008-03-30 (commit 8b757b2565ff) is distributed
+# under the terms of the GNU General Public license version 3 or (at your
+# option) any later version; further contributions are covered by
+# the GNU Affero General Public license version 3 or (at your option)
+# any later version.  The license notices for the AGPL and the GPL follow.
+#
 # Savane is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
 # published by the Free Software Foundation, either version 3 of the
@@ -22,23 +29,50 @@
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# Savane is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as
+# published by the Free Software Foundation, either version 3 of the
+# License, or (at your option) any later version.
+#
+# Savane is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-require_once(dirname (__FILE__) . '/savane_error.php');
+require_once (dirname (__FILE__) . '/savane_error.php');
+require_once (dirname (__FILE__) . '/utils.php');
+
+define ('TRACKER_EVENT_NEW_ITEM', 1);
+define ('TRACKER_EVENT_COMMENT', 2);
+define ('TRACKER_FLAG_FACTOR', 100);
+define ('TRACKER_PERM_ANON', 2);
+define ('TRACKER_PERM_USER', 3);
+define ('TRACKER_PERM_MEMBER', 5);
+define ('TRACKER_PERM_NOBODY', 6);
 
 $PROJECT_OBJ = [];
 
-function project_get_object ($group_id)
+function group_get_object ($group_id)
 {
   # Create a common set of group objects,
   # save a little wear on the database.
 
   global $PROJECT_OBJ;
-  $idx = "_${group_id}_";
+  $idx = "_{$group_id}_";
   if (empty ($PROJECT_OBJ[$idx]))
     $PROJECT_OBJ[$idx] = new Group ($group_id);
   return $PROJECT_OBJ[$idx];
 }
 
+function project_get_object ($group_id)
+{
+  return group_get_object ($group_id);
+}
+
 class Group extends savane_error
 {
   var $data_array; # Data from db.
@@ -110,6 +144,11 @@ class Group extends savane_error
      return $this->type_data_array['devel_status_array'];
   }
 
+  function getTypeVirtualHost ()
+  {
+     return $this->type_data_array['mailing_list_virtual_host'];
+  }
+
   function getTypeUrl ($artifact)
   {
     return
@@ -163,12 +202,12 @@ class Group extends savane_error
 
   function getTypePermissions ($flags)
   {
-    return $this->get_flags ("${flags}_flags");
+    return $this->get_flags ("{$flags}_flags");
   }
 
   function getTypeRestrictions ($flags)
   {
-    return $this->get_flags ("${flags}_rflags");
+    return $this->get_flags ("{$flags}_rflags");
   }
 
   function getTypeMailingListHost ()
@@ -334,7 +373,7 @@ class Group extends savane_error
           continue;
         # TRANSLATORS: the first argument is the full name,
         # the second is the login.
-        $keyring .= sprintf(_("GPG keys of %s <%s>"), $name, $user);
+        $keyring .= sprintf (_("GPG keys of %s <%s>"), $name, $user);
         $keyring .= "\n$key\n";
       }
     return $keyring;
@@ -370,7 +409,7 @@ class Group extends savane_error
 
   function get_vcs_admin_url ($vcs)
   {
-    if ($vcs != 'cvs')
+    if (!in_array ($vcs, ['cvs', 'git']))
       return null;
     return preg_replace (',.*/,', '$0admin/', $this->getArtifactUrl ($vcs));
   }
@@ -528,88 +567,104 @@ function group_getid ($group_name)
   return null;
 }
 
-function group_getpermissions ($group_id, $flags)
+function group_trimmed_array ($res, $suff)
 {
-  if (!$flags)
-    return null;
-  if (!preg_match ('/^[a-z]+$/', $flags))
-    die ('group_getpermissions: unvalid argument flags');
-  $res =
-    db_execute ("
-      SELECT {$flags}_flags FROM groups_default_permissions
-      WHERE group_id = ?",
-      [$group_id]
-    );
-  if (db_numrows($res) > 0)
-    return db_result($res, 0, "${flags}_flags");
-  return null;
+  $a = db_fetch_array ($res);
+  $ret = []; $len = strlen ($suff);
+  foreach ($a as $k => $v)
+    {
+      if (is_int ($k))
+        continue;
+      $ret[substr ($k, 0, -$len)] = $v;
+    }
+  return $ret;
 }
 
-function group_getrestrictions ($group_id, $flags, $event = 1)
+function group_get_perm_flags ($group_id, $artifact, $prefix = '')
 {
-  # event = 1: posting new items.
-  # event = 2: posting followups.
-
-  # flag = (comment post restrictions)*100 + (newitem post restrictions)
-  #        with post restrictions = 2 ... allow post by ANONYMOUS
-  #                               = 3 ... allow post by LOGGED-IN
-  #                               = 5 ... allow post by MEMBERS
-  #                               = 6 ... allow post by NOBODY
-
-  if (!$flags)
+  if (empty ($artifact))
     return null;
-  $flag = null;
-  if (!preg_match ('/^[a-z]+$/', $flags))
-    die ('group_getrestrictions: unvalid argument flags');
-  $res = db_execute ("
-    SELECT {$flags}_rflags FROM groups_default_permissions
-    WHERE group_id = ?", [$group_id]);
-  if (db_numrows ($res) > 0)
-    $flag = db_result ($res, 0, "${flags}_rflags");
+  $art = $artifact;
+  if (is_scalar ($artifact))
+    $art = [$art];
+  $suff = "_{$prefix}flags";
+  foreach ($art as $a)
+    if (!preg_match ('/^[a-z]+$/', $a))
+      util_die ('group_getpermissions: unvalid argument artifact');
+  $fields = join ("$suff, ", $art) . $suff;
+  $res = db_execute (
+    "SELECT $fields FROM groups_default_permissions WHERE group_id = ?",
+    [$group_id]
+  );
+  if (!db_numrows ($res))
+    return null;
+  if (is_scalar ($artifact))
+    return db_result ($res, 0, "$artifact$suff");
+  return group_trimmed_array ($res, $suff);
+}
 
-  if ($event == 1)
-    {
-      # Trying to post a NEW item.
-      $flag = ($flag % 100);
-    }
-  if ($event == 2)
-    {
-      # Trying to post a COMMENT.
-      $flag = (int)($flag / 100);
-    }
+function group_getpermissions ($group_id, $artifact)
+{
+  return group_get_perm_flags ($group_id, $artifact);
+}
+
+function group_flag_value ($flag, $event)
+{
+  if ($flag === null)
+    return $flag;
+
+  if ($event == TRACKER_EVENT_NEW_ITEM)
+    $flag = $flag % TRACKER_FLAG_FACTOR;
+  if ($event == TRACKER_EVENT_COMMENT)
+    $flag = (int)($flag / TRACKER_FLAG_FACTOR);
   # We really want group restrictions here, not group type ones if missing.
   return $flag;
 }
 
-function group_getrestrictions_explained ($group_id, $artifact, $event = 1)
+function group_getrestrictions (
+  $group_id, $artifact, $event = TRACKER_EVENT_NEW_ITEM
+)
+{
+  $flag = group_get_perm_flags ($group_id, $artifact, 'r');
+  if ($flag === null)
+    return $flag;
+  $f = $flag;
+  if (is_scalar ($f))
+    $f = [$f];
+  $ret = [];
+  foreach ($f as $k => $v)
+    $ret[$k] = group_flag_value ($v, $event);
+  if (is_scalar ($flag))
+    return $ret[0];
+  return $ret;
+}
+
+function group_restriction_flag ($group_id, $artifact, $event)
 {
   $flag = group_getrestrictions ($group_id, $artifact, $event);
+  if ($flag)
+    return $flag;
+  if ($event == TRACKER_EVENT_COMMENT)
+    # No restriction defined for comment, check the restriction for new items.
+    $flag = group_getrestrictions ($group_id, $artifact);
+  if ($flag)
+    return $flag;
 
-  # If we are looking for item post restriction, Get group type default
-  # in case no flag was found.
-  # For comment post restriction we want the group restriction first.
-  if (!$flag)
+  # No restriction set for the group: use group type default.
+  return group_gettyperestrictions ($group_id, $artifact);
+}
+
+function group_getrestrictions_explained (
+  $group_id, $artifact, $event = TRACKER_EVENT_NEW_ITEM
+)
+{
+  switch (group_restriction_flag ($group_id, $artifact, $event))
     {
-      if ($event == 2)
-        {
-          # Post comment, fetching the restriction for post item.
-          $flag = group_getrestrictions ($group_id, $artifact, 1);
-        }
-
-      if ($event == 1 || !$flag)
-        {
-          # Post item or post comment with no group restriction to fallback on.
-          $flag = group_gettyperestrictions ($group_id, $artifact);
-        }
-    }
-
-  switch ($flag)
-    {
-    case '2':
+    case TRACKER_PERM_ANON:
       return _("It is possible to post anonymously on this tracker.");
-    case '5':
-      return _("Project Membership is required to post on this tracker.");
-    case '3':
+    case TRACKER_PERM_MEMBER:
+      return _("Group membership is required to post on this tracker.");
+    case TRACKER_PERM_USER:
       return _("Being logged-in is required to post on this tracker.");
     }
   return _("Posting on this tracker is disabled.");
@@ -627,45 +682,22 @@ function group_gettyperestrictions ($group_id, $flags)
   return $grp->getTypeRestrictions ($flags);
 }
 
-function group_restrictions_check ($group_id, $artifact, $event = 1)
+function group_restrictions_check (
+  $group_id, $artifact, $event = TRACKER_EVENT_NEW_ITEM
+)
 {
-  # No restriction for the logged in superuser
-  if (user_is_super_user ())
+  if (user_is_super_user ()) # No restriction for superusers.
     return true;
 
-  $flag = group_getrestrictions ($group_id, $artifact, $event);
-
-  # If we are looking for item post restriction, Get group type default
-  # in case no flag was found.
-  # For comment post restriction we want the group restriction first
-  if (!$flag)
-    {
-      if ($event == 2)
-        {
-          # Post comment, fetching the restriction for post item.
-          $flag = group_getrestrictions ($group_id, $artifact, 1);
-        }
-
-      if ($event == 1 || !$flag)
-        {
-          # Post item or post comment with no group restriction to fallback on.
-          $flag = group_gettyperestrictions ($group_id, $artifact);
-        }
-    }
-
-  # Anonymous required? Always OK.
-  if ($flag == '2')
-    return true;
-
-  # Logged in required? OK if logged in.
-  if ($flag == '3' && user_isloggedin ())
-    return true;
-
-  # Member required?
-  if ($flag == '5' && member_check (0, $group_id))
-    return true;
-
-  # $flag should be '6' here.
+  $check_functions = [
+    TRACKER_PERM_ANON => function ($group_id) { return true; },
+    TRACKER_PERM_USER => function ($group_id) { return user_isloggedin (); },
+    TRACKER_PERM_MEMBER => function ($gid) { return member_check (0, $gid); }
+  ];
+  $flag = group_restriction_flag ($group_id, $artifact, $event);
+  if (array_key_exists ($flag, $check_functions))
+    return $check_functions[$flag] ($group_id);
+  # $flag should be TRACKER_PERM_NOBODY here.
   return false;
 }
 
@@ -689,7 +721,7 @@ function group_add_history ($field_name, $old_value, $group_id)
    'group_history',
     [
       'group_id' => $group_id, 'field_name' => $field_name,
-      'old_value' => $old_value, 'mod_by' => user_getid (), 'date' => time()
+      'old_value' => $old_value, 'mod_by' => user_getid (), 'date' => time ()
     ],
     DB_AUTOQUERY_INSERT
   );
@@ -698,34 +730,22 @@ function group_add_history ($field_name, $old_value, $group_id)
 # Return the standard URL for an artifact.
 function group_get_artifact_url ($artifact, $hostname = 1)
 {
-  if ($artifact == "homepage")
-    return $GLOBALS['project']->getTypeUrl("homepage");
-  if ($artifact == "download")
-    return $GLOBALS['project']->getTypeUrl("download");
-  if ($artifact == "cvs_viewcvs")
-    return $GLOBALS['project']->getTypeUrl("cvs_viewcvs");
-  if ($artifact == "cvs_viewcvs_homepage")
-    return $GLOBALS['project']->getTypeUrl("cvs_viewcvs_homepage");
-  if ($artifact == "arch_viewcvs")
-    return $GLOBALS['project']->getTypeUrl("arch_viewcvs");
-  if ($artifact == "svn_viewcvs")
-    return $GLOBALS['project']->getTypeUrl("svn_viewcvs");
-  if ($artifact == "git_viewcvs")
-    return $GLOBALS['project']->getTypeUrl("git_viewcvs");
-  if ($artifact == "hg_viewcvs")
-    return $GLOBALS['project']->getTypeUrl("hg_viewcvs");
-  if ($artifact == "bzr_viewcvs")
-    return $GLOBALS['project']->getTypeUrl("bzr_viewcvs");
+  global $project, $sys_home;
+  $type_urls = [
+    "homepage", "download", "cvs_viewcvs", "cvs_viewcvs_homepage",
+    "arch_viewcvs", "svn_viewcvs", "git_viewcvs", "hg_viewcvs", "bzr_viewcvs"
+  ];
+  if (in_array ($artifact, $type_urls))
+    return $project->getTypeUrl ($artifact);
+
   if (!$hostname)
-    return "{$GLOBALS['sys_home']}$artifact/?group="
-      . $GLOBALS['project']->getUnixName ();
-  if ($GLOBALS['project']->getTypeBaseHost ())
-    $host = $GLOBALS['project']->getTypeBaseHost ();
+    return "{$sys_home}$artifact/?group=" . $project->getUnixName ();
+  if ($project->getTypeBaseHost ())
+    $host = $project->getTypeBaseHost ();
   else
     $host = $_SERVER['HTTP_HOST'];
 
-  return "http://$host{$GLOBALS['sys_home']}$artifact/?group="
-    . $GLOBALS['project']->getUnixName ();
+  return "http://$host{$sys_home}$artifact/?group=" . $project->getUnixName ();
 }
 
 # Normalize preference names before feeding it to SQL.
@@ -774,15 +794,13 @@ function group_get_preference ($group_id, $preference_names)
     );
   if (!is_array ($preference_names))
     {
-      if (db_numrows ($result) < 1)
-        return false;
-      return db_result ($result, 0, 'preference_value');
+      if (db_numrows ($result))
+        return db_result ($result, 0, 'preference_value');
+     return false;
     }
 
   while ($row = db_fetch_array ())
-    {
-      $val_arr[$row['preference_name']] = $row['preference_value'];
-    }
+    $val_arr[$row['preference_name']] = $row['preference_value'];
   return $val_arr;
 }
 
