@@ -1,15 +1,22 @@
 <?php
 # Common reusable HTML code.
 #
-# Copyright (C) 1999-2000 The SourceForge Crew
-# Copyright (C) 2002-2006 Mathieu Roy <yeupou--gnu.org>
+# Copyright (C) 1999, 2000 The SourceForge Crew
+# Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
 # Copyright (C) 2002-2006 Pogonyshev <pogonyshev--gmx.net>
-# Copyright (C) 2007, 2008  Sylvain Beucler
-# Copyright (C) 2008  Aleix Conchillo Flaque
-# Copyright (C) 2013, 2017, 2018, 2020, 2021, 2022, 2023 Ineiev
+# Copyright (C) 2008 Aleix Conchillo Flaque
+# Copyright (C) 2014, 2016, 2017 Assaf Gordon
+# Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
+# Copyright (C) 2013, 2014, 2017-2023 Ineiev
 #
 # This file is part of Savane.
 #
+# Code written before 2008-03-30 (commit 8b757b2565ff) is distributed
+# under the terms of the GNU General Public license version 3 or (at your
+# option) any later version; further contributions are covered by
+# the GNU Affero General Public license version 3 or (at your option)
+# any later version.  The license notices for the AGPL and the GPL follow.
+#
 # Savane is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
 # published by the Free Software Foundation, either version 3 of the
@@ -22,6 +29,19 @@
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# Savane is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as
+# published by the Free Software Foundation, either version 3 of the
+# License, or (at your option) any later version.
+#
+# Savane is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 $dir_name = dirname (__FILE__);
 require_once ("$dir_name/sane.php");
@@ -39,11 +59,12 @@ function html_show_displayoptions ($content, $form_opening=0, $submit=0)
   );
 }
 
-function html_show_boxoptions ($legend, $content, $form_opening=0, $submit=0)
+function html_show_boxoptions ($legend, $text, $form_opening = 0,
+  $submit = 0
+)
 {
-  $ret = "\n<fieldset id='options' class='boxoptions'>\n<legend>";
-
-  extract(sane_import('request', ['true' => 'boxoptionwanted']));
+  $ret = "\n";
+  extract (sane_import ('request', ['true' => 'boxoptionwanted']));
 
   if ($boxoptionwanted != 1)
     $boxoptionwanted = 0;
@@ -51,12 +72,12 @@ function html_show_boxoptions ($legend, $content, $form_opening=0, $submit=0)
     $boxoptionwanted = 1;
 
   $ret .= "\n<script type='text/javascript' src=\"/js/show-hide.php?"
-  . "deploy=$boxoptionwanted&amp;legend=" . urlencode ($legend)
-  . "&amp;box_id=boxoptions&amp;suffix=\"></script>";
+    . "deploy=$boxoptionwanted&amp;legend=" . utils_urlencode ($legend)
+    . "&amp;box_id=boxoptions&amp;suffix=\"></script>";
   $ret .= "\n<noscript>\n<span id='boxoptionslinkshow'>$legend</span>\n"
-    . "</noscript>\n</legend>\n";
+    . "</noscript>\n";
 
-  $ret .= "<span id='boxoptionscontent'>\n";
+  $ret .= "<div id='boxoptionscontent'>\n";
   if ($boxoptionwanted != 1)
     $ret .= "\n<script type=\"text/javascript\" "
       . "src=\"/js/hide-span.php?box_id=boxoptionscontent\"></script>\n";
@@ -66,14 +87,14 @@ function html_show_boxoptions ($legend, $content, $form_opening=0, $submit=0)
 
   # We add boxoptionwanted to be able to determine if a boxoption was used
   # to update the page, in which case the boxoption must appear deployed.
-  $ret .= "<span class='smaller'>$content"
+  $ret .= "$text"
      . form_input ("hidden", "boxoptionwanted", "1")
-     . '</span>';
+     . '</div>';
 
   if ($form_opening && $submit)
     $ret .= "\n</form>\n";
 
-  return "$ret\n</span>\n</fieldset>\n";
+  return "$ret\n";
 }
 
 # Function to create a an area in the page that can be hidden or shown
@@ -99,7 +120,7 @@ function html_hidsubpart_header ($uniqueid, $title, $deployed=false)
 
   $ret = "\n<h2 id=\"$uniqueid\">\n"
     . '<script type="text/javascript" src="/js/show-hide.php?'
-  . "deploy=$deployed&amp;legend=" . urlencode ($title)
+  . "deploy=$deployed&amp;legend=" . utils_urlencode ($title)
   . "&amp;box_id=hidsubpart&amp;suffix=$uniqueid\"></script>\n";
   $ret .= "\n<noscript>\n<a href=\"#$uniqueid\">$title</a>\n</noscript>"
     . "</h2>\n\n";
@@ -129,49 +150,55 @@ function html_splitpage ($how)
 function html_image_dir ($theme, $suffix = null)
 {
   global $sys_home;
-  $ret = "${sys_home}images$theme.theme/";
+  $ret = "{$sys_home}images$theme.theme/";
   if ($suffix)
     $ret .= "$suffix/";
   return $ret;
 }
 
+function html_nextprev_link ($search_url, $varprefix, $offset)
+{
+  global $max_rows;
+  print "<a href=\"$search_url&amp;{$varprefix}offset="
+    . "$offset&amp;{$varprefix}max_rows="
+    . utils_specialchars ($max_rows) . "#{$varprefix}results\">";
+}
+
 function html_nextprev ($search_url, $rows, $rows_returned, $varprefix = false)
 {
-  global $offset, $max_rows, $sys_home;
+  global $offset, $sys_home, $max_rows;
 
   if (!$varprefix)
     $varprefix = '';
   else
     $varprefix .= '_';
 
-  if (($rows_returned > $rows) || ($offset != 0))
+  if ($rows_returned < $rows && !$offset)
+    return;
+  $prev_msg = _("Previous Results");
+  $next_msg = _("Next Results");
+  print "\n<br /><p class=\"nextprev\">\n";
+
+  if ($offset)
     {
-      $prev_msg = _("Previous Results");
-      $next_msg = _("Next Results");
-      print "\n<br /><p class=\"nextprev\">\n";
-
-      if ($offset != 0)
-        {
-          print "<a href=\"$search_url&amp;${varprefix}offset="
-            . ($offset - $rows) . "&amp;${varprefix}max_rows="
-            . htmlspecialchars ($max_rows) . "#${varprefix}results\">";
-          print html_image ("arrows/previous.png") . " $prev_msg</a>";
-        }
-      else
-        print html_image ("arrows/previousgrey.png") . " <i>$prev_msg</i>";
-      print "&nbsp; &nbsp; &nbsp;";
-
-      if ($rows_returned > $rows)
-        {
-          print "<a href=\"$search_url&amp;${varprefix}offset="
-            . ($offset + $rows) . "&amp;${varprefix}max_rows="
-            . htmlspecialchars ($max_rows) . "#${varprefix}results\">";
-          print "$next_msg " . html_image ("arrows/next.png") . "</a>";
-        }
-      else
-        print "<i>$next_msg</i> " . html_image ("arrows/nextgrey.png");
-      print "</p>\n";
+      $prev_offset = $offset - $max_rows;
+      if ($prev_offset < 0)
+        $prev_offset = 0;
+      html_nextprev_link ($search_url, $varprefix, $prev_offset);
+      print html_image ("arrows/previous.png") . " $prev_msg</a>";
     }
+  else
+    print html_image ("arrows/previousgrey.png") . " <i>$prev_msg</i>";
+  print "&nbsp; &nbsp; &nbsp;";
+
+  if ($rows_returned > $rows)
+    {
+      html_nextprev_link ($search_url, $varprefix, $offset + $rows);
+      print "$next_msg " . html_image ("arrows/next.png") . "</a>";
+    }
+  else
+    print "<i>$next_msg</i> " . html_image ("arrows/nextgrey.png");
+  print "</p>\n";
 }
 
 function html_anchor ($content, $name)
@@ -181,6 +208,12 @@ function html_anchor ($content, $name)
   return "<a id=\"$name\" href=\"#$name\">$content</a>";
 }
 
+function html_format_feedback ($f)
+{
+  $f = preg_replace ('/\n*$/', '', $f);
+  return nl2br (markup_basic (utils_specialchars ($f)));
+}
+
 # Print out the feedback.
 function html_feedback ($bottom)
 {
@@ -198,8 +231,8 @@ function html_feedback ($bottom)
   if (!($ffeedback || $feedback))
     return;
 
-  $feedback = markup_basic (htmlspecialchars ($feedback));
-  $ffeedback = markup_basic (htmlspecialchars ($ffeedback));
+  $feedback = html_format_feedback ($feedback);
+  $ffeedback = html_format_feedback ($ffeedback);
 
   $suffix = '';
   if ($bottom)
@@ -307,6 +340,11 @@ function html_image_trash ($args)
   return html_image ('misc/trash.png', $args);
 }
 
+function html_label ($for, $title)
+{
+  return "<label for='$for'>$title</label>";
+}
+
 # Start a list table from an array of titles and builds.
 # The first row of a new table.
 #
@@ -589,13 +627,13 @@ function html_select_permission_box ($artifact, $row, $level = "member")
   else
     {
       $num = $row['user_id'];
-      $value = $row["${artifact}_flags"];
+      $value = $row["{$artifact}_flags"];
       $default = _("Group Default");
     }
 
   print "<td align=\"center\">\n"
     . '<select title="' . _("Roles of members")
-    . "\" name=\"${artifact}_user_$num\">\n";
+    . "\" name=\"{$artifact}_user_$num\">\n";
   if ($default)
     {
       $sel = ' selected="selected"';
@@ -656,7 +694,7 @@ function html_select_restriction_box (
     print "<td align='center'>\n";
 
   print '<select title="' . _("Permission level")
-    . "\" name=\"${artifact}_restrict_event$event\">\n";
+    . "\" name=\"{$artifact}_restrict_event$event\">\n";
 
   if ($default)
     {
@@ -666,7 +704,7 @@ function html_select_restriction_box (
       print "<option value='NULL'$sel>$default</option>\n";
     }
   $labels = [
-    [6, _("Nobody")], [5, _("Project Member")],  [3, _("Logged-in User")],
+    [6, _("Nobody")], [5, _("Group Member")],  [3, _("Logged-in User")],
     [2, _("Anonymous")],
   ];
   foreach ($labels as $vl)
@@ -893,7 +931,7 @@ function html_member_explain_roles ()
           . "and projects,\nchanging priority and status of items&mdash;but "
           . "they cannot configure the\ntrackers.");
   print "</p>\n<p>";
-  print _("Project Admins can manage members, configure the trackers, post\n"
+  print _("Group admins can manage members, configure the trackers, post\n"
           . "jobs, and add mailing lists. They actually also have manager "
           . "rights on every\ntracker and are allowed to read private items.");
   print "</p>\n";
