@@ -1,13 +1,22 @@
 <?php
 # Configure locale using browser preferences.
 #
-# Copyright (C) 2016 Karl Berry (disable languages)
-# Copyright (C) 2003-2006 Stéphane Urbanovski <s.urbanovski--ac-nancy-metz.fr>
-# Copyright (C) 2003-2006 Mathieu Roy <yeupou--gnu.org>
-# Copyright (C) 2017, 2018, 2019, 2020, 2023 Ineiev
+# Copyright (C) 1999, 2000 The SourceForge Crew
+# Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
+# Copyright (C) 2000-2006 Stéphane Urbanovski <s.urbanovski--ac-nancy-metz.fr>
+# Copyright (C) 2014, 2016, 2017 Assaf Gordon
+# Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
+# Copyright (C) 2008-2017, 2020 Karl Berry (disable languages)
+# Copyright (C) 2013, 2014, 2017-2023 Ineiev
 #
 # This file is part of Savane.
 #
+# Code written before 2008-03-30 (commit 8b757b2565ff) is distributed
+# under the terms of the GNU General Public license version 3 or (at your
+# option) any later version; further contributions are covered by
+# the GNU Affero General Public license version 3 or (at your option)
+# any later version.  The license notices for the AGPL and the GPL follow.
+#
 # Savane is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
 # published by the Free Software Foundation, either version 3 of the
@@ -20,8 +29,28 @@
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# Savane is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as
+# published by the Free Software Foundation, either version 3 of the
+# License, or (at your option) any later version.
+#
+# Savane is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 require_once (dirname (__FILE__) . '/utils.php');
+
+# Used for strings that specifically shouldn't be localized.
+function no_i18n ($x)
+{
+  return $x;
+}
+
 # Table of supported languages:
 # "language variant" => "associated preferred locale"
 $locale_list = [];
@@ -54,8 +83,6 @@ register_language ("fr", "fr_FR", "français");
 register_language ("it", "it_IT", "italiano");
 register_language ("ja", "ja_JP", "日本語");
 #register_language ("ja-jp", "ja_JP");
-register_language ("ko", "ko_KR", "한국어");
-#register_language ("ko-kr", "ko_KR");
 register_language ("he", "he_IL", "עברית");
 register_language ("pt", "pt_BR", "português do Brasil");
 register_language ("pt-br", "pt_BR");
@@ -123,11 +150,10 @@ function i18n_setup ($locale)
   global $sys_localedir;
   # The LANGUAGE variable would override our settings, so we unset it.
   putenv ("LANGUAGE=");
-
-  $sloc = setlocale (LC_ALL, $locale);
+  setlocale (LC_ALL, $locale);
   utils_update_decimal_separator ();
   if (!empty ($sys_localedir))
-    $res = bindtextdomain ('savane', $sys_localedir);
+    bindtextdomain ('savane', $sys_localedir);
   textdomain ('savane');
 }
 i18n_setup  ($locale);
