@@ -1,12 +1,20 @@
 <?php
 # Setup a minimal environment (database, configuration file...)
 #
-# Copyright (C) 1999-2000 The SourceForge Crew
-# Copyright (C) 2002-2006 Mathieu Roy <yeupou--gna.org>
-# Copyright (C) 2017, 2018, 2020, 2022, 2023 Ineiev
+# Copyright (C) 1999, 2000 The SourceForge Crew
+# Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
+# Copyright (C) 2014, 2016, 2017 Assaf Gordon
+# Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
+# Copyright (C) 2013, 2014, 2017-2023 Ineiev
 #
 # This file is part of Savane.
 #
+# Code written before 2008-03-30 (commit 8b757b2565ff) is distributed
+# under the terms of the GNU General Public license version 3 or (at your
+# option) any later version; further contributions are covered by
+# the GNU Affero General Public license version 3 or (at your option)
+# any later version.  The license notices for the AGPL and the GPL follow.
+#
 # Savane is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
 # published by the Free Software Foundation, either version 3 of the
@@ -19,9 +27,23 @@
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# Savane is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as
+# published by the Free Software Foundation, either version 3 of the
+# License, or (at your option) any later version.
+#
+# Savane is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 $file_dir = dirname (__FILE__);
 
+require_once ("$file_dir/error.php");
 # Autoconf-based:
 require_once ("$file_dir/ac_config.php");
 
@@ -98,6 +120,8 @@ $pwqcheck_args = 'match=0 max=256 min=24,24,11,8,7';
 # Default uploads directory for './register2/upload.html'.
 $sys_upload_dir = "/var/www/submissions_uploads" ;
 
+$sys_mailman_wrapper = "$bindir/sv_mailman-wrapper.pl";
+
 if (empty ($sys_linguas))
   $sys_linguas = "en:ru";
 
@@ -130,6 +154,13 @@ $sys_home = $GLOBALS['sys_url_topdir'];
 if (!preg_match ('|/$|', $GLOBALS['sys_url_topdir']))
   $sys_home = $GLOBALS['sys_url_topdir'] . '/';
 
+if (empty ($sys_savane_url))
+  $sys_savane_url = '//savannah.nongnu.org/projects/administration';
+
+if (empty ($sys_savane_cgit))
+  $sys_savane_cgit =
+    "//git.savannah.nongnu.org/cgit/administration/savane.git";
+
 # Defines the https url, if available -- no path is added since this
 # variable can be used with REQUEST_URI added. It's used when we need
 # to point a https URL (cannot be expressed using a http-relative
@@ -139,102 +170,13 @@ if (isset ($GLOBALS['sys_https_host']))
 else
   $sys_https_url = 'http://' . $GLOBALS['sys_default_domain'];
 
+$php_self = utils_specialchars ($_SERVER['PHP_SELF']);
+
 # Security issues apply even during fundrasing periods.  Please don't disable
 # this, make the banner work with the headers instead.
 utils_set_csp_headers ();
 utils_update_decimal_separator ();
 
-# Debug initialization.
-if ($sys_debug_on == true)
-  {
-    # Initialize the variable (avoid later warnings).
-    $GLOBALS['debug'] = '';
-    $GLOBALS['debug_query_count'] = 0;
-    $GLOBALS['debug_queries'] = [];
-
-    # Save the input arrays in case they are emptied
-    # (e.g. trackers_run/index.php).
-    $GLOBALS['INPUT_SAVE'] = [
-      'get' => $_GET, 'post' => $_POST,
-      'cookie' => $_COOKIE, 'files' => $_FILES
-    ];
-    function debug_dump ()
-    {
-      global $INPUT_SAVE;
-
-      print "<pre>\n<hr />\n";
-      print utils_size_readable (memory_get_usage (false)) . '/'
-        . utils_size_readable (memory_get_peak_usage (false))
-        . ' now/peak memory usage<br />';
-      print utils_size_readable (memory_get_usage (true))  . '/'
-        . utils_size_readable (memory_get_peak_usage (true))
-        . " now/peak real memory usage<br />\n<hr />\n";
-
-      # SQL query counter.
-      print "{$GLOBALS['debug_query_count']} database queries used:<br/>\n";
-      foreach ($GLOBALS['debug_queries'] as $query_data)
-        {
-          list ($query, $location) = $query_data;
-          print "$query [$location]<br />\n";
-        }
-      foreach (['GET', 'POST', 'COOKIE', 'FILES'] as $key)
-        {
-          print "<hr />\n$key:<br />\n";
-          print
-            htmlspecialchars (
-              print_r ($INPUT_SAVE[strtolower ($key)], true), ENT_QUOTES
-            );
-        }
-      print "<hr />\n";
-
-      # All debug messages.
-      if ($GLOBALS['debug'])
-        print "DEBUG information:<br />\n{$GLOBALS['debug']}";
-      print "</pre>\n";
-    }
-    register_shutdown_function ("debug_dump");
-
-    # Alternate PHP error handler that prints a backtrace.
-    function btErrorHandler ($errno, $errstr, $errfile, $errline, $context)
-    {
-      print '<strong>';
-      switch ($errno)
-        {
-        case E_ERROR:             print "Error";                  break;
-        case E_WARNING:           print "Warning";                break;
-        case E_PARSE:             print "Parse Error";            break;
-        case E_NOTICE:            print "Notice";                 break;
-        case E_CORE_ERROR:        print "Core Error";             break;
-        case E_CORE_WARNING:      print "Core Warning";           break;
-        case E_COMPILE_ERROR:     print "Compile Error";          break;
-        case E_COMPILE_WARNING:   print "Compile Warning";        break;
-        case E_USER_ERROR:        print "User Error";             break;
-        case E_USER_WARNING:      print "User Warning";           break;
-        case E_USER_NOTICE:       print "User Notice";            break;
-        case E_STRICT:            print "Strict Notice";          break;
-        case E_RECOVERABLE_ERROR: print "Recoverable Error";      break;
-        /* E_DEPRECATED - PHP >= 5.3 : */
-        case 8192:                return false; // too much noise
-        default:                  print "Unknown error ($errno)"; break;
-        }
-      print '</strong>';
-      print ": $errstr in <strong>$errfile</strong> on line "
-        . "<strong>$errline</strong><br />\n";
-      print '<pre>';
-
-      # Write my own backtrace function to avoid printing
-      # btErrorHandler () in the stack trace.
-      $bt = debug_backtrace ();
-      array_shift ($bt); # Remove this very function.
-      utils_debug_print_mybacktrace ($bt);
-      print '</pre>';
-      # Don't execute PHP internal error handler.
-      return true;
-    }
-  # Set to the user-defined error handler.
-  $old_error_handler = set_error_handler ("btErrorHandler");
-}
-
 # Stop a failed assertion.  We don't use much assertions though,
 # because you can't provide additional feedback for debugging (like
 # the value of the invalid variable). Check util_die () instead.
@@ -248,7 +190,7 @@ function require_directory ($module)
 {
   if ($module=="")
     return;
-  if (!empty ($GLOBALS["directory_${module}_is_loaded"]))
+  if (!empty ($GLOBALS["directory_{$module}_is_loaded"]))
     return;
 
   $dir = dirname (__FILE__) . "/$module";
@@ -266,7 +208,7 @@ function require_directory ($module)
         }
       closedir ($odir);
     }
-  $GLOBALS["directory_${module}_is_loaded"] = 1;
+  $GLOBALS["directory_{$module}_is_loaded"] = 1;
 }
 
 $tracker_list = ['bugs', 'patch', 'task', 'cookbook', 'support'];
@@ -370,7 +312,7 @@ if (!defined ('ARTIFACT'))
 # Necessary to determine group_id.
 if (
   in_array (ARTIFACT, $tracker_list) && !empty ($_SERVER['QUERY_STRING'])
-  && ctype_digit ($_SERVER['QUERY_STRING'])
+  && ctype_digit (strval ($_SERVER['QUERY_STRING']))
 )
   $item_id = $_SERVER['QUERY_STRING'];
 
@@ -407,7 +349,7 @@ if (
   # it actually belongs to the system group.
     if (ARTIFACT == 'cookbook'
         && $group_id == $sys_group_id && isset ($comingfrom)
-        && $comingfrom && ctype_digit ($comingfrom))
+        && $comingfrom && ctype_digit (strval ($comingfrom)))
       $group_id = $comingfrom;
   }
 
@@ -515,5 +457,4 @@ function init_check_group ()
 
 init_check_group ();
 unset ($group_row);
-$php_self = htmlentities ($_SERVER['PHP_SELF']);
 ?>
