@@ -1,12 +1,21 @@
 <?php
 # Markup functions.
 #
-# Copyright (C) 2005-2006 Tobias Toedter <t.toedter--gmx.net>
-# Copyright (C) 2005-2006 Mathieu Roy <yeupou--gnu.org>
-# Copyright (C) 2017, 2018, 2019, 2020, 2021, 2022, 2023 Ineiev
+# Copyright (C) 1999, 2000 The SourceForge Crew
+# Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
+# Copyright (C) 2002-2006 Tobias Toedter <t.toedter--gmx.net>
+# Copyright (C) 2014, 2016, 2017 Assaf Gordon
+# Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
+# Copyright (C) 2013, 2014, 2017-2023 Ineiev
 #
 # This file is part of Savane.
 #
+# Code written before 2008-03-30 (commit 8b757b2565ff) is distributed
+# under the terms of the GNU General Public license version 3 or (at your
+# option) any later version; further contributions are covered by
+# the GNU Affero General Public license version 3 or (at your option)
+# any later version.  The license notices for the AGPL and the GPL follow.
+#
 # Savane is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
 # published by the Free Software Foundation, either version 3 of the
@@ -19,7 +28,21 @@
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# Savane is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as
+# published by the Free Software Foundation, either version 3 of the
+# License, or (at your option) any later version.
+#
+# Savane is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+require_once (dirname (__FILE__) . '/utils.php');
 # Make sure the string has no newlines after translation.
 function markup_i18n ($str)
 {
@@ -422,7 +445,7 @@ function markup_heading_chunk ($ch)
 
 function markup_quote_chunk ($ch)
 {
-  $ch = nl2br (markup_inline_chunk ($ch));
+  $ch = markup_inline_chunk ($ch);
   return "<blockquote class='quote'><p>$ch</p></blockquote>\n";
 }
 
@@ -654,7 +677,7 @@ function markup_parse_list ($ch, &$stack, &$prev)
   if ($token === false)
     return array_merge (markup_close_lists ($stack, $prev), [$ch]);
   $c = substr ($next, -1, 1);
-  $item = ["${c}li", $matches[2]];
+  $item = ["{$c}li", $matches[2]];
   $ret = [$item];
   if ($token == 'end')
     return array_merge (markup_close_lists ($stack, $prev, $next), $ret);
@@ -663,7 +686,7 @@ function markup_parse_list ($ch, &$stack, &$prev)
   if ($token == 'start')
     array_unshift ($ret, ["$c-start"]);
   elseif ($pr == $next)
-    array_unshift ($ret, ["${c}li-end"]);
+    array_unshift ($ret, ["{$c}li-end"]);
   return $ret;
 }
 
@@ -725,6 +748,8 @@ function markup_mark_quoted ($chunks)
 # Parse markup and post-process it with the $build_chunk function.
 function markup_run_markup ($text, $allow_headings, $build_chunk)
 {
+  if ($text === null)
+    return "";
   $marked = markup_mark_nomarkup ([$text]);
   $marked = markup_mark_quoted ($marked);
   $marked = markup_mark_lists ($marked);
@@ -781,9 +806,8 @@ function markup_substitute_img_file_domain ($line)
   global $sys_file_domain;
   if ($GLOBALS['sys_default_domain'] == $sys_file_domain)
     return $line;
-  $http = session_issecure ()? 'https': 'http';
   return preg_replace (
-    '/<img src="\/file/', "<img src=\"$http://$sys_file_domain/file", $line
+    '/<img src="\/file/', "<img src=\"//$sys_file_domain/file", $line
   );
 }
 
@@ -811,8 +835,8 @@ function markup_expand_img ($line, $file_id, $file_name, $comment)
   if (substr ($alt, 0, 1) === ' ')
     $alt = substr ($alt, 1);
   if ($alt !== '')
-    $alt = 'alt="' . htmlspecialchars ($alt) . '" ';
-  $file_name = htmlspecialchars ($file_name);
+    $alt = 'alt="' . utils_specialchars ($alt) . '" ';
+  $file_name = utils_specialchars ($file_name);
   return preg_replace ("/\(?((files? ))#{$file_id}[^),]*((\)|, )?)/",
     "<img src=\"/file/$file_name?file_id=$file_id\" $alt/> ", $line
   );
@@ -910,6 +934,7 @@ function markup_convert_mail_links ($line, $protocols)
 function markup_expand_tracker_links ($line, $regexp, $link)
 {
   global $sys_home;
+  $line = markup_expand_img_files ($line);
   # Allow only two white spaces between the string and the numeric id
   # to avoid having too time consuming regexp. People just have to pay
   # attention.
@@ -1083,10 +1108,9 @@ function markup_inline_nomarkup ($line)
 
 function markup_inline_string ($line)
 {
-  if (strlen ($line) == 0)
+  if ($line === null || strlen ($line) == 0)
     return "";
 
-  $line = markup_expand_img_files ($line);
   $line = markup_expand_links ($line);
   $line = markup_substitute_asterized ($line);
   $line = markup_substitute_underscored ($line);
@@ -1111,6 +1135,6 @@ function markup_inline ($line)
 function markup_ascii ($text)
 {
   $text = markup_run_markup ($text, false, 'markup_build_ascii');
-  return htmlspecialchars_decode ($text, ENT_QUOTES);
+  return utils_specialchars_decode ($text, ENT_QUOTES);
 }
 ?>
