@@ -1,11 +1,20 @@
 <?php
 # Membership functions.
 #
-# Copyright (C) 2003-2006 Mathieu Roy <yeupou--gnu.org>
-# Copyright (C) 2017, 2022, 2023 Ineiev
+# Copyright (C) 1999, 2000 The SourceForge Crew
+# Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
+# Copyright (C) 2014, 2016, 2017 Assaf Gordon
+# Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
+# Copyright (C) 2013, 2014, 2017-2023 Ineiev
 #
 # This file is part of Savane.
 #
+# Code written before 2008-03-30 (commit 8b757b2565ff) is distributed
+# under the terms of the GNU General Public license version 3 or (at your
+# option) any later version; further contributions are covered by
+# the GNU Affero General Public license version 3 or (at your option)
+# any later version.  The license notices for the AGPL and the GPL follow.
+#
 # Savane is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
 # published by the Free Software Foundation, either version 3 of the
@@ -18,6 +27,19 @@
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# Savane is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as
+# published by the Free Software Foundation, either version 3 of the
+# License, or (at your option) any later version.
+#
+# Savane is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 require_once (dirname(__FILE__) . '/database.php');
 
@@ -88,16 +110,7 @@ function member_remove ($user_id, $group_id)
       return $result;
     }
   group_add_history ('Deleted Squad', user_getname ($user_id), $group_id);
-  # If it is a squad, it means that we also mark the user account as
-  # shutdowned.
-  db_execute ("
-    UPDATE user
-    SET realname = '-Deleted Squad-', status = 'S', user_name = ?
-    WHERE user_id = ?",
-    ["_$user_id", $user_id]
-  );
-  # We also  make sure no user is any longer associated
-  # to the squad.
+  db_execute ("DELETE FROM user WHERE user_id = ?", [$user_id]);
   db_execute (
     "DELETE FROM user_squad WHERE squad_id = ? AND group_id = ?",
     [$user_id, $group_id]
@@ -165,7 +178,7 @@ function member_array_getpermissions ($group_id, $flags, $user_ids)
       return $ret;
     }
   if (!preg_match ('/^[a-z]+$/', $flags))
-    die ('group_getpermissions: unvalid argument flags');
+    util_die ('group_getpermissions: unvalid argument flags');
   if (!count ($user_ids))
     return [];
   $flags .= '_flags';
