@@ -2,12 +2,21 @@
 # Show hidden or visible a list of items depending on user prefs.
 # Set prefs if a changed was asked.
 #
-# Copyright (C) 2001-2002 Laurent Julliard, CodeX Team, Xerox
-# Copyright (C) 2003-2006 Mathieu Roy <yeupou--gnu.org>
-# Copyright (C) 2017, 2020, 2023 Ineiev
+# Copyright (C) 1999, 2000 The SourceForge Crew
+# Copyright (C) 2001, 2002 Laurent Julliard, CodeX Team, Xerox
+# Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
+# Copyright (C) 2014, 2016, 2017 Assaf Gordon
+# Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
+# Copyright (C) 2013, 2014, 2017-2023 Ineiev
 #
 # This file is part of Savane.
 #
+# Code written before 2008-03-30 (commit 8b757b2565ff) is distributed
+# under the terms of the GNU General Public license version 3 or (at your
+# option) any later version; further contributions are covered by
+# the GNU Affero General Public license version 3 or (at your option)
+# any later version.  The license notices for the AGPL and the GPL follow.
+#
 # Savane is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
 # published by the Free Software Foundation, either version 3 of the
@@ -20,6 +29,20 @@
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# Savane is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as
+# published by the Free Software Foundation, either version 3 of the
+# License, or (at your option) any later version.
+#
+# Savane is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+require_once (dirname (__FILE__) . '/../utils.php');
 
 #  Function that generates hide/show urls to expand/collapse
 #  sections of the personal page.
@@ -153,8 +176,8 @@ function my_item_list_buildsql (
   global $item_data, $group_data, $sql_limit, $usergroups, $usergroups_groupid;
   global $items_per_groups, $usersquads;
 
-  if (!ctype_alnum ($tracker))
-    die (_("Invalid tracker name:") . " " . htmlspecialchars ($tracker));
+  if (!ctype_alnum (strval ($tracker)))
+    util_die (_("Invalid tracker name:") . " $tracker");
 
   # status: 1 = open, 3 = closed
   if ($openclosed == "open")
