@@ -1,12 +1,20 @@
 <?php
 # Forum functions.
 #
-# Copyright (C) 1999-2000 The SourceForge Crew
-# Copyright (C) 2004-2005 Mathieu Roy <yeupou--gnu.org>.
-# Copyright (C) 2017, 2018, 2022, 2023 Ineiev
+# Copyright (C) 1999, 2000 The SourceForge Crew
+# Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
+# Copyright (C) 2014, 2016, 2017 Assaf Gordon
+# Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
+# Copyright (C) 2013, 2014, 2017-2023 Ineiev
 #
 # This file is part of Savane.
 #
+# Code written before 2008-03-30 (commit 8b757b2565ff) is distributed
+# under the terms of the GNU General Public license version 3 or (at your
+# option) any later version; further contributions are covered by
+# the GNU Affero General Public license version 3 or (at your option)
+# any later version.  The license notices for the AGPL and the GPL follow.
+#
 # Savane is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
 # published by the Free Software Foundation, either version 3 of the
@@ -19,6 +27,19 @@
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# Savane is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as
+# published by the Free Software Foundation, either version 3 of the
+# License, or (at your option) any later version.
+#
+# Savane is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 # Accepts a database result handle to display a single message
 # in the format appropriate for the nested messages
@@ -134,7 +155,7 @@ function forum_header ($params)
 
   print "\n<div class='indexright'>\n";
   print $HTML->box_top (_("Latest News"));
-  print news_show_latest (db_result ($result, 0, 'group_id'), 5, "false");
+  print news_show_latest (db_result ($result, 0, 'group_id'), 5, false);
   print $HTML->box_bottom ();
   print "</div>\n<div class='indexcenter'>\n";
   print "<h2><a href='forum.php?forum_id=$forum_id'>"
@@ -169,23 +190,11 @@ function forum_create_forum (
 {
   global $feedback;
   $fields = [
-    'group_id' => $group_id, 'forum_name' => $forum_name,
+    'group_id' => $group_id, 'forum_name' => utils_specialchars ($forum_name),
     'is_public' => $is_public,
-    'description' => htmlspecialchars ($description)
+    'description' => utils_specialchars ($description)
   ];
-
-  $result = db_autoexecute ('forum_group_list',
-    [ 'group_id' => $group_id, 'forum_name' => htmlspecialchars ($forum_name),
-      'is_public' => $is_public,
-      'description' => htmlspecialchars ($description)
-    ],
-    DB_AUTOQUERY_INSERT
-  );
-
-  if (!$result)
-    " Error Adding Forum ";
-  else
-    " Forum Added ";
+  $result = db_autoexecute ('forum_group_list', $fields, DB_AUTOQUERY_INSERT);
   $forum_id = db_insertid ($result);
 
   if ($create_default_message)
