@@ -1,16 +1,24 @@
 <?php
 # Page-specific menu (Bugs/Tasks/Admin/Source Code/...)
 #
-# Copyright (C) 1999-2000 The SourceForge Crew (was in layout.php)
-# Copyright (C) 2003-2006 Mathieu Roy <yeupou--gnu.org>
-# Copyright (C) 2003-2006 Yves Perrin <yves.perrin--cern.ch>
-# Copyright (C) 2007, 2008  Sylvain Beucler
-# Copyright (C) 2008  Aleix Conchillo Flaque
-# Copyright (C) 2015, 2016 Karl Berry (tiny reordering, downcasing, #devtools)
-# Copyright (C) 2017, 2021, 2023 Ineiev
+# Copyright (C) 1999, 2000 The SourceForge Crew (was in layout.php)
+# Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
+# Copyright (C) 2002-2006 Yves Perrin <yves.perrin--cern.ch>
+# Copyright (C) 2008 Aleix Conchillo Flaque
+# Copyright (C) 2014, 2016, 2017 Assaf Gordon
+# Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
+# Copyright (C) 2008-2017, 2020 Karl Berry (tiny reordering, downcasing,
+#   #devtools)
+# Copyright (C) 2013, 2014, 2017-2023 Ineiev
 #
 # This file is part of Savane.
 #
+# Code written before 2008-03-30 (commit 8b757b2565ff) is distributed
+# under the terms of the GNU General Public license version 3 or (at your
+# option) any later version; further contributions are covered by
+# the GNU Affero General Public license version 3 or (at your option)
+# any later version.  The license notices for the AGPL and the GPL follow.
+#
 # Savane is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
 # published by the Free Software Foundation, either version 3 of the
@@ -23,12 +31,27 @@
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# Savane is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as
+# published by the Free Software Foundation, either version 3 of the
+# License, or (at your option) any later version.
+#
+# Savane is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 # Note about submenus: they should always contain a verb, enlightening the
 # action they permit to do.
 # The related pages the submenus point to should have title that are the
 # same as the submenu, or almost.
 
+require_once (dirname (__FILE__) . "/vcs.php");
+
 # Menu specific to the current page: group if group page, my if my pages etc.
 function pagemenu ($params)
 {
@@ -131,6 +154,11 @@ function pagemenu ($params)
     . "<div id='topmenunooverlapbis'>&nbsp;</div>\n";
 }
 
+function pagemenu_submenu_class ()
+{
+  return 'topmenuitemmainitem';
+}
+
 # Column title.
 function pagemenu_submenu_title (
   $title, $url, $selected = 0, $available = 1, $help = ''
@@ -147,16 +175,23 @@ function pagemenu_submenu_title (
   if  (!empty ($stone_age_menu))
     list ($stone_age_menu_lastcontext, $ign) = context_guess_from_url ($url);
 
+  $li_class = pagemenu_submenu_class ();
   # We make appear the submenu with both CSS and JavaScript.  That is because
   # some browsers (MSIE) have poor CSS support and cannot do it otherwise.
   # (When it gains focus, the submenu appears.)
-  print "  <li class='topmenuitemmainitem'>\n    "
-    . utils_link ($url, $title, $class, $available, $help);
+  if (empty ($url))
+    {
+      $ret = "$title\n";
+      $li_class .= " sublist";
+    }
+  else
+    $ret = utils_link ($url, $title, $class, $available, $help);
+  return "  <li class='$li_class'>\n$ret";
 }
 
 function pagemenu_submenu_end ()
 {
-  print "  </li><!-- end topmenuitemmainitem -->\n\n";
+  return "  </li><!-- end " . pagemenu_submenu_class () . " -->\n\n";
 }
 
 function pagemenu_submenu_body ($txt)
@@ -176,7 +211,7 @@ function pagemenu_submenu_body ($txt)
         $stone_age_submenu = $txt;
       return;
     }
-  print "<ul id='submenu{$submenucount}' "
+  return "<ul id='submenu{$submenucount}' "
     . "class='topmenuitemsubmenu'>$txt\n</ul><!-- end submenu -->\n";
 }
 
@@ -185,10 +220,12 @@ function pagemenu_submenu_entry ($title, $url, $available = 1, $help = "")
   $class = "topmenuitemsubmenu";
 
   if ($GLOBALS['stone_age_menu'])
-    $class = "topmenuitemmainitem";
-  return "<li class=\"$class\">"
-    . utils_link ($url, $title, '', $available, $help)
-    . "</li>\n";
+    $class = pagemenu_submenu_class ();
+  if (empty ($url))
+    $ret = $title;
+  else
+    $ret = utils_link ($url, $title, '', $available, $help);
+  return "<li class=\"$class\">$ret</li>\n";
 }
 
 function pagemenu_submenu_entry_separator ()
@@ -224,8 +261,9 @@ function pagemenu_my ()
 
   foreach ($titles as $t)
     {
-      pagemenu_submenu_title ($t[0], $t[1], SUBCONTEXT == $t[2], 1, $t[3]);
-      pagemenu_submenu_end ();
+      print pagemenu_submenu_title ($t[0], $t[1],
+        SUBCONTEXT == $t[2], 1, $t[3]);
+      print pagemenu_submenu_end ();
     }
 }
 
@@ -234,13 +272,13 @@ function pagemenu_tracker_submenu ($project, $tracker, $title, $help)
   if (!$project->Uses ($tracker))
     return;
 
-  pagemenu_submenu_title ($title, $project->getArtifactUrl ($tracker),
+  print pagemenu_submenu_title ($title, $project->getArtifactUrl ($tracker),
     CONTEXT == $tracker, 1, $help);
 
   # Only add submenu list when the URL wasn't customized.
   if ($project->url_is_default ($tracker))
-    pagemenu_submenu_body (pagemenu_group_trackers ($tracker));
-  pagemenu_submenu_end ();
+    print pagemenu_submenu_body (pagemenu_group_trackers ($tracker));
+  print pagemenu_submenu_end ();
 }
 
 # Submenu for group admins.
@@ -296,12 +334,22 @@ function pagemenu_vcs_use_entry ($group, $vcs, $vcs_name)
 
 function pagemenu_vcs_browse_entry ($group, $vcs, $name)
 {
+  $group_id = $group->getGroupId ();
   $a_idx = $vcs . '_viewcvs';
   if (!($group->Uses ($vcs) && pagemenu_url_is_set ($group, $a_idx)))
-  return '';
-  return pagemenu_submenu_entry (
-    _("Browse Sources Repository"), $group->getUrl ($a_idx)
-  );
+    return '';
+  $repos = vcs_get_repos ($vcs, $group_id);
+  $n = count ($repos);
+  $scm_url = $group->getUrl ($a_idx);
+  if ($n < 2)
+    {
+      $title = sprintf (_("Browse %s repository"), $name);
+      return pagemenu_submenu_entry ($title, $scm_url);
+    }
+  $title = sprintf (_("Browse %s repositories"), $name);
+  $ret = pagemenu_submenu_entry ("<span>$title</span>", null);
+  $ret .= "\n" . vcs_compile_repo_ul ($repos, $scm_url) . "\n";
+  return $ret;
 }
 
 function pagemenu_vcs_web_browse_url ($group, $vcs)
@@ -354,7 +402,7 @@ function pagemenu_vcs_append_entry ($func, $group, $vcs, $name, &$count)
 function pagemenu_vcs_entry ($group, &$count, $vcs, $name)
 {
   $ret = '';
-  foreach (['admin', 'use', 'browse', 'web_browse'] as $f)
+  foreach (['use', 'admin', 'browse', 'web_browse'] as $f)
     {
       $func = "pagemenu_vcs_{$f}_entry";
       $ret .= pagemenu_vcs_append_entry ($func, $group, $vcs, $name, $count);
@@ -367,13 +415,6 @@ function pagemenu_group ()
 {
   global $group_id, $sys_group_id, $project, $sys_home, $sys_name;
   $url = $sys_home . 'project';
-
-  if (CONTEXT == 'userguide')
-    {
-      $group_id = $sys_group_id;
-      $GLOBALS['group_name'] = $GLOBALS['sys_unix_group_name'];
-    }
-
   $is_admin = member_check (0, $group_id, 'A');
 
   $project = project_get_object ($group_id);
@@ -382,10 +423,10 @@ function pagemenu_group ()
   $unix_name = $project->getUnixName ();
   $uname = "{$url}s/$unix_name/";
   $gr_n = "?group=$unix_name";
-  pagemenu_submenu_title (_("Main"), $uname,
+  print pagemenu_submenu_title (_("Main"), $uname,
     CONTEXT == 'project', 1,
     # TRANSLATORS: the argument is site name like Savannah.
-    sprintf(_("Project Main Page at %s"), $sys_name)
+    sprintf (_("Project Main Page at %s"), $sys_name)
   );
   $ret = pagemenu_submenu_entry (_("Main"), $uname)
     . pagemenu_submenu_entry (_("View members"), "$url/memberlist.php$gr_n")
@@ -393,24 +434,25 @@ function pagemenu_group ()
 
   if ($is_admin)
     $ret .= pagemenu_group_admin ($url, $gr_n);
-  pagemenu_submenu_body ($ret);
-  pagemenu_submenu_end ();
+  print pagemenu_submenu_body ($ret);
+  print pagemenu_submenu_end ();
 
   if (pagemenu_test_url ($project, "homepage"))
     {
-      pagemenu_submenu_title( _("Homepage"), $project->getUrl("homepage"),
+      print pagemenu_submenu_title ( _("Homepage"),
+        $project->getUrl("homepage"),
         0, 1, _("Browse project homepage (outside of Savane)")
       );
-      pagemenu_submenu_end ();
+      print pagemenu_submenu_end ();
     }
 
   if ($project->Uses ("download"))
     {
-      pagemenu_submenu_title (_("Download"),
+      print pagemenu_submenu_title (_("Download"),
         $project->getArtifactUrl ("files"), CONTEXT == 'download', 1,
         _("Visit download area: files released")
       );
-      pagemenu_submenu_end ();
+      print pagemenu_submenu_end ();
     }
 
   # The cookbook is the default and cannot be deactivated as it contains
@@ -425,11 +467,11 @@ function pagemenu_group ()
 
   if ($project->getUrl ("extralink_documentation"))
     {
-      pagemenu_submenu_title (_("Docs"), $u, CONTEXT == 'cookbook', 1,
+      print pagemenu_submenu_title (_("Docs"), $u, CONTEXT == 'cookbook', 1,
         _("Docs: Cookbook, etc")
       );
-      pagemenu_submenu_body (pagemenu_group_trackers ("cookbook"));
-      pagemenu_submenu_end ();
+      print pagemenu_submenu_body (pagemenu_group_trackers ("cookbook"));
+      print pagemenu_submenu_end ();
     }
 
 
@@ -441,7 +483,7 @@ function pagemenu_group ()
 
   if ($project->Uses ('mail'))
     {
-      pagemenu_submenu_title ( _("Mailing lists"),
+      print pagemenu_submenu_title ( _("Mailing lists"),
         $project->getArtifactUrl ("mail"), CONTEXT == 'mail', 1,
         _("List existing mailing lists")
       );
@@ -457,9 +499,9 @@ function pagemenu_group ()
                 '<strong>' . _("Configure:") . '</strong>',
                 "$u/admin/$gr_n"
               );
-          pagemenu_submenu_body ($ret);
+          print pagemenu_submenu_body ($ret);
         }
-      pagemenu_submenu_end ();
+      print pagemenu_submenu_end ();
     }
 
   $count = 0;
@@ -483,26 +525,28 @@ function pagemenu_group ()
     {
       if ($count == 1)
         # Only one SCM - direct link.
-        pagemenu_submenu_title (_("Source code"),
+        print pagemenu_submenu_title (_("Source code"),
           $project->getArtifactUrl ($last_vcs), CONTEXT == $last_vcs, 1,
           _("Source code management")
         );
       else
-        pagemenu_submenu_title (_("Source code"), "$uname#devtools",
+        print pagemenu_submenu_title (_("Source code"), "$uname#devtools",
           isset ($vcses[CONTEXT]), 1, _("Source code management")
         );
 
-      $ret = '';
+      $ret = [];
       $count = 0;
 
       foreach ($vcses as $v => $t)
         if ($have_vcs[$v])
-          $ret .= pagemenu_vcs_entry ($project, $count, $v, $t);
+          $ret[] = pagemenu_vcs_entry ($project, $count, $v, $t);
 
       # Add a submenu only if there is more than one item.
       if ($ret && $count > 1)
-        pagemenu_submenu_body ($ret);
-      pagemenu_submenu_end ();
+        print pagemenu_submenu_body (
+          join (pagemenu_submenu_entry_separator (), $ret)
+        );
+      print pagemenu_submenu_end ();
     } # if ($count)
 
   pagemenu_tracker_submenu ($project, "bugs", _("Bugs"),
@@ -517,7 +561,7 @@ function pagemenu_group ()
   if (!$project->Uses ("news"))
     return;
   $news = $sys_home . 'news';
-  pagemenu_submenu_title (_("News"), "$news/$gr_n", CONTEXT == 'news', 1,
+  print pagemenu_submenu_title (_("News"), "$news/$gr_n", CONTEXT == 'news', 1,
     _("Read latest News, post News")
   );
   $ret = pagemenu_submenu_entry (_("Browse"), "$news/$gr_n");
@@ -536,8 +580,8 @@ function pagemenu_group ()
             1, _("News Manager: edit notifications")
           );
     }
-  pagemenu_submenu_body ($ret);
-  pagemenu_submenu_end ();
+  print pagemenu_submenu_body ($ret);
+  print pagemenu_submenu_end ();
 }
 
 # Menu specific to tracker pages.
@@ -636,7 +680,7 @@ function pagemenu_group_trackers ($tracker)
       if ($group_id == $sys_group_id)
         $ret .= pagemenu_submenu_entry_separator ()
           . pagemenu_submenu_entry (
-              _("Savane In Depth Guide"), "{$sys_home}userguide/"
+              _("Savane In Depth Guide"), "{$sys_home}maintenance/back-page/"
             );
     } # ($tracker == "cookbook")
 
@@ -684,20 +728,21 @@ function pagemenu_siteadmin ()
 {
   global $sys_home, $group_name, $sys_unix_group_name;
   $root = $sys_home . "siteadmin";
-  pagemenu_submenu_title ("Configuration", "root/?func=configure",
+  print pagemenu_submenu_title ("Configuration", "$root/?func=configure",
     SUBCONTEXT == 'configure'
   );
   $titles = [
-    "$root/retestconfig.php" => "Test System Configuration",
-    "$root/group_type.php" => "Configure Group Types",
-    "{$sys_home}people/admin/" => "Configure People Area"];
+    "$root/retestconfig.php" => "Test system configuration",
+    "$root/group_type.php" => "Configure group types",
+    "{$sys_home}people/admin/" => "Configure people area",
+    "$root/mailman.php" => "Assign mailing lists"];
   $txt = "";
   foreach ($titles as $u => $t)
     $txt .= pagemenu_submenu_entry ($t, $u);
-  pagemenu_submenu_body ($txt);
-  pagemenu_submenu_end ();
+  print pagemenu_submenu_body ($txt);
+  print pagemenu_submenu_end ();
 
-  pagemenu_submenu_title ("Management", "$root/?func=manage",
+  print pagemenu_submenu_title ("Management", "$root/?func=manage",
     SUBCONTEXT == 'manage'
   );
   # If the current page shows a group edition page, add extra links.
@@ -720,7 +765,7 @@ function pagemenu_siteadmin ()
     }
   $uname = "?group=$sys_unix_group_name";
   $txt =
-    pagemenu_submenu_entry ("Pending project registrations",
+    pagemenu_submenu_entry ("Pending registrations",
       "{$sys_home}task/$uname&amp;category_id=1"
       . "&amp;status_id=1&amp;go_report=Apply"
     )
@@ -730,9 +775,9 @@ function pagemenu_siteadmin ()
     . pagemenu_submenu_entry_separator ()
     . pagemenu_submenu_entry ("Group list", "$root/grouplist.php")
     . pagemenu_submenu_entry ("User list", "$root/userlist.php");
-  pagemenu_submenu_body ("$txt$extralinks");
-  pagemenu_submenu_end ();
-  pagemenu_submenu_title ("Monitoring", "$root/?func=monitor",
+  print pagemenu_submenu_body ("$txt$extralinks");
+  print pagemenu_submenu_end ();
+  print pagemenu_submenu_title ("Monitoring", "$root/?func=monitor",
     SUBCONTEXT == 'monitor'
   );
   $txt = pagemenu_submenu_entry ("Monitor spam", "$root/spamlist.php")
@@ -740,7 +785,7 @@ function pagemenu_siteadmin ()
     . pagemenu_submenu_entry ("Anonymous posts",
         "$root/usergroup.php?user_id=100"
       );
-  pagemenu_submenu_body ($txt);
-  pagemenu_submenu_end ();
+  print pagemenu_submenu_body ($txt);
+  print pagemenu_submenu_end ();
 }
 ?>
