@@ -1,12 +1,20 @@
 <?php
 # Functions for the people module.
 #
-# Copyright (C) 1999-2000 The SourceForge Crew
-# Copyright (C) 2004 Mathieu Roy <yeupou--gnu.org>
-# Copyright (C) 2013, 2017, 2018, 2022, 2023 Ineiev <ineiev--gnu.org>
+# Copyright (C) 1999, 2000 The SourceForge Crew
+# Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
+# Copyright (C) 2014, 2016, 2017 Assaf Gordon
+# Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
+# Copyright (C) 2013, 2014, 2017-2023 Ineiev <ineiev@gnu.org>
 #
 # This file is part of Savane.
 #
+# Code written before 2008-03-30 (commit 8b757b2565ff) is distributed
+# under the terms of the GNU General Public license version 3 or (at your
+# option) any later version; further contributions are covered by
+# the GNU Affero General Public license version 3 or (at your option)
+# any later version.  The license notices for the AGPL and the GPL follow.
+#
 # Savane is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
 # published by the Free Software Foundation, either version 3 of the
@@ -19,6 +27,19 @@
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# Savane is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as
+# published by the Free Software Foundation, either version 3 of the
+# License, or (at your option) any later version.
+#
+# Savane is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 function people_get_type_name ($type_id)
 {
@@ -597,42 +618,45 @@ function people_add_to_skill_inventory (
   print db_error ();
 }
 
+function people_print_skill_table ($result)
+{
+  print html_build_list_table_top ([_("Skill"), _("Level"), _("Experience")]);
+  $i = 0;
+  while ($row = db_fetch_array ($result))
+    {
+      foreach (['skill_name', 'level_name', 'year_name'] as $v)
+         $$v = gettext ($row[$v]);
+      print "<tr class=\"" . utils_altrow ($i++) . "\">\n"
+        . "<td>$skill_name</td>\n<td>$level_name</td>\n"
+        . "<td>$year_name</td></tr>\n";
+    }
+  print "</table>\n";
+}
+
 function people_show_skill_inventory ($user_id)
 {
   $result = db_execute ("
-    SELECT
-      s.name AS skill_name, l.name AS level_name, y.name AS year_name
+    SELECT s.name AS skill_name, l.name AS level_name, y.name AS year_name
     FROM
       people_skill_year y, people_skill_level l, people_skill s,
       people_skill_inventory i
     WHERE
-      y.skill_year_id = i.skill_year_id
-      AND l.skill_level_id = i.skill_level_id
-      AND s.skill_id = i.skill_id
-      AND i.user_id = ?",
+      y.skill_year_id = i.skill_year_id AND l.skill_level_id = i.skill_level_id
+      AND s.skill_id = i.skill_id AND i.user_id = ?",
     [$user_id]
   );
-
-  print html_build_list_table_top ([_("Skill"), _("Level"), _("Experience")]);
-
-  $rows = db_numrows ($result);
   if (!$result)
     {
-      print '<tr><td><p class="warn">(' . _("SQL Error:") . ")</p>\n";
+      print '<p class="warn">' . _("SQL Error:") . "</p>\n";
       print db_error ();
-      print "</td></tr>\n";
+      return;
     }
-  elseif ($rows < 1)
-    print '<tr><td><p class="warn">(' . _("No skill inventory set up")
-      . ")</p>\n</td></tr>\n";
-  else
-    for ($i = 0; $i < $rows; $i++)
-      print "<tr class=\"" . utils_altrow ($i) . "\">\n"
-        . "<td>" . db_result ($result, $i, 'skill_name')
-        . "</td>\n<td>" . db_result ($result, $i, 'level_name')
-        . "</td>\n<td>" . db_result ($result, $i, 'year_name')
-        . "</td></tr>\n";
-  print "</table>\n";
+  if (db_numrows ($result) < 1)
+    {
+      print '<p class="warn">' . _("No skill inventory set up") . "</p>\n";
+      return;
+    }
+  people_print_skill_table ($result);
 }
 
 function people_edit_skill_inventory ($user_id)
