@@ -1,16 +1,23 @@
 <?php
 # Group homepage.
 #
-# Copyright (C) 1999-2000 The SourceForge Crew
-# Copyright (C) 2002-2006 Mathieu Roy <yeupou--gnu.org>
+# Copyright (C) 1999, 2000 The SourceForge Crew
+# Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
 # Copyright (C) 2002-2006 Yves Perrin <yves.perrin--cern.ch>
-# Copyright (C) 2007, 2008  Sylvain Beucler
-# Copyright (C) 2008  Aleix Conchillo Flaque
-# Copyright (C) 2016  Karl Berry (#devtools anchor for "Source code")
-# Copyright (C) 2017, 2022, 2023 Ineiev
+# Copyright (C) 2008 Aleix Conchillo Flaque
+# Copyright (C) 2014, 2016, 2017 Assaf Gordon
+# Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
+# Copyright (C) 2008-2017, 2020 Karl Berry (#devtools anchor for "Source code")
+# Copyright (C) 2013, 2014, 2017-2023 Ineiev
 #
 # This file is part of Savane.
 #
+# Code written before 2008-03-30 (commit 8b757b2565ff) is distributed
+# under the terms of the GNU General Public license version 3 or (at your
+# option) any later version; further contributions are covered by
+# the GNU Affero General Public license version 3 or (at your option)
+# any later version.  The license notices for the AGPL and the GPL follow.
+#
 # Savane is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
 # published by the Free Software Foundation, either version 3 of the
@@ -23,12 +30,26 @@
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# Savane is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as
+# published by the Free Software Foundation, either version 3 of the
+# License, or (at your option) any later version.
+#
+# Savane is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 require_directory ("people");
 require_directory ("news");
 require_directory ("stats");
 require_once (dirname (__FILE__) . '/vars.php');
 require_once (dirname (__FILE__) . '/vcs.php');
+require_once (dirname (__FILE__) . '/utils.php');
 
 # If we are at wrong url, redirect.
 $host = $project->getTypeBaseHost ();
@@ -56,28 +77,40 @@ $res_admin = db_execute ("
   [$group_id]
 );
 print "\n<div class='indexright'>\n";
-print $HTML->box_top (_("Membership Info"));
-print '<span class="smaller">';
-$next_div = function (&$j)
+print $HTML->box_top (_("Membership Info"), "", 1);
+$start_div = function (&$j)
 {
-  print "</span></div>\n<div class=\""
-    . utils_altrow ($j++) . '"><span class="smaller">';
+  print "<div class=\"" . utils_altrow ($j++) . '"><span class="smaller">';
 };
-$adminsnum = db_numrows ($res_admin);
-$j = 0;
-if ($adminsnum > 0)
-  {
-    print $adminsnum < 2? _("Group Admin:"): _("Group Admins:");
-    while ($row_admin = db_fetch_array ($res_admin))
-      {
-        $next_div ($j);
-        print "&nbsp; - "
-          . utils_link (
-              "{$sys_home}users/{$row_admin['user_name']}",
-              $row_admin['realname']
-            );
-      }
-  }
+$end_div = function ()
+{
+  print "</span></div>\n";
+};
+$j = 1;
+function print_group_admins ($res_admin)
+{
+  global $sys_home, $j, $start_div, $end_div;
+  $adminsnum = db_numrows ($res_admin);
+  if (!$adminsnum)
+    return;
+  $start_div ($j);
+  print $adminsnum < 2? _("Group Admin:"): _("Group Admins:");
+  $end_div ();
+  print "\n<ul class='group-page-admins'>\n";
+  while ($row_admin = db_fetch_array ($res_admin))
+    {
+      print "<li>";
+      $start_div ($j);
+      print utils_link (
+            "{$sys_home}users/{$row_admin['user_name']}",
+            $row_admin['realname']
+          );
+      $end_div ();
+      print "</li>\n";
+    }
+  print "</ul>\n";
+}
+print_group_admins ($res_admin);
 
 # Count of members on this group.
 $membersnum = db_fetch_array (db_execute ("
@@ -91,32 +124,33 @@ $membersnum = db_fetch_array (db_execute ("
 
 $membersnum = $membersnum['count'];
 
-$next_div ($j);
+$start_div ($j);
 printf (
   ngettext ("%s active member", "%s active members", $membersnum),
-  "<strong>$membersnum</strong>"
+  "<b>$membersnum</b>"
 );
+$end_div ();
 
 # If member = 1, it's obviously (or it should be) the group admin.
 # If there's no admin, we need to get access to the list.
 # But we show it anyway: this page can be used for request for membership,
 # provide more info that the little infobox.
-$next_div ($j);
+$start_div ($j);
 
 print '['
   . utils_link (
-     "${sys_home}project/memberlist.php?group=$group", _("View Members")
+     "{$sys_home}project/memberlist.php?group=$group", _("View Members")
     )
-  . ']</span>';
-print $HTML->box_bottom ();
+  . ']';
+$end_div ();
+print $HTML->box_bottom (1);
 print "<br />\n";
-print $HTML->box_top (_("Group identification"));
-print '<span class="smaller">';
-# TRANSLATORS: the argument is group id (a number).
-printf (_("Id: <strong>#%s</strong>"), $group_id);
+print $HTML->box_top (_("Group identification"), "", 1);
 $j = 0;
 
 $item_arr = [
+   # TRANSLATORS: the group id (a number) will follow.
+  _("Id:") => $group_id,
   _("System Name:") => $group,
   _("Name:") => $project->GetName (),
   _("Group Type:") => $project->getTypeName ()
@@ -124,11 +158,13 @@ $item_arr = [
 
 foreach ($item_arr as $key => $val)
   {
-    $next_div ($j);
-    print "$key <strong>$val</strong>";
+    $start_div ($j);
+    print "$key <b>$val</b>";
+    $end_div ();
   }
-unset ($next_div);
-print '</span>'. $HTML->box_bottom () . "<br />\n";
+unset ($start_div);
+unset ($end_div);
+print $HTML->box_bottom (1) . "<br />\n";
 
 if (search_has_group_anything_to_search ($group_id))
   {
@@ -144,9 +180,7 @@ if ($project->getTypeDescription ())
   print '<p>' . $project->getTypeDescription () . "</p>\n";
 
 if ($project->getLongDescription ())
-  print "<p>"
-    . markup_full (htmlspecialchars ($project->getLongDescription ()))
-    . "</p>\n";
+  print markup_full (utils_specialchars ($project->getLongDescription ()));
 else
   {
     if ($project->getDescription ())
@@ -203,8 +237,8 @@ if ($project->Uses ("news"))
         . "class='inline-link'><img alt='rss feed' "
         . "src='{$sys_home}images/common/feed16.png' /></a>"
       );
-    print news_show_latest ($group_id, 4, "true");
-    print $HTML->box_bottom();
+    print news_show_latest ($group_id, 4);
+    print $HTML->box_bottom ();
 
     print "\n</div><!-- end splitright -->\n<div class='splitleft'>\n";
   }
@@ -226,7 +260,7 @@ if ($sys_group_id == $group_id && member_check (0, $group_id, 'A'))
     # TRANSLATORS: the argument is site name (like Savannah).
     printf (
       _("Since you are administrator of this group, which one is\n"
-        . "the &ldquo;system group,&rqduo; you are administrator of the "
+        . "the &ldquo;system group,&rdquo; you are administrator of the "
         . "whole %s server."),
       $sys_name
     );
@@ -235,11 +269,11 @@ if ($sys_group_id == $group_id && member_check (0, $group_id, 'A'))
     print $HTML->box_nextitem (utils_altrow ($odd));
     $img = proj_home_img ("contexts/admin.png");
     print utils_link (
-      "${sys_home}siteadmin/", $img . _("Server Main Administration Page")
+      "{$sys_home}siteadmin/", $img . _("Server Main Administration Page")
     );
     print $HTML->box_nextitem (utils_altrow ($even));
     print utils_link (
-      "${sys_home}task/?group={$sys_unix_group_name}"
+      "{$sys_home}task/?group={$sys_unix_group_name}"
       . '&amp;category_id=1&amp;status_id=1&amp;set=custom',
       $img . _("Pending Group List")
     );
@@ -249,7 +283,7 @@ if ($sys_group_id == $group_id && member_check (0, $group_id, 'A'))
       ngettext (
          "(%s registration pending)", "(%s registrations pending)", $reg_count
       ),
-      "<strong>$reg_count</strong>"
+      "<b>$reg_count</b>"
     );
     print $HTML->box_bottom ();
     print "<br />\n";
@@ -269,7 +303,7 @@ if (member_check (0, $group_id, 'A'))
     print $HTML->box_nextitem (utils_altrow ($odd));
     $img = proj_home_img ("contexts/main.png");
     print utils_link (
-      "${sys_home}project/admin/?group=$group",
+      "{$sys_home}project/admin/?group=$group",
        $img . _("Group Main Administration Page")
     );
     print $HTML->box_bottom();
@@ -331,10 +365,10 @@ if ($project->Uses ("extralink_documentation"))
         # The group has an external doc? Print it first. See pagemenu.php
         # for explanations about this.
         print $img;
-        $br = "<br />\n&nbsp; - ";
-        print $br
+        print "<ul><li>"
           . utils_link ($extra_link, _("Browse docs (external to Savane)"));
-        print $br . utils_link ($cb_url, _("Browse the cookbook"));
+        print "</li>\n<li>" . utils_link ($cb_url, _("Browse the cookbook"));
+        print "</li>\n<ul>\n";
       }
     else
       print utils_link ($cb_url, $img);
@@ -343,14 +377,14 @@ if ($project->Uses ("extralink_documentation"))
 
 specific_makesep ();
 print utils_link(
-  "${sys_home}project/memberlist.php?group=$group",
+  "{$sys_home}project/memberlist.php?group=$group",
   proj_home_img ("contexts/people.png") . _("Memberlist")
 );
 
 print ' ';
 printf (
   ngettext ("(%s member)", "(%s members)", $membersnum),
-  "<strong>$membersnum</strong>"
+  "<b>$membersnum</b>"
 );
 $i++;
 
@@ -358,7 +392,7 @@ if (group_get_preference ($group_id, 'gpg_keyring'))
   {
     specific_makesep ();
     print utils_link (
-      "${sys_home}project/release-gpgkeys.php?group=$group",
+      "{$sys_home}project/release-gpgkeys.php?group=$group",
       proj_home_img ("contexts/keys.png") . _("Group release GPG keyring")
     );
     $i++;
@@ -374,24 +408,25 @@ function open_vs_total_items ($url, $group_id, $artifact)
     WHERE group_id = ? AND status_id != 3",
     [$group_id]);
   $row_count = db_fetch_array($res_count)['count'];
-  $open_num = "<strong>$row_count</strong>";
+  $open_num = "<b>$row_count</b>";
   $res_count = db_execute (
     "SELECT count(*) AS count FROM $artifact WHERE group_id = ?",
     [$group_id]
   );
   $row_count = db_fetch_array($res_count)['count'];
-  $total_num = "<strong>$row_count</strong>";
+  $total_num = "<b>$row_count</b>";
   print ' ';
   # TRANSLATORS: the arguments are numbers of items.
   printf (_('(open items: %1$s, total: %2$s)'), $open_num, $total_num);
 
-  print "<br />\n&nbsp; - "
+  print "<ul>\n<li>"
     . utils_link ("$url&amp;func=browse&amp;set=open", _("Browse open items"));
-  print "<br />\n&nbsp; - "
+  print "</li>\n<li>"
     . utils_link (
        "$url&amp;func=additem", _("Submit a new item"),
        0, group_restrictions_check ($group_id, $artifact)
       );
+  print "</li>\n</ul>\n";
 }
 
 $job_num = people_project_jobs_rows ($group_id);
@@ -434,7 +469,7 @@ if ($sys_unix_group_name == $group
           ngettext (
             "(%s public mailing list)", "(%s public mailing lists)", $row_count
            ),
-           "<strong>$row_count</strong>"
+           "<b>$row_count</b>"
         );
         $i++;
       }
@@ -443,15 +478,15 @@ if ($sys_unix_group_name == $group
       {
         specific_makesep ();
         print utils_link (
-          "${sys_home}people/?group=$group",
+          "{$sys_home}people/?group=$group",
           proj_home_img ("contexts/people.png")
           . _("This group is looking for people")
-        );
+        ) . ' ';
         printf (
           ngettext (
             "(%s contributor wanted)", "(%s contributors wanted)", $job_num
           ),
-          "<strong>$job_num</strong>"
+          "<b>$job_num</b>"
         );
         $i++;
       }
@@ -472,13 +507,12 @@ function print_scm_entry ($group, &$i, $scm, $scm_name)
   print proj_home_img ("contexts/cvs.png") . "<a href=\"$url\">";
   # TRANSLATORS: the argument is name of VCS (like Git or Bazaar).
   printf (_("%s Repository"), $scm_name);
-  print "</a>\n";
-  $brk = "<br />\n&nbsp; - "; 
+  print "</a>\n<ul>\n";
   $admin_url = pagemenu_vcs_admin_url ($group, $scm);
   if ($admin_url != '')
-    print "$brk<a href=\"$admin_url\">" . _("Administer") . "</a>";
+    print "<li><a href=\"$admin_url\">" . _("Administer") . "</a></li>\n";
 
-  $scm_url = $group->getUrl ("${scm}_viewcvs");
+  $scm_url = $group->getUrl ("{$scm}_viewcvs");
   if (
     $group->Uses ($scm) && $scm_url != 'http://' && $scm_url != ''
   )
@@ -486,22 +520,19 @@ function print_scm_entry ($group, &$i, $scm, $scm_name)
       $repos = vcs_get_repos ($scm, $group_id);
       $n = count ($repos);
       if ($n < 2)
-        print "$brk<a href=\"$scm_url\">"
-          . _("Browse Sources Repository") . "</a>\n";
+        print "<li><a href=\"$scm_url\">"
+          . _("Browse Sources Repository") . "</a></li>\n";
       else
         {
-          $u = preg_replace(':/[^/]*$:', '/', $scm_url);
-          print '<p>' . _("Browse Sources Repository") . "</p>\n";
-          print "<ul>\n";
-          foreach ($repos as $r)
-            print "<li><a href=\"$u{$r['url']}\">{$r['desc']}</a></li>\n";
-          print "</ul>\n";
+          print '<li>' . _("Browse Sources Repository") . "\n</li>\n";
+          print vcs_compile_repo_ul ($repos, $scm_url) . "\n";
         }
     }
   $view_url = pagemenu_vcs_web_browse_url ($group, $scm);
   if ($view_url != '')
-    print "<br />\n&nbsp; - <a href=\"$view_url\">"
-      . _("Browse Web Pages Repository") . '</a>';
+    print "<li><a href=\"$view_url\">"
+      . _("Browse Web Pages Repository") . "</a></li>\n";
+  print "</ul>\n";
   $i++;
 } # print_scm_entry
 # Development.
