@@ -1,11 +1,20 @@
 <?php
 # Sanitize input
 #
-# Copyright (C) 2005-2006 Mathieu Roy <yeupou--gnu.org>
-# Copyright (C) 2022 Ineiev
+# Copyright (C) 1999, 2000 The SourceForge Crew
+# Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
+# Copyright (C) 2014, 2016, 2017 Assaf Gordon
+# Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
+# Copyright (C) 2013, 2014, 2017-2023 Ineiev
 #
 # This file is part of Savane.
 #
+# Code written before 2008-03-30 (commit 8b757b2565ff) is distributed
+# under the terms of the GNU General Public license version 3 or (at your
+# option) any later version; further contributions are covered by
+# the GNU Affero General Public license version 3 or (at your option)
+# any later version.  The license notices for the AGPL and the GPL follow.
+#
 # Savane is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
 # published by the Free Software Foundation, either version 3 of the
@@ -18,7 +27,21 @@
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# Savane is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as
+# published by the Free Software Foundation, either version 3 of the
+# License, or (at your option) any later version.
+#
+# Savane is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+require_once (dirname (__FILE__) . '/utils.php');
 
 # The point of this library is to reach the point where Savane will
 # no longer needs register globals set to on.
@@ -53,7 +76,7 @@ $sane_sanitizers['specialchars'] = function ($in, &$out, $i, $arg)
 {
   if (!is_scalar ($in[$i]))
     return 1;
-  $out[$i] = htmlspecialchars ($in[$i], ENT_QUOTES);
+  $out[$i] = utils_specialchars ($in[$i], ENT_QUOTES);
   return 0;
 };
 
@@ -223,6 +246,13 @@ $sane_sanitizers['hash'] = function ($in, &$out, $i, $arg)
   return $sane_sanitizers['preg'] ($in, $out, $i, '/^[a-f\d]+$/');
 };
 
+$sane_sanitizers['path'] = function ($in,  &$out, $i, $arg)
+{
+  global $sane_sanitizers;
+  return $sane_sanitizers['preg'] ($in, $out, $i, ',^[:/[:alnum:]._-]+$,');
+};
+
+
 # Only allow strings without quotes.
 $sane_sanitizers['no_quotes'] = function ($in, &$out, $i, $arg)
 {
