@@ -1,11 +1,20 @@
 <?php
 # Every mails sent should be using functions listed here.
 #
-# Copyright (C) 2003-2006 Mathieu Roy <yeupou--gnu.org>
-# Copyright (C) 2017, 2018, 2019, 2020, 2022, 2023 Ineiev
+# Copyright (C) 1999, 2000 The SourceForge Crew
+# Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
+# Copyright (C) 2014, 2016, 2017 Assaf Gordon
+# Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
+# Copyright (C) 2013, 2014, 2017-2023 Ineiev
 #
 # This file is part of Savane.
 #
+# Code written before 2008-03-30 (commit 8b757b2565ff) is distributed
+# under the terms of the GNU General Public license version 3 or (at your
+# option) any later version; further contributions are covered by
+# the GNU Affero General Public license version 3 or (at your option)
+# any later version.  The license notices for the AGPL and the GPL follow.
+#
 # Savane is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
 # published by the Free Software Foundation, either version 3 of the
@@ -18,6 +27,21 @@
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# Savane is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as
+# published by the Free Software Foundation, either version 3 of the
+# License, or (at your option) any later version.
+#
+# Savane is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+require_once (dirname (__FILE__) . '/utils.php');
+require_once (dirname (__FILE__) . '/gpg.php');
 
 function sendmail_signature ()
 {
@@ -29,11 +53,12 @@ function sendmail_signature ()
     # TRANSLATORS: the argument is site name (like Savannah).
     . sprintf (_("Message sent via %s"), $sys_name)
     . "\nhttps://$sys_default_domain$sys_home\n";
-
 }
 
-function sendmail_format_body (&$message)
+function sendmail_format_body (&$message, &$context)
 {
+  if (!empty ($context['skip_format_body']))
+    return;
   $body = $message['body'];
   $body = wordwrap ($body, 78) . sendmail_signature ();
   # Beuc - 20050316
@@ -83,10 +108,9 @@ function sendmail_extract_comment_id (&$context)
 
 function sendmail_create_msgid ()
 {
-  mt_srand ((double)microtime () * 1000000);
-  return
-    date ("Ymd-His", time ()) . ".sv" . user_getid () . "."
-    . mt_rand (0,100000) . "@" . $_SERVER["HTTP_HOST"];
+  utils_srand ();
+  return date ("Ymd-His", time ()) . ".sv" . user_getid () . "."
+    . mt_rand (0, 100000) . "@" . $_SERVER["HTTP_HOST"];
 }
 
 function sendmail_msgid_headers ($context)
@@ -302,7 +326,7 @@ function sendmail_addr_is_email ($a)
 }
 function sendmail_addr_is_uid ($a)
 {
-  return ctype_digit ($a);
+  return ctype_digit (strval ($a));
 }
 function sendmail_addr_is_account_name ($a)
 {
@@ -445,6 +469,17 @@ function sendmail_make_subjects ($to, $message, $context)
   return [$user_subj, $emails];
 }
 
+function sendmail_encrypt_message ($uid, &$msg)
+{
+  $encrypted = $gpg_error = "";
+  if (user_get_preference ("email_encrypted", $uid))
+    list ($gpg_error, $gpg_result, $encrypted) =
+      gpg_encrypt_to_user ($uid, $msg);
+  if ($encrypted !== "")
+    $msg = $encrypted;
+  return [$encrypted === '', $gpg_error];
+}
+
 # Send the mail.
 # Every mail sent by Savannah should be using that function which
 # works like mail ().
@@ -452,7 +487,7 @@ function sendmail_make_subjects ($to, $message, $context)
 function sendmail_mail ($addresses, $message, $context = [])
 {
   sendmail_check_displayspamcheck ($context);
-  sendmail_format_body ($message);
+  sendmail_format_body ($message, $context);
   sendmail_format_from ($addresses);
   $to = sendmail_make_to_list ($addresses);
   sendmail_build_headers ($addresses['from'], $context, $message);
@@ -530,7 +565,7 @@ function sendmail_form_message ($form_action, $user_id, $cc_me = true)
   # will do it.
   print "<form action=\"$form_action\" method='post'>\n"
     . form_hidden ([
-        'touser' => htmlspecialchars ($user_id),
+        'touser' => utils_specialchars ($user_id),
         'fromuser' => user_getname ()])
     . "\n$pre" . _("From:") . "$post"
     . user_getrealname (user_getid (), 1) . ' &lt;'
