@@ -1,13 +1,21 @@
 <?php
 # Sitewide menu.
 #
-# Copyright (C) 1999-2000 The SourceForge Crew
-# Copyright (C) 2003-2006 Mathieu Roy <yeupou--gnu.org>
-# Copyright (C) 2003-2006 Yves Perrin <yves.perrin--cern.ch>
-# Copyright (C) 2017 Ineiev
+# Copyright (C) 1999, 2000 The SourceForge Crew
+# Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
+# Copyright (C) 2002-2006 Yves Perrin <yves.perrin--cern.ch>
+# Copyright (C) 2014, 2016, 2017 Assaf Gordon
+# Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
+# Copyright (C) 2013, 2014, 2017-2023 Ineiev
 #
 # This file is part of Savane.
 #
+# Code written before 2008-03-30 (commit 8b757b2565ff) is distributed
+# under the terms of the GNU General Public license version 3 or (at your
+# option) any later version; further contributions are covered by
+# the GNU Affero General Public license version 3 or (at your option)
+# any later version.  The license notices for the AGPL and the GPL follow.
+#
 # Savane is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
 # published by the Free Software Foundation, either version 3 of the
@@ -20,6 +28,19 @@
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# Savane is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as
+# published by the Free Software Foundation, either version 3 of the
+# License, or (at your option) any later version.
+#
+# Savane is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 require_once (dirname (__FILE__) . '/html.php');
 # Search tools, frequently needed.
@@ -83,21 +104,24 @@ function sitemenu_extraurl ($only_with_post = false)
   if ($_SERVER["REQUEST_METHOD"] == "POST")
     {
       if (!empty($group_name))
-        $extraurl .= "&amp;group=" . htmlspecialchars ($group_name)
+        $extraurl .= "&amp;group=" . utils_urlencode ($group_name)
           . "&amp;";
       if (!empty ($item_id))
         $extraurl .= "&amp;func=detailitem&amp;item_id="
-          . htmlspecialchars ($item_id) . "&amp;";
+          . utils_urlencode ($item_id) . "&amp;";
       return $extraurl;
     }
-  if (!empty ($item_id) && ctype_digit ($_SERVER['QUERY_STRING']))
+  $query_string = '';
+  if (!empty ($_SERVER['QUERY_STRING']))
+    $query_string = $_SERVER['QUERY_STRING'];
+  if (!empty ($item_id) && ctype_digit (strval ($query_string)))
     {
       # Short link case (like /bugs/?212).
       $extraurl .= "&amp;func=detailitem&amp;item_id="
-        . htmlspecialchars ($item_id);
+        . utils_urlencode ($item_id);
       return $extraurl;
     }
-  $extraurl = htmlspecialchars ($_SERVER['QUERY_STRING']);
+  $extraurl = utils_urlencode ($query_string);
   $extraurl = str_replace ("reload=1&amp;", "", $extraurl);
   $extraurl = "&amp;$extraurl";
   return $extraurl;
@@ -114,14 +138,11 @@ function sitemenu_site_admin ()
   # This menu is shown whether the user is a logged as super user or not.
   global $HTML, $sys_home, $sys_unix_group_name;
   $is_su = user_is_super_user ();
-  $HTML->menuhtml_top (_("Site Administration"));
-  $HTML->menu_entry ("{$sys_home}siteadmin/", _("Main page"), $is_su);
+  $HTML->menuhtml_top (no_i18n ("Site Administration"));
+  $HTML->menu_entry ("{$sys_home}siteadmin/", no_i18n ("Main page"), $is_su);
   $HTML->menu_entry ("{$sys_home}task/?group=$sys_unix_group_name"
     . '&amp;category_id=1&amp;status_id=1&amp;set=custom#results',
-    _("Pending projects")
-  );
-  $HTML->menu_entry ("{$sys_home}news/approve.php?group=$sys_unix_group_name",
-    _("Site news approval"), $is_su
+    no_i18n ("Pending registrations")
   );
   $HTML->menuhtml_bottom ();
 }
@@ -201,7 +222,7 @@ function sitemenu_thispage ($page_title, $page_toptab = 0, $page_group = 0)
       if ($extraurl)
         $extraurl = "?$extraurl";
       $HTML->menu_entry ("{$sys_home}i18n.php?lang_uri="
-        . urlencode ($_SERVER['REQUEST_URI'] . $extraurl),
+        . utils_urlencode ($_SERVER['REQUEST_URI'] . $extraurl),
         _("Language"), 1, _("Choose website language")
       );
     }
@@ -222,14 +243,14 @@ function sitemenu_thispage ($page_title, $page_toptab = 0, $page_group = 0)
     {
       if (user_isloggedin () && user_get_preference ("use_bookmarks"))
         {
-          $bookmark_title = urlencode (context_title ());
+          $bookmark_title = utils_urlencode (context_title ());
           if ($page_title)
             # TRANSLATORS: this string is used to separate context from
             # further description, like _("Bugs")._(": ").$bug_title.
-            $bookmark_title .= urlencode (_(": ") . $page_title);
+            $bookmark_title .= utils_urlencode (_(": ") . $page_title);
 
             $HTML->menu_entry ("{$sys_home}my/bookmarks.php?add=1&amp;url="
-              . urlencode ($_SERVER['REQUEST_URI']) . '&amp;title='
+              . utils_urlencode ($_SERVER['REQUEST_URI']) . '&amp;title='
               . $bookmark_title,
               _("Bookmark It"), 1, _("Add this page to my bookmarks")
             );
@@ -376,10 +397,10 @@ function sitemenu_help ()
   $HTML->menuhtml_top (_("Site Help"));
 
   $HTML->menu_entry ('/maintenance/FrontPage/', _('User Docs: FAQ'));
-  $HTML->menu_entry ("{$sys_home}userguide/", _("User Docs: In Depth Guide"),
+  $HTML->menu_entry ("/maintenance/back-page/", _("User Docs: In Depth Guide"),
     1,
     _("In-depth Documentation dedicated to any users, including "
-      . "Project Admins")
+      . "group admins")
   );
 
     # TRANSLATORS: the argument is site name (like Savannah).
@@ -418,7 +439,7 @@ function sitemenu_loggedin ($page_title, $page_toptab=0, $page_group=0)
     );
   if (user_can_be_super_user () && !user_is_super_user ())
     $HTML->menu_entry ("{$sys_home}account/su.php?action=login&amp;uri="
-      . urlencode ($_SERVER['REQUEST_URI']), _("Become Superuser"), 1,
+      . utils_urlencode ($_SERVER['REQUEST_URI']), _("Become Superuser"), 1,
       _("Superuser rights are required to perform site admin tasks")
     );
   if (user_is_super_user ())
@@ -426,7 +447,7 @@ function sitemenu_loggedin ($page_title, $page_toptab=0, $page_group=0)
       print form_tag (['action' => "{$sys_home}account/impersonate.php"])
         . '<label for="user_name">' . _("Become this user:")
         . "</label><br/>\n";
-      print form_hidden (["uri" => urlencode ($_SERVER['REQUEST_URI'])]);
+      print form_hidden (["uri" => utils_urlencode ($_SERVER['REQUEST_URI'])]);
       print '<input type="text" id="user_name" name="user_name" size=10 '
         . '/>&nbsp;';
       print '<input type="submit" name="impersonate" value="'
@@ -460,7 +481,7 @@ function sitemenu_loggedin ($page_title, $page_toptab=0, $page_group=0)
   if (user_is_super_user ())
     $HTML->menu_entry (
       "{$sys_home}account/su.php?action=logout&amp;uri="
-      . urlencode ($_SERVER['REQUEST_URI']),
+      . utils_urlencode ($_SERVER['REQUEST_URI']),
       _("Logout Superuser"), 1,
       _("End the Superuser session, go back to normal user session")
     );
@@ -487,7 +508,7 @@ function sitemenu_notloggedin ()
 
   $HTML->menu_entry (
     "{$sys_home}account/login.php?uri="
-    . urlencode ($_SERVER['REQUEST_URI'] . $extraurl),
+    . utils_urlencode ($_SERVER['REQUEST_URI'] . $extraurl),
     _("Login"), 1,
     _("Login page - you must have registered an account first")
   );
