@@ -1,11 +1,20 @@
 <?php
 # Theme functions.
 #
-# Copyright (C) 2002-2006 Mathieu Roy <yeupou--gnu.org>
-# Copyright (C) 2019 Ineiev
+# Copyright (C) 1999, 2000 The SourceForge Crew
+# Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
+# Copyright (C) 2014, 2016, 2017 Assaf Gordon
+# Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
+# Copyright (C) 2013, 2014, 2017-2023 Ineiev
 #
 # This file is part of Savane.
 #
+# Code written before 2008-03-30 (commit 8b757b2565ff) is distributed
+# under the terms of the GNU General Public license version 3 or (at your
+# option) any later version; further contributions are covered by
+# the GNU Affero General Public license version 3 or (at your option)
+# any later version.  The license notices for the AGPL and the GPL follow.
+#
 # Savane is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
 # published by the Free Software Foundation, either version 3 of the
@@ -18,6 +27,19 @@
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# Savane is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as
+# published by the Free Software Foundation, either version 3 of the
+# License, or (at your option) any later version.
+#
+# Savane is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 # theme value is fetched by getting the cookie. But we keep in the
 # database the setting, so someone using another computer can easily
@@ -113,14 +135,14 @@ function theme_validate ($user_theme)
 
   if ($forbidden)
     {
-      error_log ("Forbidden theme '$user_theme', user " . user_getname ());
+      trigger_error ("Forbidden theme '$user_theme', user " . user_getname ());
       return $GLOBALS['sys_themedefault'];
     }
 
   if (file_exists ($GLOBALS['sys_www_topdir'] . "/css/$user_theme.css"))
     return $user_theme;
   if ($user_theme != '')
-    error_log ("Invalid theme '$user_theme', user " . user_getname ());
+    trigger_error ("Invalid theme '$user_theme', user " . user_getname ());
   return $GLOBALS['sys_themedefault'];
 }
 
@@ -128,7 +150,7 @@ function theme_validate ($user_theme)
 function theme_next_random ()
 {
   $theme = theme_list ();
-  mt_srand ((double)microtime () * 1000000);
+  utils_srand ();
   $num = mt_rand (0, count ($theme) - 1);
   $random_theme = theme_validate ($theme[$num]);
   $expire = time () + 60 * 60 * 24;
