@@ -3,14 +3,22 @@
 # shared among the XML outputs and the PHP web front-end.
 # Also abstracts controls to update data.
 #
-# Copyright (C) 1999-2000 The SourceForge Crew
-# Copyright (C) 2001-2002 Laurent Julliard, CodeX Team, Xerox
-# Copyright (C) 2003-2006 Mathieu Roy <yeupou--gnu.org>
-# Copyright (C) 2003-2006 Yves Perrin <yves.perrin--cern.ch>
-# Copyright (C) 2018, 2019, 2020, 2022, 2023 Ineiev
+# Copyright (C) 1999, 2000 The SourceForge Crew
+# Copyright (C) 2001, 2002 Laurent Julliard, CodeX Team, Xerox
+# Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
+# Copyright (C) 2002-2006 Yves Perrin <yves.perrin--cern.ch>
+# Copyright (C) 2014, 2016, 2017 Assaf Gordon
+# Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
+# Copyright (C) 2013, 2014, 2017-2023 Ineiev
 #
 # This file is part of Savane.
 #
+# Code written before 2008-03-30 (commit 8b757b2565ff) is distributed
+# under the terms of the GNU General Public license version 3 or (at your
+# option) any later version; further contributions are covered by
+# the GNU Affero General Public license version 3 or (at your option)
+# any later version.  The license notices for the AGPL and the GPL follow.
+#
 # Savane is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
 # published by the Free Software Foundation, either version 3 of the
@@ -23,10 +31,24 @@
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# Savane is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as
+# published by the Free Software Foundation, either version 3 of the
+# License, or (at your option) any later version.
+#
+# Savane is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 $dir_name = dirname (__FILE__);
 require_once ("$dir_name/../trackers/transition.php");
 require_once ("$dir_name/../trackers/cookbook.php");
+require_once (dirname (__FILE__) . '/../utils.php');
 
 # Get all the possible bug fields for this project both used and unused. If
 # used then show the project specific information about field usage
@@ -36,8 +58,8 @@ function trackers_data_get_all_fields ($group_id = false, $reload = false)
 {
   global $BF_USAGE_BY_ID, $BF_USAGE_BY_NAME, $AT_START;
 
-  if (!ctype_alnum (ARTIFACT))
-    die ("Invalid ARTIFACT name: " . htmlspecialchars (ARTIFACT ));
+  if (!ctype_alnum (strval (ARTIFACT)))
+    util_die ("Invalid ARTIFACT name: " . ARTIFACT);
 
   # Do nothing if already set and reload not forced.
   if (isset ($BF_USAGE_BY_ID) && !$reload)
@@ -93,7 +115,7 @@ function trackers_data_get_item_group ($item_id)
 
 function &trackers_data_get_notification_settings ($group_id, $tracker)
 {
-  assert ('ctype_alnum($tracker)');
+  assert ('ctype_alnum (strval ($tracker))');
 
   $result = db_execute (
     "SELECT * FROM groups WHERE group_id = ?", [$group_id]
@@ -150,14 +172,13 @@ function trackers_data_show_notification_settings (
   );
   if (!(user_ismember ($group_id, 'A')))
     return;
-  $check = ' checked="checked" ';
-  $cat_ck = $glob_ck = $both_ck ='';
+  $cat_ck = $glob_ck = $both_ck = false;
   if ($grtrsettings['glnotif'] == 0)
-    $cat_ck = $check;
+    $cat_ck = true;
   if ($grtrsettings['glnotif'] == 1)
-    $glob_ck = $check;
+    $glob_ck = true;
   if ($grtrsettings['glnotif'] == 2)
-    $both_ck = $check;
+    $both_ck = true;
   $cat_n = $grtrsettings['nb_categories'];
   if ($cat_n > 0)
     {
@@ -168,38 +189,41 @@ function trackers_data_show_notification_settings (
                 . "depend on item categories, and provide the respective "
                 . "email addresses (comma-separated list).")
              . "</p>\n";
-      print "<input type='radio' name=\"${tracker}_notif_scope\" "
-        . "value='global'$glob_ck/>&nbsp;&nbsp;<span class='preinput'>"
-        . _("Notify persons in the global list only") . "</span><br />\n"
-        . "<input type='radio' name=\"${tracker}_notif_scope\" "
-        . "value='category'$cat_ck/>&nbsp;&nbsp;<span class='preinput'>"
-        . _("Notify persons in the category related list "
-            . "instead of the global list") . "</span><br />\n"
-        . "<input type='radio' name=\"${tracker}_notif_scope\" "
-        . "value='both'$both_ck/>&nbsp;&nbsp;<span class='preinput'>"
-        . _("Notify persons in the category related list in addition to "
-            . "the global list")
-        . "</span><br />\n<h2>" . _("Category related lists") . "</h2>\n";
-      print "<input type='hidden' name=\"${tracker}_nb_categories\" "
-        . "value=\"$cat_n\" />\n";
+      $cases = [
+        'global' => [$glob_ck, _("Notify persons in the global list only")],
+        'category' => [
+            $cat_ck,
+            _("Notify persons in the category-related list "
+              . "instead of the global list")
+          ],
+         'both' => [
+            $both_ck,
+            _("Notify persons in the category-related list "
+              . "in addition to the global list")]
+      ];
+      foreach ($cases as $val => $data)
+        print form_radio ("{$tracker}_notif_scope", $val,
+          ['checked' => $data[0], 'label' => $data[1]]
+        )
+        . "<br />\n";
+      print "\n<h2>" . _("Category-related lists") . "</h2>\n";
+      print form_hidden (["{$tracker}_nb_categories" => $cat_n]);
 
       for ($i = 0; $i < $cat_n ; $i++)
         {
-          $tr_cat = $tracker . '_cat_' . $i;
+          $tr_cat = "{$tracker}_cat_$i";
           $cb_name = $tr_cat . '_send_all_flag';
           $settings = $grtrsettings['category'][$i];
-          print '<input type="hidden" name="' . $tr_cat . '_bug_fv_id" value="'
-            . $settings['fv_id'] . '" />';
-          print "<span class='preinput'><label for=\"${tr_cat}_email\">"
-            . $settings['name']
-            . "</span><br />\n&nbsp;&nbsp;<input type='text' id=\""
-            . "${tr_cat}_email\" name=\"${tr_cat}_email\" value=\""
-            . htmlspecialchars ($settings['email'])
-            . "\" size='50' maxlength='255' />\n"
+          print form_hidden (["{$tr_cat}_bug_fv_id" => $settings['fv_id']]);
+          print "<span class='preinput'>"
+            . html_label ("{$tr_cat}_email", $settings['name'])
+            . "</span><br />\n&nbsp;&nbsp;"
+            . form_input ('text', "{$tr_cat}_email", $settings['email'],
+                "size='50' maxlength='255'")
             . "&nbsp;&nbsp;<span class='preinput'>("
             . form_checkbox ($cb_name, $settings['send_all_flag'])
-            . "<label for=\"$cb_name\">" . _("Send on all updates")
-            . ")</label></span><br />\n";
+            . html_label ($cb_name, _("Send on all updates"))
+            . ")</span><br />\n";
         }
       print '<h2>' . _("Global list") . "</h2>\n";
     }
@@ -213,29 +237,27 @@ function trackers_data_show_notification_settings (
 
   $cb_name = "{$tracker}_send_all_changes";
   $txt_name = "{$tracker}_new_item_address";
-  print "<span class='preinput'><label for=\"$txt_name\">"
-    . _("Global List:") . "</label></span><br />\n&nbsp;&nbsp;"
-    . "<input type='text' id=\"$txt_name\" name=\"$txt_name\""
-    . 'value="' . htmlspecialchars ($grtrsettings['glnewad'])
-    . '" size="50" maxlength="255" />
-      &nbsp;&nbsp;<span class="preinput">('
+  print "<span class='preinput'>" . html_label ($txt_name, _("Global List:"))
+    . "</span><br />\n&nbsp;&nbsp;"
+    . form_input ('text', $txt_name, $grtrsettings['glnewad'],
+        'size="50" maxlength="255"')
+    . ' &nbsp;&nbsp;<span class="preinput">('
     . form_checkbox ($cb_name, $grtrsettings['glsendall'])
-    . "<label for=\"$cb_name\">"
-    . _("Send on all updates") . '</label>)</span>';
+    . html_label ($cb_name, _("Send on all updates")). ")</span>\n";
 
-  print '<h2>' . _("Private items exclude list") . "</h2>\n";
+  print "\n<h2>" . _("Exclusions for private items") . "</h2>\n";
   if ($show_intro_msg != 0)
     print '<p>'
       . _("Addresses registered in this list will be excluded from default "
           . "mail\nnotification for private items.")
       . "</p>\n";
 
-  $txt_name = "${tracker}_private_exclude_address";
+  $txt_name = "{$tracker}_private_exclude_address";
   print "<span class='preinput'><label for=\"$txt_name\">"
     . _("Exclude List:") . "</label></span><br />\n&nbsp;&nbsp;"
-    . "<input type='text' id=\"$txt_name\" name=\"$txt_name\" value=\""
-    . htmlspecialchars ($grtrsettings['private_exclude'])
-    . "\" size='50' maxlength='255' /><br />\n";
+    . form_input ('text', $txt_name, $grtrsettings['private_exclude'],
+        "size='50' maxlength='255'")
+    . "<br />\n";
 }
 
 function trackers_data_post_notification_settings ($group_id, $tracker)
@@ -469,7 +491,7 @@ function trackers_data_get_all_report_fields ($report_id = 100)
   if (!$have_bug_id)
     {
       if (db_numrows ($res) > 0)
-        error_log ("No bug it found in query form #$report_id");
+        trigger_error ("No bug it found in query form #$report_id");
       $field = 'bug_id';
       $id = trackers_data_get_field_id ($field);
       foreach ($flags as $f => $v)
@@ -1194,9 +1216,8 @@ function trackers_data_get_history ($item_id)
 function trackers_data_get_attached_files ($item_id = false, $order = 'DESC')
 {
   if ($order != 'DESC' && $order != 'ASC')
-    die (
-      "trackers_data_get_attached_files: invalid \$order '"
-      . htmlescape ($order) . "')"
+    util_die (
+      "trackers_data_get_attached_files: invalid \$order '$order')"
     );
 
   return db_execute ("
@@ -1277,7 +1298,7 @@ function trackers_data_add_history (
     }
 
   $result = db_autoexecute (
-    "${artifact}_history",
+    "{$artifact}_history",
     [
       'bug_id' => $item_id, 'field_name' => $field_name,
       'old_value' => $old_value, 'new_value' => $new_value,
@@ -1318,7 +1339,7 @@ function trackers_data_add_history (
           if ($prev_old_value != $old_value
               || $prev_new_value != $new_value)
           $res = db_autoexecute (
-            "${artifact}_history",
+            "{$artifact}_history",
             ['new_value' => $new_value, 'old_value' => $old_value],
             DB_AUTOQUERY_UPDATE, "bug_history_id = ?", [$insert_id]
           );
@@ -1379,7 +1400,7 @@ function trackers_data_append_canned_response ($details, $canned_response)
         }
       if (!empty ($details))
         $details .= $separator;
-      $details .= htmlspecialchars_decode (
+      $details .= utils_specialchars_decode (
         db_result ($res, 0, 'body'), ENT_QUOTES
       );
       $any_response_used = true;
@@ -1501,7 +1522,7 @@ function trackers_data_handle_update (
                   || trackers_data_is_text_area ($field));
       if  ($is_text)
         {
-          $differ = ($old_value != htmlspecialchars ($value));
+          $differ = ($old_value != utils_specialchars ($value));
         }
       elseif (trackers_data_is_date_field ($field))
         {
@@ -1525,7 +1546,7 @@ function trackers_data_handle_update (
           $extra_addresses .= $field_transition_cc;
 
           if ($is_text)
-            $upd_list[$field] = htmlspecialchars ($value);
+            $upd_list[$field] = utils_specialchars ($value);
           else
             $upd_list[$field] = $value;
           trackers_data_add_history ($field, $old_value, $value, $item_id);
@@ -1571,7 +1592,7 @@ function trackers_data_handle_update (
     {
       $change_exists = 1;
       fb (_("Comment added"), 0);
-      $dtext = htmlspecialchars ($details);
+      $dtext = utils_specialchars ($details);
       if (empty ($vfl['comment_type_id']))
         $vfl['comment_type_id'] = false;
       trackers_data_add_history (
@@ -1591,7 +1612,7 @@ function trackers_data_handle_update (
   # If we are on the cookbook, the original submission have been details.
   if (ARTIFACT == 'cookbook')
     {
-      $details = htmlspecialchars ($vfl['details']);
+      $details = utils_specialchars ($vfl['details']);
       $previous_details = db_result ($result, 0, 'details');
 
       if ($details != $previous_details)
@@ -1611,8 +1632,8 @@ function trackers_data_handle_update (
           $change .= " chars";
 
           trackers_data_add_history (
-            'realdetails', htmlspecialchars ($del_cut),
-            htmlspecialchars ($change), $item_id, false, false, true
+            'realdetails', utils_specialchars ($del_cut),
+            utils_specialchars ($change), $item_id, false, false, true
           );
           $changes['realdetails']['add'] = $change;
           $changes['realdetails']['del'] = $del_cut;
@@ -2101,7 +2122,7 @@ function trackers_data_create_item ($group_id, $vfl, &$extra_addresses)
 
       if (trackers_data_is_text_area ($field)
           || trackers_data_is_text_field ($field))
-        $value = htmlspecialchars ($value);
+        $value = utils_specialchars ($value);
       elseif (trackers_data_is_date_field ($field))
         list ($value, $ok) = utils_date_to_unixtime ($value);
 
@@ -2136,8 +2157,8 @@ function trackers_data_create_item ($group_id, $vfl, &$extra_addresses)
   $insert_fields['group_id'] = $group_id;
   $insert_fields['submitted_by'] = $user;
   $insert_fields['date'] = time ();
-  $insert_fields['summary'] = htmlspecialchars ($vfl['summary']);
-  $insert_fields['details'] = htmlspecialchars ($vfl['details']);
+  $insert_fields['summary'] = utils_specialchars ($vfl['summary']);
+  $insert_fields['details'] = utils_specialchars ($vfl['details']);
   $insert_fields['spamscore'] = $spamscore;
   $insert_fields['ip'] = '127.0.0.1';
 
@@ -2444,7 +2465,7 @@ function trackers_data_count_field_value_usage (
   if (!preg_match ('/^[a-z0-9_]+$/', $field))
     util_die (
       'trackers_data_count_field_value_usage: invalid $field <em>'
-      . htmlspecialchars ($field) . '</em>'
+      . $field . '</em>'
     );
   $res = db_execute ("
     SELECT COUNT(*) AS count FROM " . ARTIFACT . "
