@@ -1,14 +1,22 @@
 <?php
 # Format tracker data.
 #
-# Copyright (C) 1999-2000 The SourceForge Crew
-# Copyright (C) 2001-2002 Laurent Julliard, CodeX Team, Xerox
-# Copyright (C) 2003-2006 Mathieu Roy <yeupou--gnu.org>
-# Copyright (C) 2003-2006 Yves Perrin <yves.perrin--cern.ch>
-# Copyright (C) 2017-2020, 2022 Ineiev
+# Copyright (C) 1999, 2000 The SourceForge Crew
+# Copyright (C) 2001, 2002 Laurent Julliard, CodeX Team, Xerox
+# Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
+# Copyright (C) 2002-2006 Yves Perrin <yves.perrin--cern.ch>
+# Copyright (C) 2014, 2016, 2017 Assaf Gordon
+# Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
+# Copyright (C) 2013, 2014, 2017-2023 Ineiev
 #
 # This file is part of Savane.
 #
+# Code written before 2008-03-30 (commit 8b757b2565ff) is distributed
+# under the terms of the GNU General Public license version 3 or (at your
+# option) any later version; further contributions are covered by
+# the GNU Affero General Public license version 3 or (at your option)
+# any later version.  The license notices for the AGPL and the GPL follow.
+#
 # Savane is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
 # published by the Free Software Foundation, either version 3 of the
@@ -21,6 +29,20 @@
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# Savane is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as
+# published by the Free Software Foundation, either version 3 of the
+# License, or (at your option) any later version.
+#
+# Savane is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+require_once (dirname (__FILE__) . '/../utils.php');
 
 function format_item_details (
   $item_id, $group_id, $ascii = false, $item_assigned_to = false,
@@ -296,14 +318,14 @@ function format_item_details (
               else
                 {
                   $icon = "project-admin";
-                  $icon_alt = _("Project Administrator");
+                  $icon_alt = _("Group administrator");
                 }
             }
           elseif (member_check ($poster_id, $group_id))
             {
               # Simple project member.
               $icon = "project-member";
-              $icon_alt = _("Project Member");
+              $icon_alt = _("Group Member");
             }
         } # if ($poster_id != 100)
 
@@ -508,6 +530,7 @@ function format_item_changes ($changes, $item_id, $group_id)
   return $out;
 }
 
+# Show the files attached to this tracker item.
 function format_item_attached_files ($item_id, $group_id, $ascii = false)
 {
   global $HTML, $sys_home, $php_self;
@@ -539,20 +562,17 @@ function format_item_attached_files ($item_id, $group_id, $ascii = false)
       . "Date: %s  Name: %s  Size: %s   By: %s\n%s\n%s";
 
   # Loop throuh the attached files and format them.
-  for ($i = 0; $i < $rows; $i++)
+  $i = 0;
+  while ($row = db_fetch_array ($result))
     {
-      $item_file_id = db_result ($result, $i, 'file_id');
+      $item_file_id = $row['file_id'];
       $href = $sys_home . ARTIFACT . "/download.php?file_id=$item_file_id";
 
       if ($ascii)
         $out .= sprintf (
-          $fmt,
-          utils_format_date (db_result ($result, $i, 'date')),
-          db_result ($result, $i, 'filename'),
-          utils_filesize (0, intval (db_result ($result, $i, 'filesize'))),
-          db_result ($result, $i, 'user_name'),
-          db_result ($result, $i, 'description'),
-          '<http://' . $GLOBALS['sys_default_domain']
+          $fmt, utils_format_date ($row['date']), $row['filename'],
+          utils_filesize (0, intval ($row['filesize'])), $row['user_name'],
+          $row['description'], '<http://' . $GLOBALS['sys_default_domain']
           . utils_unconvert_htmlspecialchars ($href) . '>'
         );
       else
@@ -570,32 +590,26 @@ function format_item_attached_files ($item_id, $group_id, $ascii = false)
                 . '</a></span>';
             }
 
-          $out .= '<div class="' . utils_altrow($i) . '">' . $html_delete;
+          $out .= '<div class="' . utils_altrow ($i++) . '">' . $html_delete;
           $out .= "<a href=\"$href\">file #$item_file_id: &nbsp;";
 
           # TRANSLATORS: the first argument is file name, the second
           # is user's name.
           $out .= sprintf (
             _('<!-- file -->%1$s added by %2$s'),
-            htmlspecialchars (db_result ($result, $i, 'filename'))
-            . '</a>',
-            utils_user_link (db_result ($result, $i, 'user_name'))
+            utils_specialchars ($row['filename']) . '</a>',
+            utils_user_link ($row['user_name'])
           );
 
           $out .= ' <span class="smaller">('
-            . utils_filesize (0, db_result ($result, $i, 'filesize'));
-
-          if (db_result ($result, $i, 'filetype'))
-            $out .= ' - ' . db_result ($result, $i, 'filetype');
-
-          if (db_result ($result, $i, 'description'))
-            {
-              $out .= ' - '
-                . markup_basic (db_result ($result, $i, 'description'));
-            }
+            . utils_filesize (0, $row['filesize']);
+          if ($row['filetype'])
+            $out .= ' - ' . $row['filetype'];
+          if ($row['description'])
+            $out .= ' - ' . markup_basic ($row['description']);
           $out .= ")</span></div>\n";
         }
-    } # for ($i = 0; $i < $rows; $i++)
+    } # while ($row = db_fetch_array ($result))
 
   if ($ascii)
     $out .= "\n";
@@ -605,7 +619,7 @@ function format_item_attached_files ($item_id, $group_id, $ascii = false)
   return $out;
 }
 
-# Show the files attached to this bug.
+# Show the notification list for this item.
 function format_item_cc_list ($item_id, $group_id, $ascii = false)
 {
   global $HTML, $php_self;
@@ -657,7 +671,7 @@ function format_item_cc_list ($item_id, $group_id, $ascii = false)
 
           # If email is numeric, it must be an user id. Try to convert it
           # to the username.
-          if (ctype_digit ($email) && user_exists ($email))
+          if (ctype_digit (strval ($email)) && user_exists ($email))
             $email =  user_getname ($email);
 
           # HTML preformat the address.
