@@ -1,8 +1,12 @@
 <?php
 # General tracker functions.
 #
-# Copyright (C) 1999-2000 The SourceForge Crew
-# Copyright (C) 2001-2002 Laurent Julliard, CodeX Team, Xerox
+# Copyright (C) 1999, 2000 The SourceForge Crew
+# Copyright (C) 2001, 2002 Laurent Julliard, CodeX Team, Xerox
+# Copyright (C) 2000-2006 Mathieu Roy
+# Copyright (C) 2014, 2016, 2017 Assaf Gordon
+# Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
+# Copyright (C) 2013, 2014, 2017-2023 Ineiev
 #
 # Copyright (C) 2003-2006 Mathieu Roy <yeupou--gnu.org>
 # Copyright (C) 2003-2006 Yves Perrin <yves.perrin--cern.ch>
@@ -10,6 +14,12 @@
 #
 # This file is part of Savane.
 #
+# Code written before 2008-03-30 (commit 8b757b2565ff) is distributed
+# under the terms of the GNU General Public license version 3 or (at your
+# option) any later version; further contributions are covered by
+# the GNU Affero General Public license version 3 or (at your option)
+# any later version.  The license notices for the AGPL and the GPL follow.
+#
 # Savane is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
 # published by the Free Software Foundation, either version 3 of the
@@ -22,12 +32,26 @@
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# Savane is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as
+# published by the Free Software Foundation, either version 3 of the
+# License, or (at your option) any later version.
+#
+# Savane is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 $dir_name = dirname (__FILE__);
 require_once ("$dir_name/../calendar.php");
 require_once ("$dir_name/../sendmail.php");
 require_once ("$dir_name/data.php");
 require_once ("$dir_name/format.php");
+require_once ("$dir_name/../utils.php");
 
 # Generate URL arguments from a variable wether scalar or array.
 function trackers_convert_to_url_arg ($varname, $var)
@@ -128,9 +152,9 @@ function trackers_field_label_display (
   $output = '';
 
   if (!$ascii)
-    $output .= '<span class="preinput"><span class="help" title="'
+    $output .= "<span class='preinput help' title=\""
       . trackers_data_get_description ($field_name) . '">'
-      . "$label</span></span>";
+      . "$label</span>";
 
   if ($break)
     $output .= ($ascii? "\n": '<br />');
@@ -139,7 +163,7 @@ function trackers_field_label_display (
       if (!$ascii)
         $output .= '&nbsp;';
       else
-        $output .= sprintf ("%${tab}s", $label) . ' ';
+        $output .= sprintf ("%{$tab}s", $label) . ' ';
     }
   return $output;
 }
@@ -289,7 +313,7 @@ function trackers_field_date (
 
   $html = calendar_select_date (
     $day, $month, $year,
-    ["${field}_dayfd", "${field}_monthfd", "${field}_yearfd"]
+    ["{$field}_dayfd", "{$field}_monthfd", "{$field}_yearfd"]
   );
   return $html;
 }
@@ -314,7 +338,7 @@ function trackers_multiple_field_date (
     . "\" size=\"$size\" maxlength=\"$maxlength\" value=\"$date_begin\">"
     . _('(yyyy-mm-dd)') . "</td></tr>\n<tr><td>"
     . _('End:') . "<br />\n"
-    . "<input type='text' name=\"${field_name}_end\" id=\"${field_name}_end"
+    . "<input type='text' name=\"{$field_name}_end\" id=\"{$field_name}_end"
     . "\" size=\"$size\" maxlength=\"$maxlength\" value=\"$date_end\">"
     . _('(yyyy-mm-dd)');
 
@@ -329,12 +353,12 @@ function trackers_date_op_list ()
 function trackers_field_date_operator ($field_name, $value = '', $ro = false)
 {
   if ($ro)
-    return htmlspecialchars ($value);
+    return utils_specialchars ($value);
   $options = '';
   foreach (trackers_date_op_list () as $v)
-    $options .= form_option ($v, $value, htmlspecialchars ($v));
+    $options .= form_option ($v, $value, utils_specialchars ($v));
   return '<select title="' . _("comparison operator")
-    . "\" name=\"${field_name}_op\">$options</select>\n";
+    . "\" name=\"{$field_name}_op\">$options</select>\n";
 }
 
 function trackers_field_text (
@@ -708,12 +732,11 @@ function trackers_artifact_is_sane (&$artifact)
   if (!$artifact)
     $artifact = ARTIFACT;
 
-  if (ctype_alnum ($artifact))
+  if (ctype_alnum (strval ($artifact)))
     return true;
 
-  $arg = '<em>' . htmlspecialchars ($artifact) . '</em>';
   # TRANSLATORS: the argument is name of artifact (like bugs or patches).
-  util_die (sprintf (_('Invalid artifact %s'), $arg));
+  util_die (sprintf (_('Invalid artifact %s'), "<em>$artifact</em>"));
   return false; # Just in case.
 }
 
@@ -741,7 +764,7 @@ function trackers_get_cc_list ($artifact, $item_id)
 
 function trackers_cc_is_to_be_ignored ($email, $added_by)
 {
-  if ($email != $added_by || !ctype_digit ($email))
+  if ($email != $added_by || !ctype_digit (strval ($email)))
     return false;
   # Here we have an integer as email address, it is likely to be
   # a CC automatically added.
@@ -758,7 +781,7 @@ function trackers_cc_is_to_be_ignored ($email, $added_by)
 function trackers_convert_user_name_to_uid ($email, &$addresses_to_skip)
 {
   # If we have a valid username, convert it to an uid.
-  if (ctype_digit ($email) || !user_getid ($email))
+  if (ctype_digit (strval ($email)) || !user_getid ($email))
     return $email;
   # Since is is will be registered, we can ignore it in further check.
   $addresses_to_skip[$email] = true;
@@ -799,7 +822,7 @@ function trackers_initial_notification_list ($tracker, $item)
 
 function trackers_enforce_notif_per_user_prefs ($changes, $email)
 {
-  if (!ctype_digit ($email))
+  if (!ctype_digit (strval ($email)))
     return true;
 
   # We have a user ID: check specific user's prefs.
@@ -908,7 +931,7 @@ function trackers_build_mail ($artifact, $res, $item_id, $changes)
   else
     $body = format_item_summary ($res, $bug_ref, $artifact);
   $body .= format_message_trailer ($bug_ref);
-  $subject = htmlspecialchars_decode ($res['summary'], ENT_QUOTES);
+  $subject = utils_specialchars_decode ($res['summary'], ENT_QUOTES);
   # Necessary to mention the comment id (for delayed mails).
   if ($int_delayspamcheck_comment_id)
     $item_id .= ":$int_delayspamcheck_comment_id";
@@ -924,7 +947,7 @@ function trackers_exclude_list ($artifact, $group_id, $force_exclude, $privacy)
         SELECT ${artifact}_private_exclude_address
         FROM groups WHERE group_id = ?", [$group_id]
       );
-      $exclude = db_result ($result, 0, "${artifact}_private_exclude_address");
+      $exclude = db_result ($result, 0, "{$artifact}_private_exclude_address");
     }
   return trim ("$exclude,$force_exclude", ',');
 }
