@@ -1,13 +1,21 @@
 <?php
 # Show items
 #
-# Copyright (C) 1999-2000 The SourceForge Crew
-# Copyright (C) 2001-2002 Laurent Julliard, CodeX Team, Xerox
-# Copyright (C) 2003-2006 Mathieu Roy <yeupou--gnu.org>
-# Copyright (C) 2017, 2019, 2020, 2022 Ineiev
+# Copyright (C) 1999, 2000 The SourceForge Crew
+# Copyright (C) 2001, 2002 Laurent Julliard, CodeX Team, Xerox
+# Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
+# Copyright (C) 2014, 2016, 2017 Assaf Gordon
+# Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
+# Copyright (C) 2013, 2014, 2017-2023 Ineiev
 #
 # This file is part of Savane.
 #
+# Code written before 2008-03-30 (commit 8b757b2565ff) is distributed
+# under the terms of the GNU General Public license version 3 or (at your
+# option) any later version; further contributions are covered by
+# the GNU Affero General Public license version 3 or (at your option)
+# any later version.  The license notices for the AGPL and the GPL follow.
+#
 # Savane is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
 # published by the Free Software Foundation, either version 3 of the
@@ -20,8 +28,22 @@
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# Savane is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as
+# published by the Free Software Foundation, either version 3 of the
+# License, or (at your option) any later version.
+#
+# Savane is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 require_once (dirname (__FILE__) . '/cookbook.php');
+require_once (dirname (__FILE__) . '/../utils.php');
 
 function show_item_navbar_begin ($url, $offset, $total_rows)
 {
@@ -292,7 +314,7 @@ function show_item_history ($item_id, $group_id, $no_limit = false)
           print utils_format_date ($value_id, 'natural');
         }
       else
-        print markup_basic (htmlspecialchars ($value_id));
+        print markup_basic (utils_specialchars ($value_id));
 
        print "</td>\n<td class='smaller' align='center'>"
          . html_image ('arrows/next.png') . "</td>\n"
@@ -302,7 +324,7 @@ function show_item_history ($item_id, $group_id, $no_limit = false)
       elseif (trackers_data_is_date_field ($field))
         print utils_format_date ($new_value_id, 'natural');
       else
-        print markup_basic (htmlspecialchars ($new_value_id));
+        print markup_basic (utils_specialchars ($new_value_id));
       print "</td>\n</tr>\n";
     } # for ($i = 0; $i < $rows; $i++)
   print "</table>\n";
