@@ -1,14 +1,22 @@
 <?php
 # Add item to trackers.
 #
-# Copyright (C) 1999-2000 The SourceForge Crew
-# Copyright (C) 2001-2002 Laurent Julliard, CodeX Team, Xerox
-# Copyright (C) 2003-2006 Mathieu Roy <yeupou--gnu.org>
-# Copyright (C) 2003-2006 Yves Perrin <yves.perrin--cern.ch>
-# Copyright (C) 2017, 2022 Ineiev
+# Copyright (C) 1999, 2000 The SourceForge Crew
+# Copyright (C) 2001, 2002 Laurent Julliard, CodeX Team, Xerox
+# Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
+# Copyright (C) 2002-2006 Yves Perrin <yves.perrin--cern.ch>
+# Copyright (C) 2014, 2016, 2017 Assaf Gordon
+# Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
+# Copyright (C) 2013, 2014, 2017-2023 Ineiev
 #
 # This file is part of Savane.
 #
+# Code written before 2008-03-30 (commit 8b757b2565ff) is distributed
+# under the terms of the GNU General Public license version 3 or (at your
+# option) any later version; further contributions are covered by
+# the GNU Affero General Public license version 3 or (at your option)
+# any later version.  The license notices for the AGPL and the GPL follow.
+#
 # Savane is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
 # published by the Free Software Foundation, either version 3 of the
@@ -21,6 +29,19 @@
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# Savane is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as
+# published by the Free Software Foundation, either version 3 of the
+# License, or (at your option) any later version.
+#
+# Savane is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 extract (sane_import ('request',
   ['hash' => 'form_id', 'array' => [['prefill', [null, 'specialchars']]]]
@@ -52,12 +73,10 @@ if ($preamble)
 print '<h2>' . _("Details") . "</h2>\n";
 
 # Beginning of the submission form with fixed fields.
-print form_header (
-  $_SERVER['PHP_SELF'], $form_id, "post",
+print form_header ($php_self, $form_id, "post",
   'enctype="multipart/form-data" name="trackers_form"'
 );
-print form_input ("hidden", "func", "postadditem");
-print form_input ("hidden", "group_id", $group_id);
+print form_hidden (["func" => "postadditem", 'group_id' => $group_id]);
 print "\n<table cellpadding='0' width='100%'>";
 
 # Now display the variable part of the field list (depending on the project).
@@ -90,7 +109,7 @@ while ($field_name = trackers_list_all_fields ())
     # We allow people to make urls with predefined values,
     # if the values are in the url, we override the default value.
     if (!empty ($$field_name))
-      $field_value = htmlspecialchars ($$field_name);
+      $field_value = utils_specialchars ($$field_name);
     elseif (isset ($prefill[$field_name]))
       $field_value = $prefill[$field_name];
     else
@@ -122,29 +141,23 @@ while ($field_name = trackers_list_all_fields ())
     # Fields colors.
     $field_class = $row_class = '';
     if ($j % 2 && $field_name != 'details')
-      {
-        # We keep the original submission with the default
-        # background color, for lisibility sake.
-        #
-        # We also use the boxitem background color only one time
-        # out of two, to keep the page light.
-        $row_class = ' class="' . utils_altrow ($j + 1) . '"';
-      }
+      # We keep the original submission with the default background color,
+      # for lisibility sake.
+      #
+      # We also use the boxitem background color only one time out of two,
+      # to keep the page light.
+      $row_class = ' class="' . utils_altrow ($j + 1) . '"';
 
     # If we are working on the cookbook, present checkboxes to
     # defines context before the summary line.
     if (CONTEXT == 'cookbook' && $field_name == 'summary' && $is_trackeradmin)
-      {
-        cookbook_print_form ();
-      }
+      cookbook_print_form ();
 
     # We highlight fields that were not properly/completely
     # filled.
     if (!empty ($previous_form_bad_fields)
         && array_key_exists ($field_name, $previous_form_bad_fields))
-      {
-        $field_class = ' class="highlight"';
-      }
+      $field_class = ' class="highlight"';
 
     if ($sz > $max_size)
       {
@@ -185,7 +198,8 @@ print
 if ($preview)
   {
     print '<h2>' . _('Preview') . "</h2>\n\n";
-    print markup_full (htmlspecialchars ($details));
+    if (isset ($details))
+      print markup_full (utils_specialchars ($details));
   }
 
 
@@ -231,31 +245,26 @@ if (user_isloggedin ())
     print '<p><span class="preinput">'
       . _("Add Email Addresses (use comma as separator):")
       . "</span><br />\n&nbsp;&nbsp;&nbsp;"
-      . '<input type="text" name="add_cc" size="40" value="'
-      . htmlspecialchars ($add_cc) . "\" />&nbsp;&nbsp;&nbsp;\n"
+      . form_input ('text', 'add_cc', $add_cc, 'size="40"')
+      . "&nbsp;&nbsp;&nbsp;\n"
       . "<br />\n<span class='preinput'>" . _("Comment:")
       . "</span><br />\n&nbsp;&nbsp;&nbsp;"
-      . '<input type="text" name="cc_comment" value="'
-      . htmlspecialchars ($cc_comment) . '" size="40" maxlength="255" />';
+      . form_input ('text', "cc_comment", $cc_comment,
+          'size="40" maxlength="255"');
     print "</p>\n";
   }
 
-# Minimal anti-spam.
 if (empty ($fields['check']))
   $check = '';
 else
-  $check = htmlspecialchars ($fields['check']);
+  $check = $fields['check'];
 if (!user_isloggedin ())
   print '<p class="noprint">'
     . _("Please enter the title of <a\n"
         . "href=\"https://en.wikipedia.org/wiki/George_Orwell\">George "
         . "Orwell</a>'s famous\ndystopian book (it's a date):")
-    . "\n<input type='text' value=\"$check\" name='check' /></p>\n";
+    . "\n" . form_input ('text', 'check', $check) . "</p>\n";
 
-print "<p>&nbsp;</p>\n";
-print '<p><span class="warn">'
-  . _("Did you check to see if this item has already been submitted?")
-  . "</span></p>\n";
 print '<div align="center">';
 print form_submit (false, "submit", 'class="bold"');
 print "</div>\n";
