@@ -1,15 +1,22 @@
 <?php
 # List of tracker items, with various sorts & filters
 #
-# Copyright (C) 1999-2000 The SourceForge Crew
-# Copyright (C) 2001-2002 Laurent Julliard, CodeX Team, Xerox
-# Copyright (C) 2003-2006 Mathieu Roy <yeupou--gnu.org>
-# Copyright (C) 2003-2006 Yves Perrin <yves.perrin--cern.ch>
-# Copyright (C) 2007  Sylvain Beucler
-# Copyright (C) 2014, 2017-2023  Ineiev
+# Copyright (C) 1999, 2000 The SourceForge Crew
+# Copyright (C) 2001, 2002 Laurent Julliard, CodeX Team, Xerox
+# Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
+# Copyright (C) 2002-2006 Yves Perrin <yves.perrin--cern.ch>
+# Copyright (C) 2014, 2016, 2017 Assaf Gordon
+# Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
+# Copyright (C) 2013, 2014, 2017-2023 Ineiev
 #
 # This file is part of Savane.
 #
+# Code written before 2008-03-30 (commit 8b757b2565ff) is distributed
+# under the terms of the GNU General Public license version 3 or (at your
+# option) any later version; further contributions are covered by
+# the GNU Affero General Public license version 3 or (at your option)
+# any later version.  The license notices for the AGPL and the GPL follow.
+#
 # Savane is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
 # published by the Free Software Foundation, either version 3 of the
@@ -22,6 +29,19 @@
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# Savane is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as
+# published by the Free Software Foundation, either version 3 of the
+# License, or (at your option) any later version.
+#
+# Savane is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 # There are parameters that defined before, in the pages that include browse.
 
@@ -156,13 +176,13 @@ foreach ($url_params as $field => $value_id)
       {
         if ($advsrch)
           {
-            $co_field = "${field}_end";
+            $co_field = "{$field}_end";
             $names =
               ['preg' => [[$field, $co_field, '/^\d{4}-\d{1,2}-\d{1,2}$/']]];
           }
         else
           {
-            $co_field = "${field}_op";
+            $co_field = "{$field}_op";
             $names = ['strings' => [[$co_field, trackers_date_op_list ()]]];
           }
         $in = sane_import ('request', $names);
@@ -195,9 +215,9 @@ if ($history_search)
 # $msort = 1 if multicolumn sort activated.
 #
 # if morder not defined then reuse the one in preferences.
-$order_pref = "${preference_prefix}_browse_order$group_id";
-$report_pref = "${preference_prefix}_browse_report$group_id";
-$cust_pref = "${preference_prefix}_brow_cust$group_id";
+$order_pref = "{$preference_prefix}_browse_order$group_id";
+$report_pref = "{$preference_prefix}_browse_report$group_id";
+$cust_pref = "{$preference_prefix}_brow_cust$group_id";
 if (user_isloggedin () && !isset ($morder))
   $morder = user_get_preference ($order_pref);
 
@@ -234,7 +254,7 @@ if (user_isloggedin ())
 
 # If the report type is not defined then get it from group preferences.
 if (!$report_id)
-  $report_id = group_get_preference ($group_id, "${art}_default_query");
+  $report_id = group_get_preference ($group_id, "{$art}_default_query");
 
 if (!$report_id)
   $report_id = 100; # Fallback to 'Basic' report.
@@ -447,7 +467,7 @@ foreach ($url_params as $field => $value_id)
         if ($advsrch)
           {
             list ($time_end, $ok_end) =
-              utils_date_to_unixtime ($url_params["${field}_end"]);
+              utils_date_to_unixtime ($url_params["{$field}_end"]);
             if ($ok)
               {
                 $where .= " AND $art.$field >= ?";
@@ -463,7 +483,7 @@ foreach ($url_params as $field => $value_id)
           }
         else
           {
-            $operator = $url_params["${field}_op"][0];
+            $operator = $url_params["{$field}_op"][0];
             if ($operator == '*')
               $field_defined = ''; # Allow undefined dates in this case.
             elseif ($operator == '=')
@@ -585,9 +605,9 @@ while ($field = trackers_list_all_fields ('cmp_place_query'))
         $boxes .= "\n<tr align=\"$align\" valign='top'>";
       }
 
-    $labels .= '<td>'
-      . trackers_field_label_display ($field, $group_id, false, false)
-      . "</td>\n";
+    $labels .= '<td><span class="smaller">'
+      . trackers_field_label_display ($field, $group_id)
+      . "</span></td>\n";
     $boxes .= '<td><span class="smaller">';
 
     if (trackers_data_is_select_box ($field))
@@ -609,13 +629,13 @@ while ($field = trackers_list_all_fields ('cmp_place_query'))
     elseif (trackers_data_is_date_field ($field))
       {
         $end_value = '';
-        if (isset ($url_params["${field}_end"]))
-          $end_value = $url_params["${field}_end"];
+        if (isset ($url_params["{$field}_end"]))
+          $end_value = $url_params["{$field}_end"];
 
         $op_value = '';
-        if (isset ($url_params["${field}_op"])
-            && isset ($url_params["${field}_op"][0]))
-          $op_value = $url_params["${field}_op"][0];
+        if (isset ($url_params["{$field}_op"])
+            && isset ($url_params["{$field}_op"][0]))
+          $op_value = $url_params["{$field}_op"][0];
 
         $value = '';
         if (isset ($url_params[$field]) && isset ($url_params[$field][0]))
@@ -785,7 +805,7 @@ while ($field = trackers_list_all_fields ('cmp_place_result'))
     $where .= " AND user_$field.user_id = $art.$field ";
   } # while ($field = trackers_list_all_fields ('cmp_place_result'))
 
-$art_h = "${art}_history";
+$art_h = "{$art}_history";
 
 $froms_count = $froms;
 $froms_count[] = $art;
@@ -865,12 +885,10 @@ while ($thisarray = db_fetch_array ($result))
   {
     if (!isset ($thisarray['bug_id']))
       {
-        $error_msg =
-          'trackers_run/browse.php: no bug_id in result; $thisarray: ';
+        $error_msg = 'no bug_id in result; $thisarray: ';
         foreach ($thisarray as $idx => $val)
           $error_msg .= " [$idx] => '$val'";
-        $error_msg .= "; URI: '" . ($_SERVER['REQUEST_URI']) . "'";
-        error_log ($error_msg);
+        trigger_error ($error_msg);
       }
     # Get the id.
     $thisitem_id = $thisarray['bug_id'];
