@@ -1,14 +1,22 @@
 <?php
 # Modify items.
 #
-# Copyright 1999-2000 The SourceForge Crew
-# Copyright 2001-2002 Laurent Julliard, CodeX Team, Xerox
-# Copyright 2002-2006 Mathieu Roy <yeupou--gnu.org>
-# Copyright 2002-2006 Yves Perrin <yves.perrin--cern.ch>
-# Copyright 2017, 2018, 2020, 2022 Ineiev
+# Copyright (C) 1999, 2000 The SourceForge Crew
+# Copyright (C) 2001, 2002 Laurent Julliard, CodeX Team, Xerox
+# Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
+# Copyright (C) 2002-2006 Yves Perrin <yves.perrin--cern.ch>
+# Copyright (C) 2014, 2016, 2017 Assaf Gordon
+# Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
+# Copyright (C) 2013, 2014, 2017-2023 Ineiev
 #
 # This file is part of Savane.
 #
+# Code written before 2008-03-30 (commit 8b757b2565ff) is distributed
+# under the terms of the GNU General Public license version 3 or (at your
+# option) any later version; further contributions are covered by
+# the GNU Affero General Public license version 3 or (at your option)
+# any later version.  The license notices for the AGPL and the GPL follow.
+#
 # Savane is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
 # published by the Free Software Foundation, either version 3 of the
@@ -21,6 +29,19 @@
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# Savane is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as
+# published by the Free Software Foundation, either version 3 of the
+# License, or (at your option) any later version.
+#
+# Savane is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 $dirname = dirname (__FILE__);
 require_once ("$dirname/../trackers/show.php");
@@ -54,7 +75,7 @@ $item_discussion_lock = $res_arr['discussion_lock'];
 $enable_comments = !$item_discussion_lock || $is_trackeradmin;
 $preambles = [];
 foreach (['comment', 'file'] as $pre)
-  $preambles[] = ARTIFACT . "_${pre}_preamble";
+  $preambles[] = ARTIFACT . "_{$pre}_preamble";
 
 $preambles = group_get_preference  ($group_id, $preambles);
 
@@ -85,8 +106,8 @@ if ($res_arr['privacy'] == "2")
           . "allowed to read private items.")
       );
   }
-# Check if it is possible for the current user to post a comment.
-if (!group_restrictions_check ($group_id, ARTIFACT, 2))
+
+if (!group_restrictions_check ($group_id, ARTIFACT, TRACKER_EVENT_COMMENT))
   {
     $private_intro .= ' '
        . _("You are not allowed to post comments on this tracker "
@@ -260,7 +281,7 @@ while ($field_name = trackers_list_all_fields ())
                 $$field_name = mktime (0, 0, 0, $mn, $dy, $yr);
               }
           }
-        $field_value = htmlspecialchars ($$field_name);
+        $field_value = utils_specialchars ($$field_name);
       }
     list ($sz,) = trackers_data_get_display_size ($field_name);
     $label = trackers_field_label_display ($field_name, $group_id,
@@ -280,21 +301,20 @@ while ($field_name = trackers_list_all_fields ())
     # assigned_to, status_id and priority too, for technicians
     # (if super_user, do nothing).
     if (!$is_manager
-        && ($field_name == 'status_id'
-            || $field_name == 'assigned_to'
-            || $field_name == 'priority'
-            || $field_name == 'originator_email'))
+        && (in_array ($field_name,
+            ['status_id', 'assigned_to', 'priority', 'originator_email'])))
       {
         $value = trackers_field_display ($field_name, $group_id, $field_value,
-                                        false, false, true);
+          false, false, true
+        );
         if ($field_name == 'originator_email')
           $value = utils_email_basic ($value);
       }
     else
       $value = trackers_field_display ($field_name, $group_id, $field_value,
-                                      false, false, $ro_fields, false, false,
-                                      _("None"), false,
-                                      _("Any"), true);
+        false, false, $ro_fields, false, false, _("None"), false, _("Any"),
+        true
+      );
 
     # Check if the field is mandatory.
     $star = '';
@@ -511,7 +531,7 @@ if ($enable_comments)
       . ' ' . markup_info ("rich");
     print form_submit (_('Preview'), 'preview')
       . "</span><br />&nbsp;&nbsp;&nbsp;\n";
-    print trackers_field_textarea ('comment', htmlspecialchars ($comment),
+    print trackers_field_textarea ('comment', utils_specialchars ($comment),
       0, 0, _("New comment"));
     print "</p>\n";
     print_comment_type_and_canned ($group_id, $canned_response,
@@ -546,7 +566,7 @@ if ($preview)
         );
     $comm = $comment . $canned_text;
     if (!empty ($comm))
-      $comm = trackers_encode_value (htmlspecialchars ($comm));
+      $comm = trackers_encode_value (utils_specialchars ($comm));
     $new_comment['old_value'] = $comm;
     $new_comment['bug_history_id'] = -1;
     $new_comment['spamscore'] = '0';
@@ -688,7 +708,7 @@ if ($is_trackeradmin)
         printf (
           _("Please select a dependency to add in the result of your search\n"
             . "of '%s' in the database:"),
-          htmlspecialchars ($depends_search)
+          utils_specialchars ($depends_search)
         );
         print '</span>';
 
@@ -777,13 +797,13 @@ if (user_isloggedin() && !$item_discussion_lock)
       . "<p class='noprint'><span class='preinput'><label for='add_cc'>"
       . _("Add Email Addresses (comma as separator):")
       . "</label></span><br />\n&nbsp;&nbsp;&nbsp;"
-      . '<input type="text" id="add_cc" name="add_cc" size="40" value="'
-      . htmlspecialchars ($add_cc) . '" />&nbsp;&nbsp;&nbsp;'
+      . form_input ('text', 'add_cc', $add_cc,  'size="40"')
+      . '&nbsp;&nbsp;&nbsp;'
       . "\n<br />\n<span class='preinput'><label for='cc_comment'>"
       . _("Comment:") . "</label></span><br />\n&nbsp;&nbsp;&nbsp;"
-      . '<input type="text" id="cc_comment" name="cc_comment" '
-      . 'size="40" maxlength="255" value="'
-      . htmlspecialchars ($cc_comment) . '" />';
+      . form_input ('text', "cc_comment", $cc_comment,
+          'size="40" maxlength="255"')
+      . "\n";
     print "<p>&nbsp;</p>\n";
   }
 show_item_cc_list ($item_id, $group_id);
@@ -921,7 +941,7 @@ if ($check_member ($group_id, ARTIFACT, '3') && ARTIFACT != "cookbook")
         printf (
           _("To which project this bug should be reassigned to? This is\n"
             . "the result of your search of '%s' in the database:"),
-          htmlspecialchars ($reassign_change_project_search));
+          utils_specialchars ($reassign_change_project_search));
         print '</span>';
 
         # Print a null-option, someone may change his mine without having
