@@ -1,12 +1,20 @@
 <?php
 # User-related functions.
 #
-# Copyright (C) 1999-2000 The SourceForge Crew
-# Copyright (C) 2004-2006 Mathieu Roy <yeupou--gnu.org>
-# Copyright (C) 2017, 2019, 2020, 2023 Ineiev
+# Copyright (C) 1999, 2000 The SourceForge Crew
+# Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
+# Copyright (C) 2014, 2016, 2017 Assaf Gordon
+# Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
+# Copyright (C) 2013, 2014, 2017-2023 Ineiev
 #
 # This file is part of Savane.
 #
+# Code written before 2008-03-30 (commit 8b757b2565ff) is distributed
+# under the terms of the GNU General Public license version 3 or (at your
+# option) any later version; further contributions are covered by
+# the GNU Affero General Public license version 3 or (at your option)
+# any later version.  The license notices for the AGPL and the GPL follow.
+#
 # Savane is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
 # published by the Free Software Foundation, either version 3 of the
@@ -19,6 +27,19 @@
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# Savane is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as
+# published by the Free Software Foundation, either version 3 of the
+# License, or (at your option) any later version.
+#
+# Savane is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 require_once (dirname (__FILE__) . '/member.php');
 
@@ -89,8 +110,9 @@ function user_get_email ($uid)
 
 function user_getname ($user_id = 0, $getrealname = 0)
 {
-  global $G_USER,$USER_NAMES;
+  global $G_USER, $USER_NAMES;
 
+  # Use current user if one is not passed in.
   if (!$user_id && $getrealname)
     $user_id = user_getid ();
 
@@ -101,21 +123,16 @@ function user_getname ($user_id = 0, $getrealname = 0)
       $prefix = 'user';
       $column = 'user_name';
     }
-  # Use current user if one is not passed in.
-  if (!$user_id && !$getrealname)
+  if (!$user_id)
    {
+      if ($getrealname)
+        return _("anonymous");
       if ($G_USER)
         return $G_USER['user_name'];
       # TRANSLATORS: "Not applicable".
       return _("NA");
    }
 
-  if (!$user_id)
-    {
-      if (!$getrealname)
-        return _("NA");
-      return _("anonymous");
-    }
   # Lookup name.
   if (!empty ($USER_NAMES["{$prefix}_$user_id"]))
     return $USER_NAMES["{$prefix}_$user_id"];
@@ -124,7 +141,7 @@ function user_getname ($user_id = 0, $getrealname = 0)
     SELECT user_id, user_name, realname FROM user WHERE user_id = ?",
     [$user_id]
   );
-  if (db_numrows ($result) > 0)
+  if (db_numrows ($result))
     {
       # Valid user - store and return.
       $USER_NAMES["{$prefix}_$user_id"] = db_result ($result, 0, $column);
@@ -416,12 +433,21 @@ function user_has_history ($user_id)
   return db_numrows ($result) > 0;
 }
 
+# Delete user's data that are not stored in the 'user' table.
+function user_delete_aux_data ($user_id)
+{
+  foreach (['user_group', 'user_squad', 'user_bookmarks', 'user_preferences',
+    'user_votes', 'session'] as $table)
+    db_execute ("DELETE FROM $table WHERE user_id = ?", [$user_id]);
+}
+
 # Completely remove account from the database; should only be done
 # when there was no activity related to the account on trackers
 # and in group_history.
 function user_purge ($user_id)
 {
   db_execute ("DELETE FROM user where user_id = ?", [$user_id]);
+  user_delete_aux_data ($user_id);
 }
 
 # Rename account, with necessary history adjustments in the database (unless
@@ -501,22 +527,113 @@ function user_delete ($user_id = false, $confirm_hash = false)
       fb (_("Failed to update the database."), 1);
       return false;
     }
-  # Remove from any groups, if by any chances this was not done before
-  # (normally, an user must quit groups before being allowed to delete his
-  # account).
-  db_execute ("DELETE FROM user_group WHERE user_id = ?", [$user_id]);
-  db_execute ("DELETE FROM user_squad WHERE user_id = ?", [$user_id]);
-
-  # Additionally, clean up sessions, remove prefs.
-  db_execute ("DELETE FROM user_bookmarks WHERE user_id = ?", [$user_id]);
-  db_execute ("DELETE FROM user_preferences WHERE user_id = ?", [$user_id]);
-  db_execute ("DELETE FROM user_votes WHERE user_id = ?", [$user_id]);
-  db_execute ("DELETE FROM session WHERE user_id = ?", [$user_id]);
+  user_delete_aux_data ($user_id);
   # Rename user; the name starts with '_' so it can't be registered manually,
   # and it shall be unique because it's derived from $user_id.
   user_rename ($user_id, "_$user_id");
-
   fb (_("Account deleted."));
   return true;
 }
+
+# List groups where we can track date of inclusion; private groups
+# are not filtered out.
+function user_list_groups_with_history ($uid, $skip)
+{
+  return db_execute ("
+    SELECT
+      g.group_name, g.group_id, g.unix_group_name, g.is_public,
+      u.admin_flags, h.date
+    FROM groups g, user_group u, group_history h, user a
+    WHERE
+      g.group_id = u.group_id AND h.group_id = u.group_id $skip
+      AND u.user_id = ? AND a.user_id = ? AND h.old_value = a.user_name
+      AND g.status = 'A' AND h.field_name IN ('Added User', 'Approved User')
+    GROUP BY g.group_id ORDER BY g.group_id", [$uid, $uid]
+  );
+}
+
+# Like user_list_group_with_history, but based only on actual membership.
+function user_list_groups_without_history ($uid, $skip)
+{
+  return db_execute ("
+    SELECT g.group_name, g.group_id, g.unix_group_name, g.is_public,
+      u.admin_flags, 0 as date
+    FROM groups g, user_group u
+    WHERE g.group_id = u.group_id AND u.user_id = ? AND g.status = 'A' $skip
+    GROUP BY g.group_id ORDER BY g.group_id", [$uid]
+  );
+}
+
+# Merge results of user_list_groups_with_history
+# and user_list_group_without_history into an array.
+function user_list_merge_row (&$ret, &$row)
+{
+  if (array_key_exists ($row['group_id'], $ret))
+    return;
+  $fields = [
+    'group_name', 'unix_group_name', 'date', 'admin_flags', 'is_public'
+  ];
+  $ret[$row['group_id']] = [];
+  foreach ($fields as $f)
+    $ret[$row['group_id']][$f] = $row[$f];
+}
+
+# Auxiliary function used in user_list_groups.
+function user_enumerate_groups ($uid, $skip_pending)
+{
+  $skip = $skip_pending? "AND u.admin_flags != 'P'": "";
+  $ret = [];
+  $result = user_list_groups_with_history ($uid, $skip);
+  while ($row = db_fetch_array ($result))
+    user_list_merge_row ($ret, $row);
+  $result = user_list_groups_without_history ($uid, $skip);
+  while ($row = db_fetch_array ($result))
+    user_list_merge_row ($ret, $row);
+  return $ret;
+}
+
+# List private groups listed in $ret that the current user shouldn't see;
+# used in user_list_groups.
+function user_list_groups_to_hide (&$ret)
+{
+  $private = [];
+  foreach ($ret as $group_id => $v)
+    if (!$v['is_public'])
+      $private[] = $group_id;
+  if (empty ($private) || !user_isloggedin ())
+    return $private;
+  $gid_in = utils_in_placeholders ($private);
+  $result = db_execute ("
+    SELECT group_id FROM user_group
+    WHERE user_id = ? AND group_id $gid_in AND admin_flags != 'P'",
+    array_merge ([user_getid ()], $private)
+  );
+  $allowed = [];
+  while ($row = db_fetch_array ($result))
+    $allowed[] = $row['group_id'];
+  return array_diff ($private, $allowed);
+}
+
+# Return groups $uid belongs in allowed to show up for the current user.
+# The key is group_id, the items are arrays with keys 'group_name',
+# 'unix_group_name', 'date' (zero when unavailable), 'admin_flags'.
+function user_list_groups ($uid, $skip_pending)
+{
+  $ret = user_enumerate_groups ($uid, $skip_pending);
+  if (empty ($ret) || user_is_super_user () || $uid == user_getid ())
+    # No need to filter out private groups.
+    return $ret;
+  foreach (user_list_groups_to_hide ($ret) as $gid)
+    unset ($ret[$gid]);
+  return $ret;
+}
+
+function user_format_member_since ($date)
+{
+  if (empty ($date))
+    return '';
+  return '<span class="smaller">'
+    . sprintf (_("Member since %s"), utils_format_date ($date))
+    . '</span>';
+}
 ?>
