@@ -1,15 +1,21 @@
 <?php
 # Utility functions.
 #
-# Copyright (C) 1999-2000 The SourceForge Crew
-# Copyright (C) 2002-2006 Mathieu Roy <yeupou--gnu.org>,
+# Copyright (C) 1999, 2000 The SourceForge Crew
+# Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
 # Copyright (C) 2002-2006 Tobias Toedter <t.toedter--gmx.net>
-# Copyright (C) 2004-2007 Aidan Lister <aidan@php.net>, Arpad Ray <arpad@php.net>
-# Copyright (C) 2006, 2007, 2008, 2010 Sylvain Beucler
-# Copyright (C) 2017, 2018, 2019, 2020, 2022, 2023 Ineiev
+# Copyright (C) 2014, 2016, 2017 Assaf Gordon
+# Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
+# Copyright (C) 2013, 2014, 2017-2023 Ineiev
 #
 # This file is part of Savane.
 #
+# Code written before 2008-03-30 (commit 8b757b2565ff) is distributed
+# under the terms of the GNU General Public license version 3 or (at your
+# option) any later version; further contributions are covered by
+# the GNU Affero General Public license version 3 or (at your option)
+# any later version.  The license notices for the AGPL and the GPL follow.
+#
 # Savane is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
 # published by the Free Software Foundation, either version 3 of the
@@ -22,7 +28,20 @@
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
-
+#
+# Savane is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as
+# published by the Free Software Foundation, either version 3 of the
+# License, or (at your option) any later version.
+#
+# Savane is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+namespace {
 # Clean initialization for globals.
 $GLOBALS['feedback_count'] = 0;
 $GLOBALS['feedback'] = '';
@@ -115,8 +134,8 @@ function utils_email ($address, $nohtml = 0)
   if (preg_match ("/\<([\w\d\-\@\.]*)\>/", $address, $matches))
     $realaddress = $matches[1];
 
-  $addr = htmlspecialchars ($address);
-  $raddr = htmlspecialchars ($realaddress);
+  $addr = utils_specialchars ($address);
+  $raddr = utils_specialchars ($realaddress);
   # We have a user name.
   if (!strpos ($address, "@"))
     {
@@ -175,7 +194,7 @@ function utils_email_basic ($address, $nohtml = 0)
       || CONTEXT == '' # frontpage
   )
     {
-      $addr = htmlspecialchars ($address);
+      $addr = utils_specialchars ($address);
       if ($nohtml)
         return $addr;
       # Make mailto without trying to find out whether it makes sense.
@@ -214,6 +233,15 @@ function utils_cutstring ($string, $length = 35)
   return $string;
 }
 
+function utils_utils_strftime ($timestamp, $format)
+{
+  $env['LC_ALL'] = setlocale (LC_TIME, 0);
+  $cmd = "date +$format -d @$timestamp";
+  utils_run_proc ($cmd, $output, $error, ['env' => $env]);
+  $output = substr ($output, 0, -1); # Drop trailing "\n".
+  return $output;
+}
+
 if (function_exists ("strftime"))
   {
     # Used until strftime is dropped from PHP.
@@ -230,19 +258,7 @@ else # !function_exists ("strftime")
     # Fallback for the PHP versions (> 8.1) when no strftime is provided.
     function utils_strftime ($timestamp, $format)
     {
-      $env = $_ENV;
-      $env['LC_ALL'] = setlocale (LC_TIME, 0);
-      $d_spec = [
-        0 => array ("pipe", "r"), 1 => array ("pipe", "w"),
-        2 => array ("pipe", "w")
-      ];
-      $cmd = "date +$format -d @$timestamp";
-      $date_proc = proc_open ($cmd, $d_spec, $pipes, NULL, $env);
-      $output = stream_get_contents ($pipes[1]);
-      fclose ($pipes[1]); fclose ($pipes[2]);
-      proc_close ($date_proc);
-      $output = substr ($output, 0, strlen ($output) - 1); # Drop trailing "\n".
-      return $output;
+      return utils_utils_strftime ($timestamp, $format);
     }
   } # !function_exists ("strftime")
 
@@ -385,7 +401,8 @@ function utils_unconvert_htmlspecialchars ($string)
   if (strlen ($string) < 1)
     return '';
   return str_replace (
-    ['&nbsp;', '&quot;', '&gt;', '&lt;', '&amp;'], [' ', '"', '>', '<', '&',],
+    ['&nbsp;', '&quot;', '&gt;', '&lt;', '&#039;', '&apos;',  '&amp;'],
+    [' ',      '"',      '>',    '<',     "'",      "'",      '&'],
     $string
   );
 }
@@ -402,7 +419,7 @@ function utils_result_column_to_array ($result, $col = 0, $localize = false)
     {
       $val = db_result ($result, $i, $col);
       if ($localize)
-        $val = htmlentities (gettext ($val));
+        $val = utils_specialchars (gettext ($val));
       $arr[$i] = $val;
     }
   return $arr;
@@ -422,7 +439,7 @@ function utils_user_link ($username, $realname = false, $noneisanonymous = false
       # TRANSLATORS: anonymous user.
       return _("Anonymous");
     }
-  $re = "<a href=\"${sys_home}users/$username\">";
+  $re = "<a href=\"{$sys_home}users/$username\">";
   if ($realname)
     $re .= "$realname &lt;$username&gt;";
   else
@@ -680,12 +697,9 @@ function temp_dbg ($msg)
 # Die with debug information.
 function util_die ($msg)
 {
-  $backtrace = debug_backtrace ();
-  array_shift ($backtrace);
-  error_log ( "util_die: $msg ::: backtrace: "
-    . utils_debug_print_mybacktrace ($backtrace, false)
-  );
-  if (!$GLOBALS['sys_debug_on'])
+  trigger_error ($msg);
+  $msg = utils_specialchars ($msg);
+  if (empty ($GLOBALS['sys_debug_on']))
     die ($msg);
   print "<strong>Fatal error:</strong> $msg<br />";
   print '<pre>';
@@ -694,71 +708,6 @@ function util_die ($msg)
   die ();
 }
 
-#  Modified to print any given backtrace.
-#  Original comments:
-#  Replace debug_print_backtrace()
-#
-#  @category    PHP
-#  @package     PHP_Compat
-#  @license     LGPL - http://www.gnu.org/licenses/lgpl.html
-#  @copyright   2004-2007 Aidan Lister <aidan@php.net>, Arpad Ray <arpad@php.net>
-#  @link        http://php.net/function.debug_print_backtrace
-#  @author      Laurent Laville <pear@laurent-laville.org>
-#  @author      Aidan Lister <aidan@php.net>
-#  @version     $Revision: 1.6 $
-#  @since       PHP 5
-#  @require     PHP 4.3.0 (debug_backtrace)
-function utils_debug_print_mybacktrace ($backtrace = null, $print = true)
-{
-  # Get backtrace.
-  if ($backtrace === null)
-    {
-      $backtrace = debug_backtrace ();
-      # Unset call to debug_print_backtrace.
-      array_shift ($backtrace);
-    }
-
-  if (empty ($backtrace))
-    return '';
-
-  $calls = [];
-  foreach ($backtrace as $i => $call)
-    {
-      if (!isset ($call['file']))
-        $call['file'] = '(null)';
-      if (!isset ($call['line']))
-        $call['line'] = '0';
-      $location = $call['file'] . ':' . $call['line'];
-      $function = (isset ($call['class'])) ?
-      $call['class'] . (isset ($call['type']) ? $call['type'] : '.')
-        . $call['function'] :
-      $call['function'];
-
-      $params = '';
-      if (isset ($call['args']))
-        {
-          $args = [];
-          foreach ($call['args'] as $arg)
-            {
-              if (is_array ($arg))
-                $args[] = print_r ($arg, true);
-              elseif (is_object ($arg))
-                $args[] = get_class ($arg);
-              else
-                $args[] = $arg;
-            }
-          $params = implode (', ', $args);
-        }
-      $calls[] = sprintf (
-        '#%d  %s(%s) called at [%s]', $i, $function, $params, $location
-      );
-    }
-  $ret = join ("\n", $calls) . "\n";
-  if ($print)
-    print $ret;
-  return $ret;
-}
-
 function util_feedback ($msg, $error = 0)
 {
   fb ($msg, $error);
@@ -850,24 +799,93 @@ function utils_set_csp_headers ()
   header ($policy);
 }
 
-# Run a command $cmd, return its exit code; put its output and error streams
-# to $out and $err.
-function utils_run_proc ($cmd, &$out, &$err)
+} # namespace {
+
+namespace utils_run_proc_ns {
+function dispatch_error ($cmd, $code, $err, $log_error, $in)
+{
+  if (!$code || !$log_error)
+    return;
+  $msg = "$cmd failed ($code): $err";
+  if (!empty ($in))
+    $msg .= "\n  with input:\n$in";
+  trigger_error ($msg);
+}
+
+function init_aux ($aux)
+{
+  $in = null; $log_error = false;
+  if (!empty ($aux['in']))
+    $in = $aux['in'];
+  if (!empty ($aux['log_error']))
+    $log_error = true;
+  $env = $_ENV;
+  if (!empty ($aux['env']))
+    foreach ($aux['env'] as $k => $v)
+      $env[$k] = $v;
+  return  [$in, $env, $log_error];
+}
+
+function close_pipes ($pipes, $proc)
+{
+  for ($i = 0; $i < 3; $i++)
+    fclose ($pipes[$i]);
+  proc_close ($proc);
+}
+
+function p_open ($cmd, $env, $log_error)
 {
   $d_spec = [0 => ["pipe", "r"], 1 => ["pipe", "w"], 2 => ["pipe", "w"]];
+  $proc = proc_open ($cmd, $d_spec, $pipes, NULL, $env);
+  if ($proc !== false)
+    return [null, '', $pipes, $proc];
+  $err = "can't run $cmd\n";
+  utils_run_proc_ns\dispatch_error ($cmd, -1, $err, $log_error);
+  return ['fail', $err, null, null];
+}
 
+function write ($fd, $in, $cmd, $log_error)
+{
+  if (empty ($in))
+    return [null, ''];
+  $ns = fwrite ($fd, $in);
+  $len = strlen ($in);
+  if ($ns === $len)
+    return [null, ''];
+  if ($ns === false)
+    $err = "$cmd: can't pass input data\n";
+  else
+    $err = "$cmd: can't pass input data; wrote $ns of $len bytes\n";
+  return ['fail', $err];
+}
+} # namespace utils_run_proc_ns
+
+namespace {
+# Run a command $cmd, return its exit code; put its output and error streams
+# to $out and $err; in $aux, ['in'] enters to stdin, ['env'] modifies
+# the environment, if ['log_error'], errors are logged.
+function utils_run_proc ($cmd, &$out, &$err, $aux = [])
+{
+  list ($in, $env, $log_error) = utils_run_proc_ns\init_aux ($aux);
   $out = null;
-  $proc = proc_open ($cmd, $d_spec, $pipes, NULL, $_ENV);
-  if ($proc === false)
+  list ($ret, $err, $pipes, $proc) =
+    utils_run_proc_ns\p_open ($cmd, $env, $log_error);
+  if (!empty ($ret))
+    return $ret;
+  list ($ret, $err) =
+    utils_run_proc_ns\write ($pipes[0], $in, $cmd, $log_error);
+  if (!empty ($ret))
     {
-      $err = "can't run $cmd\n";
-      return -1;
+      utils_run_proc_ns\close_pipes ($pipes, $proc);
+      return $ret;
     }
   fclose ($pipes[0]);
   $out = stream_get_contents ($pipes[1]);
   $err = stream_get_contents ($pipes[2]);
   fclose ($pipes[1]); fclose ($pipes[2]);
-  return proc_close ($proc);
+  $res = proc_close ($proc);
+  utils_run_proc_ns\dispatch_error ($cmd, $res, $err, $log_error, $in);
+  return $res;
 }
 
 # Try to move $tmp_path to $path without overwriting if the latter exists;
@@ -887,6 +905,34 @@ function utils_try_move ($tmp_path, $path)
   return $path;
 }
 
+function utils_mktemp ($template, $type = 'file')
+{
+  $cmd = "mktemp --tmpdir ";
+  if ($type !== 'file')
+    {
+      $type = 'dir';
+      $cmd .= "-d ";
+    }
+  $is_func = "is_$type";
+  $cmd .= $template;
+  $res = utils_run_proc ($cmd, $out, $err);
+  if ($res)
+    {
+      trigger_error ("$cmd failed, $res: $err");
+      return null;
+    }
+  $out = trim ($out);
+  if ($is_func ($out))
+    return $out;
+  trigger_error ("$cmd failed: no $out $type");
+  return null;
+}
+
+function utils_rm_fr ($dir)
+{
+  exec ("rm -fr $dir");
+}
+
 # Make a file with a name based on $tarball_name in $sys_upload_dir without
 # overwriting existing files; the new file name is $tarball_name unless
 # such file already exists, otherwise a name based on a template is used.
@@ -919,6 +965,11 @@ function utils_str_join ($separator, $str, $n)
   return str_repeat ("$str$separator", $n - 1) . $str;
 }
 
+function utils_srand ()
+{
+  mt_srand ((int)((double)microtime () * 1000000));
+}
+
 function utils_placeholders ($array)
 {
   return utils_str_join (', ', '?', count ($array));
@@ -945,4 +996,32 @@ function utils_comply_with_rfc822 ($string)
     return "\"$string\"";
   return $string;
 }
+
+# Work-around PHP 8.1 deprecation of null parameter #1 and change of defaults
+# for parameter #2.
+function utils_specialchars ($string, $flags = ENT_COMPAT)
+{
+  if ($string === null)
+    $string = '';
+  return htmlspecialchars ($string, $flags, 'UTF-8');
+}
+function utils_specialchars_decode ($string, $flags = ENT_COMPAT)
+{
+  if ($string === null)
+    $string = '';
+  return htmlspecialchars_decode ($string, $flags);
+}
+function utils_htmlentities ($string, $flags = ENT_COMPAT)
+{
+  if ($string === null)
+    $string = '';
+  return htmlentities ($string, $flags, 'UTF-8');
+}
+function utils_urlencode ($string)
+{
+  if ($string === null)
+    $string = '';
+  return urlencode ($string);
+}
+} # namespace {
 ?>
