@@ -1,14 +1,21 @@
 <?php
 # Generate show/hide JavaScript code.
 #
-# Copyright (C) 1999-2000 The SourceForge Crew
-# Copyright (C) 2002-2006 Mathieu Roy <yeupou--gnu.org>
+# Copyright (C) 1999, 2000 The SourceForge Crew
+# Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
 # Copyright (C) 2002-2006 Pogonyshev <pogonyshev--gmx.net>
-# Copyright (C) 2007, 2008  Sylvain Beucler
-# Copyright (C) 2018, 2022 Ineiev <ineiev--gnu.org>
+# Copyright (C) 2014, 2016, 2017 Assaf Gordon
+# Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
+# Copyright (C) 2013, 2014, 2017-2023 Ineiev <ineiev@gnu.org>
 #
 # This file is part of Savane.
 #
+# Code written before 2008-03-30 (commit 8b757b2565ff) is distributed
+# under the terms of the GNU General Public license version 3 or (at your
+# option) any later version; further contributions are covered by
+# the GNU Affero General Public license version 3 or (at your option)
+# any later version.  The license notices for the AGPL and the GPL follow.
+#
 # Savane is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
 # published by the Free Software Foundation, either version 3 of the
@@ -21,11 +28,24 @@
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# Savane is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as
+# published by the Free Software Foundation, either version 3 of the
+# License, or (at your option) any later version.
+#
+# Savane is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-require_once('../include/sane.php');
-header('Content-Type: text/javascript');
+require_once ('../include/sane.php');
+header ('Content-Type: text/javascript');
 
-extract(sane_import('request',
+extract (sane_import('request',
   [
     'digits' => 'deploy',
     'preg' => [['box_id', 'suffix', '/^\w*$/']],
@@ -43,15 +63,14 @@ foreach (
   as $k => $v
 )
   {
-    $$k = "${box_id}$v$suffix";
-    ${"${k}_el"} = "document.getElementById('{$$k}')";
+    $$k = "{$box_id}$v$suffix";
+    ${"{$k}_el"} = "document.getElementById('{$$k}')";
   }
 
 $sign_func = function ($sign, $id, $legend)
 {
   return "<span class=\"show-hide\" id=\"$id\">"
-   . "<span class=\"minusorplus\">($sign)</span>"
-   . htmlspecialchars ($legend, ENT_QUOTES) . "</span>";
+   . "<span class=\"minusorplus\">($sign)</span>$legend</span>";
 };
 print "document.write('"
   .  $sign_func ('-', $hide, $legend) .  $sign_func ('+', $show, $legend)
