@@ -1,26 +1,46 @@
 <?php # -*- PHP -*-
 # User homepage.
-# 
-# Copyright (C) 1999-2000 The SourceForge Crew
-# Copyright (C) 2000-2003 Free Software Foundation
-# Copyright (C) 2002-2006 Mathieu Roy <yeupou--gnu.org>
-# Copyright (C) 2007 Sylvain Beucler
-# Copyright (C) 2017, 2018, 2019, 2022, 2023 Ineiev
+#
+# Copyright (C) 1999, 2000 The SourceForge Crew
+# Copyright (C) 2000-2006 Free Software Foundation, Inc.
+# Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
+# Copyright (C) 2014, 2016, 2017 Assaf Gordon
+# Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
+# Copyright (C) 2013, 2014, 2017-2023 Ineiev
 #
 # This file is part of Savane.
-# 
+#
+# Code written before 2008-03-30 (commit 8b757b2565ff) is distributed
+# under the terms of the GNU General Public license version 3 or (at your
+# option) any later version; further contributions are covered by
+# the GNU Affero General Public license version 3 or (at your option)
+# any later version.  The license notices for the AGPL and the GPL follow.
+#
 # Savane is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
 # published by the Free Software Foundation, either version 3 of the
 # License, or (at your option) any later version.
-# 
+#
 # Savane is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU Affero General Public License for more details.
-# 
+#
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# Savane is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as
+# published by the Free Software Foundation, either version 3 of the
+# License, or (at your option) any later version.
+#
+# Savane is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 # The context of this page cannot be guessed later, we have to hardcode it
 define ('CONTEXT', 'people');
@@ -199,64 +219,33 @@ if ($is_suspended)
     exit (0);
   }
 
-print "<br />\n";
-
-print $HTML->box_top (_("Group Information"), '', 1);
-$result = db_execute ("
-  SELECT g.group_name, g.group_id, g.unix_group_name, h.date
-  FROM groups g, user_group u, group_history h
-  WHERE
-    g.group_id = u.group_id AND h.group_id = u.group_id AND u.user_id = ?
-    AND g.status = 'A' AND g.is_public = '1' AND h.old_value = ?
-    AND h.field_name IN ('Added User', 'Approved User')
-  GROUP BY g.unix_group_name ORDER BY g.unix_group_name",
-  [$user_id, db_result ($res_user, 0, 'user_name')]
-);
-$rows = db_numrows ($result);
-
-# Alternative SQL that do not use group_history, just in case this history
-# would be flawed (history usage has been inconsistent over Savane history).
-$result_without_history = db_execute ("
-  SELECT g.group_name, g.group_id, g.unix_group_name, 0 as date
-  FROM groups g, user_group u
-  WHERE
-    g.group_id = u.group_id AND u.user_id = ?
-    AND g.status = 'A' AND g.is_public = '1' AND u.admin_flags != 'P'
-  GROUP BY g.unix_group_name ORDER BY g.unix_group_name", [$user_id]
-);
-$rows_without_history = db_numrows ($result_without_history);
-
-# The history may be broken due to an old install &c.
-$history_is_flawed = false;
-if ($rows_without_history != $rows)
+function output_group_info ($user_id)
+{
+  global $HTML;
+  $group_list = user_list_groups ($user_id, true);
+  if (empty ($group_list))
+    return;
+  print "<br />\n";
+  print $HTML->box_top (_("Group Information"), '', 1);
+  print "<ul class='boxli'>";
+  $j = 1;
+  foreach ($group_list as $gid => $v)
   {
-    # If number of rows differ, assume that history is flawed.
-    $result = $result_without_history;
-    $rows = $rows_without_history;
-    $history_is_flawed = true;
+    if ($v['admin_flags'] == 'A')
+      $color = "boxhighlight";
+    else
+      $color = utils_altrow ($j++);
+    print '<li class="' . $color . '">';
+    print "<a href=\"{$GLOBALS['sys_home']}projects/"
+       . $v['unix_group_name'] . '/">' . $v['group_name'] . "</a><br />\n";
+    print user_format_member_since ($v['date']);
+    print "</li>\n";
   }
-$j = 1;
-$items = '';
-for ($i = 0; $i < $rows; $i++)
-  {
-    $items .= '<li class="' . utils_altrow ($j++) . '">';
-    $items .= "<a href=\"{$GLOBALS['sys_home']}projects/"
-       . db_result ($result, $i, 'unix_group_name') . '/">'
-       . db_result ($result, $i, 'group_name') . "</a><br />\n";
-    $date_joined = db_result ($result, $i, 'date');
-    if ($date_joined)
-      {
-        $items .= '<span class="smaller">'
-         . sprintf (_("Member since %s"), utils_format_date ($date_joined))
-         . '</span>';
-      }
-    $items .= "</li>\n";
-  }
-if ($items === '')
-  print _("This user is not a member of any group.");
-else
-  print "<ul class='boxli'>$items</ul>\n";
-print $HTML->box_bottom (1);
+  print "</ul>\n";
+  print $HTML->box_bottom (1);
+}
+
+output_group_info ($user_id);
 
 # List of squad members, if appliable.
 if ($is_squad)
