@@ -1,15 +1,22 @@
 <?php
 # Generic user settings editor.
 #
-# Copyright (C) 1999-2000 The SourceForge Crew
-# Copyright (C) 2003-2006 Mathieu Roy <yeupou--gnu.org>
-# Copyright (C) 2003-2006 Yves Perrin <yves.perrin--cern.ch>
-# Copyright (C) 2007, 2013 Sylvain Beucler
-# Copyright (C) 2016 Karl Berry
-# Copyright (C) 2017, 2018, 2020, 2021, 2022, 2023 Ineiev
+# Copyright (C) 1999, 2000 The SourceForge Crew
+# Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
+# Copyright (C) 2002-2006 Yves Perrin <yves.perrin--cern.ch>
+# Copyright (C) 2014, 2016, 2017 Assaf Gordon
+# Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
+# Copyright (C) 2008-2017, 2020 Karl Berry
+# Copyright (C) 2013, 2014, 2017-2023 Ineiev
 #
 # This file is part of Savane.
 #
+# Code written before 2008-03-30 (commit 8b757b2565ff) is distributed
+# under the terms of the GNU General Public license version 3 or (at your
+# option) any later version; further contributions are covered by
+# the GNU Affero General Public license version 3 or (at your option)
+# any later version.  The license notices for the AGPL and the GPL follow.
+#
 # Savane is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
 # published by the Free Software Foundation, either version 3 of the
@@ -22,6 +29,19 @@
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# Savane is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as
+# published by the Free Software Foundation, either version 3 of the
+# License, or (at your option) any later version.
+#
+# Savane is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 require_once ('../../include/init.php');
 require_once ('../../include/sendmail.php');
@@ -556,16 +576,18 @@ elseif ($item == "gpgkey")
     if (!$newvalue)
       $newvalue = $row_user['gpg_key'];
 
-    $input_specific .= '<textarea title="' . _("New GPG key")
-      . '" cols="70" rows="20" wrap="virtual" name="newvalue">'
-      . htmlspecialchars ($newvalue) . "</textarea>\n";
+    $input_specific .= form_textarea (
+      'newvalue', utils_specialchars ($newvalue),
+      'title="' . _("New GPG key") . '" cols="70" rows="20" wrap="virtual"'
+    );
+    $input_specific .= "\n";
     $input_specific .= '<p><input type="submit" name="test_gpg_key" value="'
       . _("Test GPG keys") . '" /> '
       . _("(Testing is recommended before updating.)") . "</p>\n"
       . "\n<hr />\n";
     $input_specific .= $gpg_gnu_maintainers_note;
     if ($test_gpg_key)
-      $input_specific .= run_gpg_checks ($newvalue);
+      $input_specific .= gpg_run_checks ($newvalue);
   }
 elseif ($item == "email")
   {
