@@ -1,13 +1,20 @@
 <?php
 # Handle SSH keys.
 #
-# Copyright (C) 1999-2000 The SourceForge Crew
-# Copyright (C) 2004-2006 Mathieu Roy <yeupou--gnu.org>
-# Copyright (C) 2007  Sylvain Beucler
-# Copyright (C) 2017, 2018, 2022, 2023 Ineiev
+# Copyright (C) 1999, 2000 The SourceForge Crew
+# Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
+# Copyright (C) 2014, 2016, 2017 Assaf Gordon
+# Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
+# Copyright (C) 2013, 2014, 2017-2023 Ineiev
 #
 # This file is part of Savane.
 #
+# Code written before 2008-03-30 (commit 8b757b2565ff) is distributed
+# under the terms of the GNU General Public license version 3 or (at your
+# option) any later version; further contributions are covered by
+# the GNU Affero General Public license version 3 or (at your option)
+# any later version.  The license notices for the AGPL and the GPL follow.
+#
 # Savane is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
 # published by the Free Software Foundation, either version 3 of the
@@ -20,6 +27,19 @@
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# Savane is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as
+# published by the Free Software Foundation, either version 3 of the
+# License, or (at your option) any later version.
+#
+# Savane is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 require_once ('../../include/init.php');
 require_once ('../../include/account.php');
@@ -46,7 +66,7 @@ if ($update)
     if (!form_check ($form_id))
       exit_error (_("Exiting"));
 
-    $keys = '';
+    $keys = [];
     # Build the key string.
     for ($i = 0; $i < $key_limit; $i++)
       {
@@ -55,44 +75,14 @@ if ($update)
         $thiskey = $form_authorized_keys[$i];
         # Remove useless blank spaces.
         $thiskey = trim ($thiskey);
-        # Remove line breaks.
         $thiskey = str_replace ("\n", "", $thiskey);
-        if ($thiskey != '')
+        if ($thiskey !== '' && !in_array ($thiskey, $keys, true))
           {
-            # Test the key with ssh-vulnkey.
-            $descriptorspec = [
-              0 => ['pipe', 'r'], 1 => ['pipe', 'w'],
-              2 => ['file', '/dev/null', 'a'],
-            ];
-            $process = proc_open ('ssh-vulnkey -', $descriptorspec, $pipes);
-
-            $return_value = 1;
-            if (is_resource($process))
-              {
-                fwrite ($pipes[0], $thiskey);
-                fclose ($pipes[0]);
-                stream_get_contents ($pipes[1]); # empty pipe
-                fclose ($pipes[1]);
-                $return_value = proc_close ($process);
-              }
-            if ($return_value != 0)
-              {
-                fb (sprintf (_("Key #%s seen"), $i + 1));
-                $keys .= $thiskey . $key_separator;
-              }
-            else
-              # TRANSLATORS: the argument is a link to a page.
-              fb (
-                sprintf (
-                  _("Error: ssh-vulnkey detected key #%s as compromised.\n"
-                    . "Please upgrade your system and regenerate it\n"
-                    . "(see %s for more information)."),
-                  $i + 1, '//wiki.debian.org/SSLkeys'
-                ),
-                1
-              );
+            fb (sprintf (_("Key #%s seen"), $i + 1));
+            $keys[] = $thiskey;
           }
       }
+    $keys = join ($key_separator, $keys);
     # Grab original keys from the database for comparison.
     $res_orig_keys = db_execute (
       "SELECT authorized_keys FROM user WHERE user_id = ?", [user_getid ()]
