@@ -1,12 +1,19 @@
 <?php
 # Manage user preferences.
-# Copyright (C) 1999-2000 The SourceForge Crew
-# Copyright (C) 2002-2006 Mathieu Roy <yeupou--gnu.org>
-# Copyright (C) 2007  Sylvain Beucler
-# Copyright (C) 2017, 2019, 2022 Ineiev
+# Copyright (C) 1999, 2000 The SourceForge Crew
+# Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
+# Copyright (C) 2014, 2016, 2017 Assaf Gordon
+# Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
+# Copyright (C) 2013, 2014, 2017-2023 Ineiev
 #
 # This file is part of Savane.
 #
+# Code written before 2008-03-30 (commit 8b757b2565ff) is distributed
+# under the terms of the GNU General Public license version 3 or (at your
+# option) any later version; further contributions are covered by
+# the GNU Affero General Public license version 3 or (at your option)
+# any later version.  The license notices for the AGPL and the GPL follow.
+#
 # Savane is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
 # published by the Free Software Foundation, either version 3 of the
@@ -19,6 +26,19 @@
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# Savane is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as
+# published by the Free Software Foundation, either version 3 of the
+# License, or (at your option) any later version.
+#
+# Savane is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 require_once ('../../include/sane.php');
 require_once ('../../include/utils.php');
@@ -225,7 +245,7 @@ print '<p class="smaller">'
 
 $i++;
 print_box_next_item ();
-print "<p><a href=\"${sys_home}users/{$row_user['user_name']}\">"
+print "<p><a href=\"{$sys_home}users/{$row_user['user_name']}\">"
   . _("View your Public Profile") . "</a></p>\n";
 print '<p class="smaller">' . _("Your profile can be viewed by everybody.")
  . "</p>\n";
@@ -353,7 +373,7 @@ if (!theme_guidelines_check (SV_THEME))
             $sys_name
           );
         print utils_link (
-          "${sys_home}support/?group=$sys_unix_group_name",
+          "{$sys_home}support/?group=$sys_unix_group_name",
           $link_text, "warn"
         );
       }
