@@ -1,12 +1,20 @@
 <?php
-# News subnissions.
+# News submission.
 #
-# Copyright (C) 1999-2000 The SourceForge Crew
-# Copyright (C) 2003-2006 Mathieu Roy <yeupou--gnu.org>
-# Copyright (C) 2017, 2023 Ineiev
+# Copyright (C) 1999, 2000 The SourceForge Crew
+# Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
+# Copyright (C) 2014, 2016, 2017 Assaf Gordon
+# Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
+# Copyright (C) 2013, 2014, 2017-2023 Ineiev
 #
 # This file is part of Savane.
 #
+# Code written before 2008-03-30 (commit 8b757b2565ff) is distributed
+# under the terms of the GNU General Public license version 3 or (at your
+# option) any later version; further contributions are covered by
+# the GNU Affero General Public license version 3 or (at your option)
+# any later version.  The license notices for the AGPL and the GPL follow.
+#
 # Savane is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
 # published by the Free Software Foundation, either version 3 of the
@@ -19,9 +27,21 @@
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# Savane is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as
+# published by the Free Software Foundation, either version 3 of the
+# License, or (at your option) any later version.
+#
+# Savane is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 require_once ('../include/init.php');
-require_once ('../include/news/forum.php');
 
 extract (sane_import ('post',
   [
@@ -50,14 +70,10 @@ if ($update)
     $result = false;
     if ($valid)
       {
-        # Insert the new item, with 5 as status: group admin
-        # must moderate it. There must be a title.
-        $new_id = forum_create_forum ($group_id, $summary, 1, 0);
-
         $t = time ();
         $fields = [ 'group_id' => $group_id, 'submitted_by' => user_getid (),
           'is_approved' => 5, 'date' => $t, 'date_last_edit' => $t,
-          'forum_id' => $new_id, 'summary' => $summary, 'details' => $details
+          'forum_id' => 0, 'summary' => $summary, 'details' => $details
         ];
         $result = db_autoexecute ('news_bytes', $fields, DB_AUTOQUERY_INSERT);
       }
@@ -67,7 +83,8 @@ if ($update)
          . "manager of this group before it shows on the front page.");
         form_clean ($form_id);
         session_redirect (
-          "${sys_home}news/?group=$group&feedback=" . urlencode ($feedback)
+          "{$sys_home}news/?group=$group&feedback="
+          . utils_urlencode ($feedback)
         );
       }
     else
@@ -85,11 +102,11 @@ print '<p class="warn">'
   . "</p>\n"
   . form_header ($_SERVER['PHP_SELF'], $form_id)
   . form_hidden (["group_id" => $group_id])
-  . "<span class='preinput'><label for='summary'>" . _("Subject:")
-  . "</label></span><br/>&nbsp;&nbsp;\n"
+  . "<span class='preinput'>" . html_label ('summary', _("Subject:"))
+  . "</span><br/>&nbsp;&nbsp;\n"
   . "<input type='text' id='summary' name='summary' value=\"$summary\" "
-  . "size='65' maxlenght='80' /><br />\n<span class='preinput'>"
-  . "<label for='details'>" . _("Details") . '</label> '
+  . "size='65' maxlength='80' /><br />\n"
+  . "<span class='preinput'>" . html_label ('details', _("Details"))
   . markup_info ("full") . "</span><br />&nbsp;&nbsp;\n"
   . "<textarea name='details' id='details' rows='20' cols='65' wrap='soft'>\n"
   . "$details</textarea><br />\n" . form_footer ();
