@@ -1,11 +1,20 @@
 <?php
 # Vew jobs.
 #
-# Copyright (C) 1999-2000 The SourceForge Crew
-# Copyright (C) 2017, 2022 Ineiev
+# Copyright (C) 1999, 2000 The SourceForge Crew
+# Copyright (C) 2000-2006 Mathieu Roy
+# Copyright (C) 2014, 2016, 2017 Assaf Gordon
+# Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
+# Copyright (C) 2013, 2014, 2017-2023 Ineiev
 #
 # This file is part of Savane.
 #
+# Code written before 2008-03-30 (commit 8b757b2565ff) is distributed
+# under the terms of the GNU General Public license version 3 or (at your
+# option) any later version; further contributions are covered by
+# the GNU Affero General Public license version 3 or (at your option)
+# any later version.  The license notices for the AGPL and the GPL follow.
+#
 # Savane is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
 # published by the Free Software Foundation, either version 3 of the
@@ -18,10 +27,23 @@
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# Savane is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as
+# published by the Free Software Foundation, either version 3 of the
+# License, or (at your option) any later version.
+#
+# Savane is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-require_once('../include/init.php');
-require_once('../include/people/general.php');
-require_once('../include/vars.php');
+require_once ('../include/init.php');
+require_once ('../include/people/general.php');
+require_once ('../include/vars.php');
 extract (sane_import ('get', ['digits' => ['group_id', 'job_id']]));
 
 if (!$group_id)
@@ -89,7 +111,7 @@ if ($project->getTypeDescription())
   print "<p>" . markup_full ($project->getTypeDescription()) . "</p>\n";
 print "<p>";
 if ($project->getLongDescription())
-  print markup_full (htmlspecialchars ($project->getLongDescription()));
+  print markup_full (utils_specialchars ($project->getLongDescription ()));
 elseif ($project->getDescription())
   print $project->getDescription();
 print "</p>\n";
@@ -109,7 +131,7 @@ print "<span class=\"preinput\"><br />\n"
 
 print '<p><span class="preinput">'
   . _("Details (job description, contact ...):") . "</span></p>\n";
-print markup_full (htmlspecialchars (db_result ($result, 0, 'description')));
+print markup_full (utils_specialchars (db_result ($result, 0, 'description')));
 print '<h2>' . _("Required Skills:") . "</h2>\n";
 print people_show_job_inventory($job_id);
 $finish_page ();
