@@ -1,13 +1,21 @@
 <?php
 # Enable and configure a group's available services
 #
-# Copyright (C) 2003-2006 Mathieu Roy <yeupou--gnu.org>
-# Copyright (C) 2007, 2008  Sylvain Beucler
-# Copyright (C) 2008  Aleix Conchillo Flaque
-# Copyright (C) 2017, 2020, 2022 Ineiev
+# Copyright (C) 1999, 2000 The SourceForge Crew
+# Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
+# Copyright (C) 2008 Aleix Conchillo Flaque
+# Copyright (C) 2014, 2016, 2017 Assaf Gordon
+# Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
+# Copyright (C) 2013, 2014, 2017-2023 Ineiev
 #
 # This file is part of Savane.
 #
+# Code written before 2008-03-30 (commit 8b757b2565ff) is distributed
+# under the terms of the GNU General Public license version 3 or (at your
+# option) any later version; further contributions are covered by
+# the GNU Affero General Public license version 3 or (at your option)
+# any later version.  The license notices for the AGPL and the GPL follow.
+#
 # Savane is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
 # published by the Free Software Foundation, either version 3 of the
@@ -20,6 +28,19 @@
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# Savane is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as
+# published by the Free Software Foundation, either version 3 of the
+# License, or (at your option) any later version.
+#
+# Savane is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 require_once('../../include/init.php');
 require_once('../../include/sane.php');
@@ -199,7 +220,7 @@ function specific_line ($artifact, $explanation, $use, $increment=1)
     $url = $project->getUrl($artifact);
   else
     $url = $project->getArtifactUrl($artifact);
-  $url = htmlspecialchars_decode ($url);
+  $url = utils_specialchars_decode ($url, ENT_QUOTES);
   $extra = 'size="20" title="' . _("Alternative Address") . '"';
   print form_input ("text", "url_$artifact", $url, $extra) . $tail;
 }
