@@ -1,14 +1,21 @@
 <?php
 # Edit group public info.
 #
-# Copyright (C) 1999-2000 The SourceForge Crew
-# Copyright (C) 2000-2003 Free Software Foundation
+# Copyright (C) 1999, 2000 The SourceForge Crew
+# Copyright (C) 2000-2006 Free Software Foundation, Inc.
 # Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
-# Copyright (C) 2007 Sylvain Beucler
-# Copyright (C) 2017, 2018, 2020, 2021, 2022, 2023 Ineiev
+# Copyright (C) 2014, 2016, 2017 Assaf Gordon
+# Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
+# Copyright (C) 2013, 2014, 2017-2023 Ineiev
 #
 # This file is part of Savane.
 #
+# Code written before 2008-03-30 (commit 8b757b2565ff) is distributed
+# under the terms of the GNU General Public license version 3 or (at your
+# option) any later version; further contributions are covered by
+# the GNU Affero General Public license version 3 or (at your option)
+# any later version.  The license notices for the AGPL and the GPL follow.
+#
 # Savane is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
 # published by the Free Software Foundation, either version 3 of the
@@ -21,6 +28,19 @@
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# Savane is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as
+# published by the Free Software Foundation, either version 3 of the
+# License, or (at your option) any later version.
+#
+# Savane is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 require_once ('../../include/init.php');
 require_once ('../../include/vars.php');
@@ -81,7 +101,7 @@ if ($update)
   }
 
 if ($test_keyring)
-  $gpg_checks = run_gpg_checks ($new_keyring, false, '3');
+  $gpg_checks = gpg_run_checks ($new_keyring, false, '3');
 
 if ($update_keyring)
   {
@@ -119,7 +139,8 @@ $print_preinput (_("Group Name:"), 'form_group_name');
 print
   form_input (
     "text", "form_group_name",
-    htmlspecialchars_decode ($row_grp['group_name']), 'size="60" maxlen="254"'
+    utils_specialchars_decode ($row_grp['group_name'], ENT_QUOTES),
+   'size="60" maxlen="254"'
   )
   . "</p>\n";
 $print_preinput (
@@ -134,7 +155,7 @@ print
 $print_preinput (_("Long Description"), 'form_longdesc', 'full');
 print
   form_textarea (
-    "form_longdesc", htmlspecialchars ($row_grp['long_description']),
+    "form_longdesc", utils_specialchars ($row_grp['long_description']),
     'cols="70" rows="10" wrap="virtual"'
   )
   . "</p>\n";
@@ -193,7 +214,7 @@ if (!$new_keyring)
   $new_keyring = $keyring;
 
 print form_textarea ("new_keyring",
-  htmlspecialchars ($new_keyring), 'cols="70" rows="10" wrap="virtual"'
+  utils_specialchars ($new_keyring), 'cols="70" rows="10" wrap="virtual"'
 );
 print '<p>'
   . form_submit (_("Test GPG keys"), 'test_keyring') . "\n"
