@@ -1,12 +1,21 @@
 <?php
 # Edit notifications.
 #
-#  Copyright (C) 2003-2004 Yves Perrin <Yves.Perrin@cern.ch>
-#  Copyright (C) 2003-2004 Mathieu Roy <yeupou--at--gnu.org>
-#  Copyright (C) 2017, 2018, 2022 Ineiev
+#  Copyright (C) 1999, 2000 The SourceForge Crew
+#  Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
+#  Copyright (C) 2002-2006 Yves Perrin <yves.perrin--cern.ch>
+#  Copyright (C) 2014, 2016, 2017 Assaf Gordon
+#  Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
+#  Copyright (C) 2013, 2014, 2017-2023 Ineiev
 #
 # This file is part of Savane.
 #
+# Code written before 2008-03-30 (commit 8b757b2565ff) is distributed
+# under the terms of the GNU General Public license version 3 or (at your
+# option) any later version; further contributions are covered by
+# the GNU Affero General Public license version 3 or (at your option)
+# any later version.  The license notices for the AGPL and the GPL follow.
+#
 # Savane is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
 # published by the Free Software Foundation, either version 3 of the
@@ -19,12 +28,24 @@
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# Savane is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as
+# published by the Free Software Foundation, either version 3 of the
+# License, or (at your option) any later version.
+#
+# Savane is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 require_once ('../../include/init.php');
 require_once ('../../include/form.php');
 require_once ('../../include/vars.php');
 
-require_directory("trackers");
-
+require_directory ("trackers");
 session_require (['group' => $group_id, 'admin_flags' => 'A']);
 
 extract (sane_import ('post',
@@ -54,19 +75,6 @@ if ($update)
       "UPDATE groups SET new_news_address = ? WHERE group_id = ?",
       [$form_news_address, $group_id]
     );
-
-    if (group_set_preference ($group_id, "batch_frequency", $form_frequency))
-      fb (_("Successfully Updated Reminder Settings"));
-    else
-      fb (_("Failed to Update Reminder Setting"), 1);
-
-    if (group_get_preference ($group_id, "batch_lastsent") == "")
-      {
-        if (group_set_preference($group_id, "batch_lastsent", "0"))
-          fb(_("Successfully set Timestamp of the Latest Reminder"));
-        else
-          fb(_("Failed to Reset Timestamp of the Latest Reminder"), 1);
-      }
   }
 
 $res_grp = db_execute ("SELECT * FROM groups WHERE group_id = ?", [$group_id]);
@@ -92,37 +100,14 @@ foreach ($artifacts as $art => $label)
     $show_intro = 0;
     print "<br />\n";
   }
-$news_address = htmlspecialchars ($row_grp['new_news_address']);
 print_h2 (_("News Manager Email Notification Settings"));
 print '<span class="preinput">' . _("Carbon-Copy List:")
-  . "</span><br />\n&nbsp;&nbsp;<input type='text' name='form_news_address' "
-  . "value=\"{$news_address}\" size=\"40\" maxlength=\"255\" />"
+  . "</span><br />\n&nbsp;&nbsp;"
+  . form_input ('text', 'form_news_address', $row_grp['new_news_address'],
+      "size='40' maxlength='255'")
   . "<br /><br />\n";
 
-print_h2 (_("Reminders"));
-print '<p>'
-  . _("You can configure the project so that reminder emails get sent
-to project members who have opened items with priority higher than 5 assigned
-to them.")
-  . "<br/>\n<span class='warn'>"
-  . _("This will be done regardless of the
-fact project members have or have not requested to receive such reminders via
-their personal notification settings!")
-  . "</span></p>\n";
-$frequency = array("0" =>
-# TRANSLATORS: this is frequency.
-                          _("Never"),
-                   "1" => _("Daily"),
-                   "2" => _("Weekly"),
-                   "3" => _("Monthly"));
-
-print '<span class="preinput">' . _("Frequency of reminders:")
-  . "</span>\n&nbsp;&nbsp;";
-print html_build_select_box_from_array($frequency,
-                                       "form_frequency",
-                                       group_get_preference($group_id,
-                                                            "batch_frequency"));
 print "\n<p align='center'><input type='submit' name='update' value='"
   . _("Update") . "' />\n</form>\n";
-site_project_footer(array());
+site_project_footer ([]);
 ?>
