@@ -1,15 +1,22 @@
 <?php
 # List members.
 #
-# Copyright (C) 1999-2000 The SourceForge Crew
-# Copyright (C) 2000-2003 Free Software Foundation
+# Copyright (C) 1999, 2000 The SourceForge Crew
+# Copyright (C) 2000-2006 Free Software Foundation, Inc.
+# Copyright (C) 2000-2006 Lorenzo Hernandez Garcia-Hierro <lorenzohgh--tuxedo-es.org>
 # Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
-# Copyright (C) 2000-2006 Lorenzo Hernandez Garcia-Hierro
-#                                      <lorenzohgh--tuxedo-es.org>
-# Copyright (C) 2017, 2018, 2022, 2023 Ineiev
+# Copyright (C) 2014, 2016, 2017 Assaf Gordon
+# Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
+# Copyright (C) 2013, 2014, 2017-2023 Ineiev
 #
 # This file is part of Savane.
 #
+# Code written before 2008-03-30 (commit 8b757b2565ff) is distributed
+# under the terms of the GNU General Public license version 3 or (at your
+# option) any later version; further contributions are covered by
+# the GNU Affero General Public license version 3 or (at your option)
+# any later version.  The license notices for the AGPL and the GPL follow.
+#
 # Savane is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
 # published by the Free Software Foundation, either version 3 of the
@@ -22,6 +29,19 @@
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# Savane is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as
+# published by the Free Software Foundation, either version 3 of the
+# License, or (at your option) any later version.
+#
+# Savane is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 require_once ('../include/init.php');
 require_once ('../include/form.php');
@@ -105,11 +125,11 @@ function role_icon ($flags, $group_id)
     {
       if ($group_id == $sys_group_id)
         return ["site-admin",  _("Site Administrator")];
-      return ["project-admin", _("Project Administrator")];
+      return ["project-admin", _("Group administrator")];
     }
   if ($flags == 'SQD')
     return ["people", _("Squad")];
-  return ["project-member", _("Project Member")];
+  return ["project-member", _("Group member")];
 }
 
 function print_role_icon ($m, $group_id)
@@ -140,7 +160,7 @@ function watched_link ($this_user, $m, $group_id, $sys_home)
   $is_watched = trackers_data_is_watched ($this_user, $m['user_id'], $group_id);
   if ($m['user_id'] == $this_user || $is_watched)
     return "---";
-  return "<a href=\"${sys_home}my/groups.php?"
+  return "<a href=\"{$sys_home}my/groups.php?"
     . "func=addwatchee&amp;group_id=$group_id&amp;watchee_id="
     . $m['user_id'] . "\">" . _("Watch partner") . "</a>";
 }
@@ -153,7 +173,7 @@ if ((!$group_id) && $form_grp)
 
 site_project_header (
   [
-    'title' => _("Project Memberlist"), 'group' => $group_id,
+    'title' => _("Group memberlist"), 'group' => $group_id,
     'context' => 'people'
   ]
 );
@@ -193,7 +213,7 @@ else
   printf (
     _("If you would like to contribute to this project by\nbecoming a member, "
       . "use the <a href=\"%s\">request for inclusion</a> form."),
-    "${sys_home}my/groups.php?words=" . group_getname ($group_id)
+    "{$sys_home}my/groups.php?words=" . group_getname ($group_id)
     . '#searchgroup'
   );
 print "</p>\n";
