@@ -1,13 +1,21 @@
 <?php
 # Edit group types configuration.
 #
-# Copyright (C) 2002-2006 Mathieu Roy <yeupou--gnu.org>
-# Copyright (C) 2007, 2008  Sylvain Beucler
-# Copyright (C) 2008  Aleix Conchillo Flaque
-# Copyright (C) 2017, 2022, 2023 Ineiev
+# Copyright (C) 1999, 2000 The SourceForge Crew
+# Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
+# Copyright (C) 2008 Aleix Conchillo Flaque
+# Copyright (C) 2014, 2016, 2017 Assaf Gordon
+# Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
+# Copyright (C) 2013, 2014, 2017-2023 Ineiev
 #
 # This file is part of Savane.
 #
+# Code written before 2008-03-30 (commit 8b757b2565ff) is distributed
+# under the terms of the GNU General Public license version 3 or (at your
+# option) any later version; further contributions are covered by
+# the GNU Affero General Public license version 3 or (at your option)
+# any later version.  The license notices for the AGPL and the GPL follow.
+#
 # Savane is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
 # published by the Free Software Foundation, either version 3 of the
@@ -20,6 +28,19 @@
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# Savane is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as
+# published by the Free Software Foundation, either version 3 of the
+# License, or (at your option) any later version.
+#
+# Savane is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 require_once ('../include/init.php');
 require_once ('../include/vars.php');
@@ -30,10 +51,6 @@ session_require (['group' => '1','admin_flags' => 'A']);
 
 # We don't internationalize messages in this file because they are
 # for Savannah admins who use English.
-function no_i18n ($string)
-{
-  return $string;
-}
 
 function specific_showinput ($title, $form, $id = false)
 {
@@ -116,7 +133,7 @@ $name_matching = function ($trackers, $vcs_list)
   foreach ($hm_dw as $hd)
     $names['specialchars'][] = "url_$hd";
   foreach ($vcs_list as $vcs)
-    $names['specialchars'][] = "url_${vcs}_viewcvs";
+    $names['specialchars'][] = "url_{$vcs}_viewcvs";
   $names['specialchars'][] = "url_cvs_viewcvs_homepage";
   foreach (
     [
@@ -141,7 +158,7 @@ $name_matching = function ($trackers, $vcs_list)
     if ($art != 'cookbook' && $art != 'news')
       $names['true'][] = "is_menu_configurable_$art";
   foreach ($vcs_list as $vcs)
-    $names['true'][] = "is_menu_configurable_${vcs}_viewcvs";
+    $names['true'][] = "is_menu_configurable_{$vcs}_viewcvs";
   $names['true'][] = "is_configurable_download_dir";
   return $names;
 };
@@ -171,18 +188,18 @@ if ($update)
     $names = [];
     foreach ($trackers as $art)
       {
-        $names[] = "${art}_user_";
-        $names[] = "${art}_restrict_event1";
+        $names[] = "{$art}_user_";
+        $names[] = "{$art}_restrict_event1";
       }
     $names[] = '/^(\d+|NULL)$/';
     extract (sane_import ('post', ['preg' => [$names]]));
     $arg_arr = [];
     foreach ($trackers as $art)
       {
-        $var = "${art}_user_";
-        $arg_arr["${art}_flags"] = $$var;
-        $var = "${art}_restrict_event1";
-        $arg_arr["${art}_rflags"] = $$var;
+        $var = "{$art}_user_";
+        $arg_arr["{$art}_flags"] = $$var;
+        $var = "{$art}_restrict_event1";
+        $arg_arr["{$art}_rflags"] = $$var;
       }
 
     $result = db_autoexecute (
@@ -690,7 +707,7 @@ print '<p>'
 $list_head = html_build_list_table_top ($tracker_labels) . "<tr>\n";
 print $list_head;
 foreach ($trackers as $art)
-  html_select_permission_box ($art, $row_grp["${art}_flags"], "type");
+  html_select_permission_box ($art, $row_grp["{$art}_flags"], "type");
 
 print "</tr>\n</table>\n";
 
@@ -707,7 +724,7 @@ print '<p>'
 
 print $list_head;
 foreach ($trackers as $art)
-  html_select_restriction_box ($art, $row_grp["${art}_rflags"], "type");
+  html_select_restriction_box ($art, $row_grp["{$art}_rflags"], "type");
 print "</tr>\n</table>\n";
 
 $HTML->box1_bottom ();
