@@ -1,14 +1,21 @@
 <?php
 # Edit one group as superuser.
 #
-# Copyright (C) 1999-2000 The SourceForge Crew
-# Copyright (C) 2002-2006 Mathieu Roy <yeupou--gnu.org>
-# Copyright (C) 2007, 2008  Sylvain Beucler
-# Copyright (C) 2008  Aleix Conchillo Flaque
-# Copyright (C) 2017, 2018, 2020, 2023 Ineiev
+# Copyright (C) 1999, 2000 The SourceForge Crew
+# Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
+# Copyright (C) 2008 Aleix Conchillo Flaque
+# Copyright (C) 2014, 2016, 2017 Assaf Gordon
+# Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
+# Copyright (C) 2013, 2014, 2017-2023 Ineiev
 #
 # This file is part of Savane.
 #
+# Code written before 2008-03-30 (commit 8b757b2565ff) is distributed
+# under the terms of the GNU General Public license version 3 or (at your
+# option) any later version; further contributions are covered by
+# the GNU Affero General Public license version 3 or (at your option)
+# any later version.  The license notices for the AGPL and the GPL follow.
+#
 # Savane is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
 # published by the Free Software Foundation, either version 3 of the
@@ -21,6 +28,19 @@
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# Savane is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as
+# published by the Free Software Foundation, either version 3 of the
+# License, or (at your option) any later version.
+#
+# Savane is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 require_once ('../include/init.php');
 require_once ('../include/vars.php');
@@ -33,10 +53,6 @@ session_require (['group' => $sys_group_id, 'admin_flags' => 'A']);
 
 # We don't internationalize messages in this file because they are
 # for Savannah admins who use English.
-function no_i18n ($string)
-{
-  return $string;
-}
 
 $post_names = function ()
 {
@@ -91,7 +107,7 @@ if ($update || $updatefast)
             'dir_cvs' => '', 'dir_arch' => '', 'dir_svn' => '',
             'dir_git' => '', 'dir_hg' => '', 'dir_bzr' => '',
             'dir_homepage' => '', 'dir_download' => ''],
-          DB_AUTOQUERY_UPDATE, "group_id=?", [$group_id]
+          DB_AUTOQUERY_UPDATE, "group_id = ?", [$group_id]
         );
       } # $update
     if ($updatefast)
@@ -101,20 +117,22 @@ if ($update || $updatefast)
     fb (no_i18n ("Updating group info"));
   }
 # Get current information.
-$res_grp = db_execute("SELECT * FROM groups WHERE group_id=?", array($group_id));
+$res_grp = db_execute ("SELECT * FROM groups WHERE group_id=?", [$group_id]);
 
-site_admin_header(array('title'=>no_i18n("Group List"),'context'=>'admgroup'));
+site_admin_header (
+  ['title' => no_i18n ("Group List"), 'context' => 'admgroup']
+);
 
-if (db_numrows($res_grp) < 1)
+if (!db_numrows ($res_grp))
   {
-    fb(no_i18n("Invalid Group: Invalid group was passed in."));
-    site_admin_footer(array());
+    fb (no_i18n ("Invalid Group: Invalid group was passed in."), 1);
+    site_admin_footer ([]);
     exit;
   }
 
-$row_grp = db_fetch_array($res_grp);
+$row_grp = db_fetch_array ($res_grp);
 
-utils_get_content("admin/groupedit_intro");
+utils_get_content ("admin/groupedit_intro");
 
 print '<p>';
 print "<a href='../projects/{$row_grp['unix_group_name']}'>"
@@ -122,27 +140,40 @@ print "<a href='../projects/{$row_grp['unix_group_name']}'>"
 print '</p>
 ';
 
-print '<h2>' . no_i18n("Registration Management Shortcuts") . "</h2>\n";
+print '<h2>' . no_i18n ("Registration Management Shortcuts") . "</h2>\n";
 print "<a href=\"$php_self?status=A&amp;updatefast=1&amp;group_id=$group_id\">"
   . html_image ("bool/ok.orig.png", ['alt' => no_i18n ("Approve")])
-  . '</a>&nbsp;&nbsp;&nbsp;';
-print "<a href=\"$php_self?status=D&amp;updatefast=1&amp;group_id=$group_id\">"
-  . html_image ("bool/wrong.orig.png", ['alt' => no_i18n ("Discard")])
-  . '</a>&nbsp;&nbsp;&nbsp;';
-print "<a href=\"triggercreation.php?group_id=$group_id\">"
-  . html_image (
-      "contexts/preferences.orig.png",
-      ['alt' => no_i18n ("Send new group instruction email and trigger "
-                         . "group creation (should be done only once)")]
-    )
   . '</a>';
+$res = db_execute (
+  "SELECT COUNT(group_list_id) AS cnt FROM mail_group_list WHERE group_id = ?",
+  [$group_id]
+);
+$no_lists = true;
+$list_row = db_fetch_array ($res);
+if (!empty ($list_row))
+  $no_lists = $list_row['cnt'] < 1;
+if ($no_lists)
+  print "&nbsp;&nbsp;&nbsp;<a href=\"$php_self"
+    . "?status=D&amp;updatefast=1&amp;group_id=$group_id\">"
+    . html_image ("bool/wrong.orig.png", ['alt' => no_i18n ("Discard")])
+    . '</a>';
+else
+  {
+    $msg = sprintf (
+      no_i18n ("This group has associated mailing lists;\n"
+        . "<a href='%s'>unlink or remove them</a>\n"
+        . "before discarding the group."),
+      "{$sys_home}mail/admin/?group={$row_grp['unix_group_name']}"
+    );
+    print "<br />\n$msg<br />\n";
+  }
 
 print form_tag ();
 print '<h2>' . no_i18n ("Detailed Interface") . "</h2>\n";
 $HTML->box1_top (no_i18n ("General Settings"));
 
 print '<p><span class="preinput">' . no_i18n ("Group Type:")
- .  " </span><br />\n";
+  . " </span><br />\n";
 print '<em>';
 utils_get_content ("admin/groupedit_grouptype");
 print "</em><br />\n";
