@@ -1,12 +1,20 @@
 <?php
 # List groups by given criteria.
 #
-# Copyright (C) 1999-2000 The SourceForge Crew
-# Copyright (C) 2004-2006 Mathieu Roy <yeupou--gnu.org>
-# Copyright (C) 2017, 2023 Ineiev
+# Copyright (C) 1999, 2000 The SourceForge Crew
+# Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
+# Copyright (C) 2014, 2016, 2017 Assaf Gordon
+# Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
+# Copyright (C) 2013, 2014, 2017-2023 Ineiev
 #
 # This file is part of Savane.
 #
+# Code written before 2008-03-30 (commit 8b757b2565ff) is distributed
+# under the terms of the GNU General Public license version 3 or (at your
+# option) any later version; further contributions are covered by
+# the GNU Affero General Public license version 3 or (at your option)
+# any later version.  The license notices for the AGPL and the GPL follow.
+#
 # Savane is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
 # published by the Free Software Foundation, either version 3 of the
@@ -19,15 +27,24 @@
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# Savane is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as
+# published by the Free Software Foundation, either version 3 of the
+# License, or (at your option) any later version.
+#
+# Savane is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 require_once ('../include/init.php');
 
 # We don't internationalize messages in this file because they are
 # for Savannah admins who use English.
-function no_i18n ($string)
-{
-  return $string;
-}
 
 site_admin_header (
   ['title' => no_i18n ("Group List"), 'context' => 'admgroup']
@@ -103,16 +120,16 @@ print "<br />\n"
   . no_i18n ("or search by group_id, group_unix_name or group_name:");
 
 print "\n"
-  . "<form name='gpsrch' action='grouplist.php' method='POST'>\n"
-  . "<input type='text' title=\"" . no_i18n ("Group name")
-  . "\" name='search' value =\"" . htmlspecialchars ($search) . "\" />\n"
+  . form_tag (['name' => 'gpsrch'])
+  . form_input ('text', 'search', $search,
+     'title="' . no_i18n ("Group name") . '"') . "\n"
   . form_hidden (['groupsearch' => '1'])
   . "<input type='submit' value=\"" . no_i18n ("Search") . "\" />\n"
   . "</form>\n</p>\n";
 
 print '<h2>' . no_i18n ("Group List") . "</h2>\n";
 
-if (!$offset or !ctype_digit ($offset) or $offset < 0)
+if (!$offset or !ctype_digit (strval ($offset)) or $offset < 0)
   $offset = 0;
 else
   $offset = intval ($offset);
@@ -133,11 +150,11 @@ elseif (!empty ($status_arr[$status]))
   }
 elseif ($groupsearch)
 {
-  $msg = no_i18n ("Groups that match") . " <strong>'"
-    . htmlspecialchars ($search) . "'</strong>\n";
+  $msg = no_i18n ("Groups that match") . " <b>'"
+    . utils_specialchars ($search) . "'</b>\n";
   $where = "group_id LIKE '%$search%' OR unix_group_name "
     . "LIKE '%$search%' OR group_name LIKE '%$search%'";
-  $search_url = "&groupsearch=1&search=" . urlencode ($search);
+  $search_url = "&groupsearch=1&search=" . utils_urlencode ($search);
 }
 
 $res = db_execute ("
@@ -192,8 +209,8 @@ else
 print "</table>\n";
 
 html_nextprev (
- '?groupsearch=1&amp;group_name_search=' . urlencode ($group_name_search)
- . '&amp;search=' . urlencode($search),
+ '?groupsearch=1&amp;group_name_search=' . utils_urlencode ($group_name_search)
+ . '&amp;search=' . utils_urlencode ($search),
  $rows, $rows_returned
 );
 
