@@ -1,12 +1,20 @@
 <?php
 # siteadmin start page.
 #
-# Copyright (C) 1999-2000 The SourceForge Crew
-# Copyright (C) 2004-2006 Mathieu Roy <yeupou--gnu.org>
-# Copyright (C) 2017, 2019, 2023 Ineiev
+# Copyright (C) 1999, 2000 The SourceForge Crew
+# Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
+# Copyright (C) 2014, 2016, 2017 Assaf Gordon
+# Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
+# Copyright (C) 2013, 2014, 2017-2023 Ineiev
 #
 # This file is part of Savane.
 #
+# Code written before 2008-03-30 (commit 8b757b2565ff) is distributed
+# under the terms of the GNU General Public license version 3 or (at your
+# option) any later version; further contributions are covered by
+# the GNU Affero General Public license version 3 or (at your option)
+# any later version.  The license notices for the AGPL and the GPL follow.
+#
 # Savane is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
 # published by the Free Software Foundation, either version 3 of the
@@ -19,16 +27,24 @@
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# Savane is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as
+# published by the Free Software Foundation, either version 3 of the
+# License, or (at your option) any later version.
+#
+# Savane is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 require_once ('../include/init.php');
 
 # We don't internationalize messages in this file because they are
 # for Savannah admins who use English.
-function no_i18n ($string)
-{
-  return $string;
-}
-
 site_admin_header (['title' => no_i18n ("Home"),'context' => 'admhome']);
 extract (sane_import ('get',
   ['strings' => [['func', ['configure', 'manage', 'monitor']]]]
@@ -76,6 +92,11 @@ if (!$func || $func == "configure")
       . no_i18n ("Here you can define skills for users to select in their "
           . "resume and type of jobs for contribution requests.")
       . "</p>\n";
+    print $HTML->box_nextitem ($even);
+    print '<a href="mailman.php">' . no_i18n ("Assign mailing lists") . '</a>';
+    print '<p class="smaller">'
+      . no_i18n ("Move mailing lists from one group to another.");
+    print "</p>\n";
     print $HTML->box_bottom ();
     print "<br />\n";
   }
@@ -93,15 +114,16 @@ if (!$func || $func == "manage")
     print '<a href="' . $GLOBALS['sys_home'] . 'task/?group='
       . $GLOBALS['sys_unix_group_name']
       . '&amp;category_id=1&amp;status_id=1&amp;set=custom#results">'
-      . no_i18n ("Browse pending project registrations") . '</a>';
+      . no_i18n ("Browse pending registrations") . '</a>';
     print '<p class="smaller">'
       . no_i18n ("This will show the list of open task related to pending "
-          . "registrations.");
+          . "group registrations.");
     print "</p>\n";
 
     print $HTML->box_nextitem ($even);
     print '<a href="' . $GLOBALS['sys_home'] . 'news/approve.php?group='
-      . $GLOBALS['sys_unix_group_name'] . '">' . no_i18n("Approve news") . '</a>';
+      . $GLOBALS['sys_unix_group_name'] . '">'
+      . no_i18n ("Approve news") . '</a>';
     print '<p class="smaller">';
     printf (
       no_i18n ("You can browse the list of recent news posted on "
@@ -120,14 +142,16 @@ if (!$func || $func == "manage")
     print '<a href="grouplist.php">' . no_i18n ("Browse group list") . '</a>';
     print '<p class="smaller">'
       . no_i18n ("From there, you can see the complete list of groups and "
-          . "edit them (change status, etc).")
-      . "</p>\n";
+          . "edit them (change status, etc).");
+    print "</p>\n";
 
     print $HTML->box_nextitem ($even);
     print '<a href="userlist.php">' . no_i18n ("Browse user list") . '</a>';
     print '<p class="smaller">'
       . no_i18n ("From there, you can see the complete list of user and edit "
           . "them (change status, email, etc).");
+    print "</p>\n";
+
     print $HTML->box_bottom ();
     print "<br />\n";
 
