@@ -1,14 +1,22 @@
 <?php
 # Operate trackers.
 #
-# Copyright (C) 1999-2000 The SourceForge Crew
-# Copyright (C) 2001-2002 Laurent Julliard, CodeX Team, Xerox
-# Copyright (C) 2002-2006 Mathieu Roy <yeupou--gnu.org>
+# Copyright (C) 1999, 2000 The SourceForge Crew
+# Copyright (C) 2001, 2002 Laurent Julliard, CodeX Team, Xerox
+# Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
 # Copyright (C) 2002-2006 Yves Perrin <yves.perrin--cern.ch>
-# Copyright (C) 2017, 2019, 2022 Ineiev
+# Copyright (C) 2014, 2016, 2017 Assaf Gordon
+# Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
+# Copyright (C) 2013, 2014, 2017-2023 Ineiev
 #
 # This file is part of Savane.
 #
+# Code written before 2008-03-30 (commit 8b757b2565ff) is distributed
+# under the terms of the GNU General Public license version 3 or (at your
+# option) any later version; further contributions are covered by
+# the GNU Affero General Public license version 3 or (at your option)
+# any later version.  The license notices for the AGPL and the GPL follow.
+#
 # Savane is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
 # published by the Free Software Foundation, either version 3 of the
@@ -21,8 +29,22 @@
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# Savane is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as
+# published by the Free Software Foundation, either version 3 of the
+# License, or (at your option) any later version.
+#
+# Savane is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 require_once ('../include/init.php');
+require_once ('../include/group.php');
 require_once ('../include/trackers/general.php');
 require_once ('../include/trackers/votes.php');
 
@@ -67,7 +89,6 @@ function fb_anon_check_failed ($check)
 extract (sane_import ('request',
   [
     'funcs' => 'func',
-    'true' => 'printer',
     'digits' => ['item_file_id', 'item_cc_id']
   ]
 ));
@@ -133,11 +154,18 @@ if ($is_trackeradmin)
     ]
   ));
 
+foreach (['reassign_change_project_search', 'depends_search'] as $var)
+  if (!is_scalar ($$var))
+    $$var = '';
+
 if ($canned_response === null)
   extract (sane_import ('post',
     ['array' => [['canned_response', [null, 'digits']]]]
   ));
 
+if (empty ($canned_response))
+  $canned_response = null;
+
 extract (sane_import ('get',
   [
     'digits' => ['comment_internal_id', 'item_depends_on'],
@@ -151,7 +179,7 @@ extract (sane_import ('get',
 # blabla.org/task/?nnnn (blabla.org/task/?#nnnn cannot work because # is
 # not sent by the browser as it's a tag for html anchors).
 if (!empty ($_SERVER['QUERY_STRING'])
-    && ctype_digit ($_SERVER['QUERY_STRING']))
+    && ctype_digit (strval ($_SERVER['QUERY_STRING'])))
   $func = 'detailitem';
 
 # Initialize the global data structure before anything else.
@@ -235,13 +263,13 @@ switch ($func)
 
     # Check for duplicates.
     if (!form_check ($form_id))
-      exit_error(_("Exiting"));
+      exit_error (_("Exiting"));
 
     # Get the list of bug fields used in the form.
     $vfl = trackers_extract_field_list ();
 
     $item_id = null;
-    if (empty ($preview))
+    if (empty ($preview) && !$anon_check_failed)
       {
         # Data control layer.
         $item_id = trackers_data_create_item ($group_id, $vfl, $address);
@@ -384,7 +412,7 @@ switch ($func)
           }
         if (!$is_trackeradmin && db_result ($result, 0, 'discussion_lock'))
           exit_permission_denied ();
-        if (!group_restrictions_check ($group_id, ARTIFACT, 2))
+        if (!group_restrictions_check ($group_id, ARTIFACT, TRACKER_EVENT_COMMENT))
           exit_permission_denied ();
       }
     elseif (!$is_trackeradmin)
