@@ -1,12 +1,20 @@
 <?php
 # Check your configuration against recommended values.
 #
-# Copyright (C) 2006 Mathieu Roy <yeupou--gnu.org>
-# Copyright (C) 2007 Sylvain Beucler
-# Copyright (C) 2018, 2019, 2022, 2023 Ineiev
+# Copyright (C) 1999, 2000 The SourceForge Crew
+# Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
+# Copyright (C) 2014, 2016, 2017 Assaf Gordon
+# Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
+# Copyright (C) 2013, 2014, 2017-2023 Ineiev
 #
 # This file is part of Savane.
 #
+# Code written before 2008-03-30 (commit 8b757b2565ff) is distributed
+# under the terms of the GNU General Public license version 3 or (at your
+# option) any later version; further contributions are covered by
+# the GNU Affero General Public license version 3 or (at your option)
+# any later version.  The license notices for the AGPL and the GPL follow.
+#
 # Savane is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
 # published by the Free Software Foundation, either version 3 of the
@@ -19,8 +27,28 @@
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# Savane is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as
+# published by the Free Software Foundation, either version 3 of the
+# License, or (at your option) any later version.
+#
+# Savane is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 include ("include/ac_config.php");
+$sys_debug_sqlprofiler = false;
+$sys_file_domain = '';
+$sys_linguas = "en:es";
+require_once ("include/i18n.php");
+require_once ("include/utils.php");
+require_once ("include/database.php");
+require_once ("include/mailman.php");
 
 function return_bytes ($v)
 {
@@ -29,7 +57,7 @@ function return_bytes ($v)
     return $val;
   $last = strtolower (substr ($val, -1));
   $val = substr ($val, 0, -1);
-  if (!is_int ($val) || !in_array ($last, ['g', 'm', 'k']))
+  if (!preg_match ('/^\d*$/', $val) || !in_array ($last, ['g', 'm', 'k']))
     return ">$v<";
   switch ($last)
     {
@@ -41,10 +69,10 @@ function return_bytes ($v)
       case 'k':
         $val *= 1024;
     }
-  return $val;
+  return (int) $val;
 }
 
-function test_gpg()
+function test_gpg ()
 {
   print "\n<h3>GnuPG</h3>\n\n";
 
@@ -57,32 +85,21 @@ function test_gpg()
   print "<dl><dt>GPG command</dt>\n<dd><code>" . $GLOBALS['sys_gpg_name']
         . "</code></dd>\n";
 
-  $d_spec = array (0 => array("pipe", "r"), 1 => array("pipe", "w"),
-                   2 => array("pipe", "w"));
-
-  $gpg_proc = proc_open ("'" . $GLOBALS['sys_gpg_name'] . "' --version",
-                         $d_spec, $pipes, NULL, $_ENV);
-  if ($gpg_proc === false)
-    {
-      print "</dl>\n\n<p><strong>Can't run GPG.</strong></p>\n";
-      return;
-    }
-  fclose ($pipes[0]);
-  $gpg_output = stream_get_contents ($pipes[1]);
-  $gpg_stderr = stream_get_contents($pipes[2]);
-  fclose ($pipes[1]); fclose ($pipes[2]);
-  $gpg_result = proc_close($gpg_proc);
+  $gpg_result = utils_run_proc  (
+    "'" . $GLOBALS['sys_gpg_name'] . "' --version", $gpg_output,
+     $gpg_stderr
+  );
   $dd_pre = "<dd style='border: thin dashed black; border-right: none'>"
             ."<pre style='padding-left: 1em'>\n";
   print "<dt><code>--version</code> output</dt>\n";
-  print $dd_pre . htmlentities ($gpg_output) . "</pre></dd>\n";
+  print $dd_pre . utils_specialchars ($gpg_output) . "</pre></dd>\n";
   print "<dt>Exit code</dt><dd><code>" . $gpg_result . "</code></dd>\n";
   print "<dt><code>stderr</code> output</dt>\n";
-  print $dd_pre . htmlentities ($gpg_stderr) . "</pre></dd>\n";
+  print $dd_pre . utils_specialchars ($gpg_stderr) . "</pre></dd>\n";
   print "</dl>\n";
 }
 
-function test_cgitrepos()
+function test_cgitrepos ()
 {
   if (!isset ($GLOBALS['sys_etc_dir']))
     {
@@ -167,7 +184,6 @@ function test_repos ()
   print "<dt id='gitrepos'>git directories</dt>\n<dd>";
   test_git_dirs ();
   print "</dd>\n";
-   
 }
 function test_sys_upload_dir ()
 {
@@ -217,7 +233,71 @@ function test_captcha ()
     . "<p><img id='captcha' src='/captcha.php' alt='CAPTCHA' /></p>";
 }
 
-print "<?xml version=\"1.0\" encoding=\"utf-8\"?>\n";
+function test_mailman_failed ($ver)
+{
+  $fail = false;
+  $dte = "<dt><strong>Error</strong></td><dd>";
+  if (empty ($ver))
+    {
+      print "$dte<strong>No response</strong></dd>\n";
+      return true;
+    }
+  if (array_key_exists ('pipe::error', $ver))
+    {
+      print "$dte<strong>Pipe error:</strong> "
+        . "<pre>{$ver['pipe::error']}</pre></dd>\n";
+      $fail = true;
+    }
+  if (array_key_exists ('error', $ver))
+    {
+      print "$dte<pre>{$ver['error']}</pre></dd>\n";
+      $fail = true;
+    }
+  return $fail;
+}
+
+function output_mailman_version ($ver)
+{
+  if (test_mailman_failed ($ver))
+    return false;
+  if (empty ($ver['version']))
+    return false;
+  print "<dt>Version</dt><dd>{$ver['version']}</dd>\n";
+  print "<dt>Generated password</dt><dd>{$ver['password']}</dd>\n";
+  print "<dt>Timestamp</dt><dd>{$ver['timestamp']}</dd>\n";
+  return true;
+}
+function output_mailman_query ($q)
+{
+  if (test_mailman_failed ($q))
+    return false;
+  print "<dt>Query results</dt>\n<dd><dl>\n";
+  foreach ($q as $k => $v)
+    print "<dt>" . utils_specialchars ($k) . "</dt>\n"
+      . "<dd>" . utils_specialchars ($v) . "</dd>\n";
+  print "</dl>\n</dd>\n";
+  return true;
+}
+
+function test_mailman ()
+{
+  print "<h2>Mailman connection</h2>";
+  print "<dl>\n";
+  $ver = mailman_get_version ();
+  $have_version = output_mailman_version ($ver);
+  if ($have_version)
+    output_mailman_query (mailman_query_list ('savannah-users'));
+  else
+    printf ("<dt>Run time</dt><dd>%s ms</dd></dl>\n", $ver['timestamp']);
+  if ($have_version && preg_match ("/^stub /", $ver['version']))
+    print "<p><strong>This is a stub; write the real command "
+      . "in \$sys_mailman_wrapper.</strong></p>\n";
+}
+
+print "<?xml version=\"1.0\" encoding=\"utf-8\"?"
+  # Separate the previous "?" from ">" to workaround broken syntax
+  # highlighting in some editors.
+  . ">\n";
 print "<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.1//EN\"
     \"http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd\">\n\n";
 
@@ -238,77 +318,66 @@ information, since it could give details about your setup to anybody.</p>\n";
 
 print "\n<h2>Basic PHP configuration</h2>\n\n";
 
-print "<p>PHP version: " . phpversion() . "</p>\n";
+print "<p>PHP version: " . phpversion () . "</p>\n";
 
 # cf. http://php.net/manual/en/ini.php
-$phptags = array (
-        'register_globals' => 0,
-        'file_uploads' => 1,
-        'magic_quotes_gpc' => 0,
-);
+$phptags = ['file_uploads' => '1'];
 
 # Get all php.ini values.
-$all_inis = ini_get_all();
+$all_inis = ini_get_all ();
 # Define missing constant to interpret the 'access' field.
-define('PHP_INI_SYSTEM', 4);
+define ('PHP_INI_SYSTEM', 4);
 # Cf. http://www.php.net/manual/en/ini.core.php
 
 print "\n<table border=\"1\" summary=\"PHP configuration\">\n";
 print "<tr><th>PHP Tag name</th><th>Local value</th>"
-    . "<th>Suggested/Required value</th></tr>\n";
-$unset = 0;
-ksort($phptags);
-foreach ($phptags as $tag => $goodval)
-  {
-    if ((htmlentities(ini_get($tag)) == htmlentities($goodval))
-        or ($goodval==0 and !(bool)ini_get($tag)))
-      printf ("<tr><td>%s</td><td>%s</td><td>%s</td></tr>\n",
-              $tag, htmlentities(ini_get($tag)), htmlentities($goodval));
-    elseif (isset($all_inis[$tag]))
-      {
-        printf ("<tr><td>%s</td><td class=\"different\">%s</td><td>%s",
-                $tag, htmlentities(ini_get($tag)), htmlentities($goodval));
-        if ($all_inis[$tag]['access'] > PHP_INI_SYSTEM)
-          echo " (can be set in php.ini, .htaccess or httpd.conf)";
-        else
-          echo " (can be set in php.ini or httpd.conf - but not in .htaccess)";
-        echo "</td></tr>\n";
-      }
-    else
-      {
-        # non-existing ini value
-        printf ("<tr><td>%s</td><td class=\"unset\">Unknown</td>"
-                . "<td>%s</td></tr>\n",
-                $tag, htmlentities($goodval));
-        $unset = 1;
-      }
-  }
+    . "<th>Suggested value</th></tr>\n";
+$have_unset = false;
+ksort ($phptags);
+function compare_ini_vals ($tag, $good, $cmp)
+{
+  global $all_inis;
+  $gv = utils_specialchars ($good);
+  if (!array_key_exists ($tag, $all_inis))
+    {
+      printf (
+        "<tr><td>%s</td><td class=\"unset\">Unknown*</td><td>%s</td></tr>\n",
+        $tag, $gv
+      );
+      return true;
+    }
+  $ini_val = ini_get ($tag);
+  $t = utils_specialchars ($ini_val);
+  if ($cmp ($ini_val, $good))
+    {
+      printf ("<tr><td>%s</td><td>%s</td><td>%s</td></tr>\n", $tag, $t, $gv);
+      return false;
+    }
+  printf ("<tr><td>%s</td><td class=\"different\">%s</td><td>%s",
+    $tag, $t, $gv);
+  if ($all_inis[$tag]['access'] > PHP_INI_SYSTEM)
+    print " (can be set in php.ini, .htaccess or httpd.conf)";
+  else
+    print " (can be set in php.ini or httpd.conf, but not in .htaccess)";
+  print "</td></tr>\n";
+  return false;
+}
 
+$cmp = function ($a, $b) { return $a === $b; };
+foreach ($phptags as $tag => $good)
+  if (compare_ini_vals ($tag, $good, $cmp))
+    $have_unset = true;
 # Check against minimum sizes.
 $phptags = ['post_max_size' => '3M', 'upload_max_filesize' => '2M'];
-ksort ($phptags);
-foreach ($phptags as $tag => $goodval)
-  {
-    if (return_bytes(ini_get($tag)) >= return_bytes($goodval))
-      printf ("<tr><td>%s</td><td>%s</td><td>%s</td></tr>\n",
-              $tag, htmlentities(ini_get($tag)), htmlentities($goodval));
-    elseif (isset($all_inis[$tag]))
-      printf ("<tr><td>%s</td><td class=\"different\">%s</td>"
-              . "<td>%s</td></tr>\n",
-              $tag, htmlentities(ini_get($tag)), htmlentities($goodval));
-    else
-      {
-        printf ("<tr><td>%s</td><td class=\"unset\">Unknown*</td>"
-                . "<td>%s</td></tr>\n",
-                $tag,htmlentities($goodval));
-        $unset = 1;
-      }
-  }
+$cmp = function ($a, $b) { return return_bytes ($a) >= return_bytes ($b); };
+foreach ($phptags as $tag => $good)
+  if (compare_ini_vals ($tag, $good, $cmp))
+    $have_unset = true;
 print "</table>\n\n";
-if ($unset)
-  echo "<blockquote>* This tag was not found at all. It is probably "
-       . "irrelevant to your PHP version so you may ignore this "
-       . "entry.</blockquote>\n";
+if ($have_unset)
+  print "<blockquote>* This tag was not found at all. It is probably "
+    . "irrelevant to your PHP version so you may ignore this "
+    . "entry.</blockquote>\n";
 
 print "\n<h2>PHP functions</h2>\n\n";
 
@@ -343,12 +412,8 @@ foreach ($phpfunctions as $func => $comment)
   }
 print "</p>\n";
 
-$sys_linguas = "en:es";
-require_once ("include/i18n.php");
 function test_i18n ()
 {
-  global $sys_linguas;
-
   i18n_setup ("es_ES.UTF-8");
   $str = 'High';
   $res = gettext ($str);
@@ -396,8 +461,11 @@ else
       'default_domain', 'https_host', 'file_domain', 'dbhost', 'dbname',
       'dbuser', 'dbpasswd', 'www_topdir', 'url_topdir', 'etc_dir', 'incdir',
       'name', 'unix_group_name', 'themedefault', 'mail_domain', 'mail_admin',
-      'mail_replyto', 'upload_max', 'watch_anon_posts', 'new_user_watch_days'
+      'mail_replyto', 'upload_max', 'watch_anon_posts', 'new_user_watch_days',
+      'localedir', 'linguas', 'mailman_wrapper'
     ];
+    if (empty ($inside_siteadmin))
+      utils_set_csp_headers ();
 
     print "<table border=\"1\">\n";
     print "<tr><th>Conf variable</th><th>Current value</th></tr>\n";
@@ -406,7 +474,7 @@ else
         $var = "sys_$tag";
         $value = '<strong>unset</strong>';
         if (isset ($GLOBALS[$var]))
-          $value = htmlentities ($GLOBALS[$var]);
+          $value = utils_specialchars (print_r ($GLOBALS[$var], true));
         if ($var == "sys_dbpasswd")
           $value = "**************";
 
@@ -420,12 +488,9 @@ else
       . "in the configuration file.</p>\n";
     print "<p><img src='/file?file_id=test.png' alt='Test image'/></p>\n";
     test_captcha ();
+    test_mailman ();
 
     print "\n<h2>MySQL configuration</h2>\n\n";
-    require_once ("include/utils.php");
-    require_once ("include/database.php");
-    if (empty ($inside_siteadmin))
-      utils_set_csp_headers ();
     if (!db_connect ())
       print "<blockquote>Can't connect to database.</blockquote>\n";
     else
@@ -490,47 +555,24 @@ print "<p>The following is not required to run Savane, but could enhance\n"
   . "they may annoy the user with warnings, but allow you to spot "
   . "and report\npotentially harmful bugs.</p>\n";
 
-$phptags = array (
-        'display_errors' => '1',
-        'log_errors' => '1',
-        'error_reporting' => E_ALL|E_STRICT,
-        'allow_url_fopen' => '0',
-        'disable_functions' => 'exec,passthru,popen,shell_exec,system',
-);
+$phptags = [
+  'allow_url_fopen' => '0',
+  'disable_functions' => 'exec,passthru,popen,shell_exec,system',
+  'display_errors' => '1',
+  'error_reporting' => (string)(E_ALL | E_STRICT), 'log_errors' => '1',
+];
 
 print "\n<table border=\"1\">\n"
 . "<tr><th>PHP Tag name</th><th>Local value</th>"
-. "<th>Suggested/Required value</th></tr>\n";
-$unset = 0;
-ksort($phptags);
-foreach ($phptags as $tag => $goodval)
-  {
-    if (htmlentities(ini_get($tag)) == htmlentities($goodval))
-      printf ("<tr><td>%s</td><td>%s</td><td>%s</td></tr>\n",
-              $tag, htmlentities(ini_get($tag)), htmlentities($goodval));
-    elseif (isset($all_inis[$tag]))
-      {
-        printf ("<tr><td>%s</td><td class=\"different\">%s</td>"
-                . "<td><code>%s</code>",
-                $tag, htmlentities(ini_get($tag)) ,htmlentities($goodval));
-        if ($all_inis[$tag]['access'] > PHP_INI_SYSTEM)
-          echo " (can be set in php.ini, .htaccess or httpd.conf)";
-        else
-          echo " (can be set in php.ini or httpd.conf - but not in .htaccess)";
-        echo "</td></tr>\n";
-      }
-    else
-      {
-        # non-existing ini value
-        printf ("<tr><td>%s</td><td class=\"unset\">Unknown*</td>"
-                . "<td>%s</td></tr>\n",
-                $tag, htmlentities($goodval));
-        $unset = 1;
-      }
-  }
+. "<th>Suggested value</th></tr>\n";
+$have_unset = false;
+$cmp = function ($a, $b) { return $a === $b; };
+foreach ($phptags as $tag => $good)
+  if (compare_ini_vals ($tag, $good, $cmp))
+    $have_unset = true;
 print "</table>\n\n";
-if ($unset)
-  echo "<blockquote>* This tag was not found at all. It is probably irrelevant "
+if ($have_unset)
+  print "<blockquote>* This tag was not found at all. It is probably irrelevant "
        . "to your PHP version so you may ignore this entry.</blockquote>\n\n";
 
 print "</body>\n<html>\n";
