@@ -1,10 +1,20 @@
 <?php
 # Test sanitizing functions.
 #
-# Copyright (C) 2022 Ineiev
+# Copyright (C) 1999, 2000 The SourceForge Crew
+# Copyright (C) 2000-2006 Mathieu Roy
+# Copyright (C) 2014, 2016, 2017 Assaf Gordon
+# Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
+# Copyright (C) 2013, 2014, 2017-2023 Ineiev
 #
 # This file is part of Savane.
 #
+# Code written before 2008-03-30 (commit 8b757b2565ff) is distributed
+# under the terms of the GNU General Public license version 3 or (at your
+# option) any later version; further contributions are covered by
+# the GNU Affero General Public license version 3 or (at your option)
+# any later version.  The license notices for the AGPL and the GPL follow.
+#
 # Savane is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
 # published by the Free Software Foundation, either version 3 of the
@@ -18,6 +28,19 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
+# Savane is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as
+# published by the Free Software Foundation, either version 3 of the
+# License, or (at your option) any later version.
+#
+# Savane is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
 # Invocation:
 #
 #   php testing/sane.php
@@ -34,6 +57,8 @@ $reference = null;
 
 function htmlspec ($x)
 {
+  if ($x === null)
+    $x = '';
   return htmlspecialchars ($x, ENT_QUOTES);
 }
 
@@ -435,6 +460,15 @@ $reference = 'forum/message.php';
   test_sane_import ($in, $names, $out);
 }
 
+$reference = 'git/admin/index.php';
+{
+  $names = ['path' => ['readme0', 'readme1', 'readme2', 'readme3']];
+  $in = ['readme2' => 'doc/read-me.md'];
+  $out = $in;
+  $out['readme0'] = $out['readme1'] = $out['readme3'] = null;
+  test_sane_import ($in, $names, $out);
+}
+
 $reference = 'i18n.php';
 {
   $names = [
@@ -1764,7 +1798,8 @@ $reference = 'news/submit.php';
 $reference = 'news/approve.php';
 {
   $names = [
-    'digits' => ['id', 'status', 'for_group_id'],
+    'digits' => ['id', 'status'],
+    'strings' => [['status', ['0', '4', '5']]],
     'hash' => 'form_id',
     'true' => ['update', 'post_changes', 'approve'],
     'specialchars' => ['summary', 'details'],
@@ -1772,7 +1807,6 @@ $reference = 'news/approve.php';
   $in = $out = [
     'id' => 1,
     'status' => 4,
-    'for_group_id' => 83521,
     'form_id' => md5 ('md5'),
     'update' => true,
     'summary' => 'sum',
@@ -1780,6 +1814,8 @@ $reference = 'news/approve.php';
   ];
   $out['post_changes'] = $out['approve'] = null;
   test_sane_import ($in, $names, $out);
+  $in['status'] = 3; $out['status'] = null;
+  test_sane_import ($in, $names, $out);
 }
 
 $reference = 'people/admin/index.php';
@@ -2154,7 +2190,7 @@ $reference = 'siteadmin/group_type.php';
   foreach ($hm_dw as $hd)
     $names['specialchars'][] = "url_$hd";
   foreach ($vcs_list as $vcs)
-    $names['specialchars'][] = "url_${vcs}_viewcvs";
+    $names['specialchars'][] = "url_{$vcs}_viewcvs";
   $names['specialchars'][] = "url_cvs_virecvs_homepage";
   foreach (
     [
@@ -2178,7 +2214,7 @@ $reference = 'siteadmin/group_type.php';
   foreach ($conf as $art)
     $names['true'][] = "is_menu_configurable_$art";
   foreach ($vcs_list as $vcs)
-    $names['true'][] = "is_menu_configurable_${vcs}_viewvcs";
+    $names['true'][] = "is_menu_configurable_{$vcs}_viewvcs";
   $names['true'][] = "is_configurable_download_dir";
   $in = $out = [];
   foreach ($names['true'] as $n)
@@ -2269,17 +2305,11 @@ $reference = 'stats/index.php';
   $digit_names = [];
   foreach (['day', 'month', 'year'] as $term)
     foreach (['since', 'until'] as $prep)
-      $digit_names[] = "${prep}_$term";
+      $digit_names[] = "{$prep}_$term";
   $names = ['true' => 'update', 'digits' => $digit_names];
   $in = $out = ['update' => true];
   foreach ($digit_names as $n)
     $in[$n] = $out[$n] = 83521;
   test_sane_import ($in, $names, $out);
 }
-$reference = 'userguide/index.php';
-{
-  $names = ['preg' => [['file', '/^[[:alnum:]_-]+[.]html$/']]];
-  $in = $out = ['file' => 'ch01.html'];
-  test_sane_import ($in, $names, $out);
-}
 ?>
